<?php
namespace Sparks\Modules\Shortcodes\AccordionHolder;

use Sparks\Modules\Shortcodes\Lib\ShortcodeInterface;

/**
 * class Accordions
 */
class AccordionHolder implements ShortcodeInterface
{
    /**
     * @var string
     */
    private $base;

    function __construct() {
        $this->base = 'mkd_accordion_holder';
        add_action('vc_before_init', array($this, 'vcMap'));
    }

    public function getBase() {
        return $this->base;
    }

    public function vcMap() {

        if (function_exists('vc_map')) {
            vc_map(array(
                'name' => esc_html__('Accordion', 'mkd-core'),
                'base' => $this->base,
                'as_parent' => array('only' => 'mkd_accordion'),
                'content_element' => true,
                'category' => esc_html__('by MIKADO', 'mkd-core'),
                'icon' => 'icon-wpb-accordion-holder extended-custom-icon',
                'show_settings_on_create' => true,
                'js_view' => 'VcColumnView',
                'params' => array(
                    array(
                        'type' => 'textfield',
                        'heading' => esc_html__('Extra class name', 'mkd-core'),
                        'param_name' => 'el_class',
                        'description' => esc_html__('Style particular content element differently - add a class name and refer to it in custom CSS.', 'mkd-core')
                    ),
                    array(
                        'type' => 'dropdown',
                        'class' => '',
                        'heading' => esc_html__('Layout', 'mkd-core'),
                        'param_name' => 'layout',
                        'value' => array(
                            esc_html__('Accordion', 'mkd-core') => 'accordion',
                            esc_html__('Toggle', 'mkd-core') => 'toggle',
                        ),
                        'save_always' => true,
                        'description' => ''
                    ),
                    array(
                        'type' => 'colorpicker',
                        'heading' => esc_html__('Title area hover state color', 'mkd-core'),
                        'param_name' => 'title_active_color'
                    ),
                    array(
                        'type' => 'colorpicker',
                        'heading' => esc_html__('Content area background color', 'mkd-core'),
                        'param_name' => 'content_background_color'
                    )
                )
            ));
        }
    }

    public function render($atts, $content = null) {
        $default_atts = (array(
            'title' => '',
            'layout' => 'accordion',
            'type' => 'boxed',
            'title_active_color' => '',
            'content_background_color' => '',
            'skin' => '',
        ));

        $params = shortcode_atts($default_atts, $atts);
        extract($params);

        $params['accordion_classes'] = $this->getAccordionClasses($params);
        $params['accordion_data'] = $this->getAccordionData($params);
        $params['content'] = $content;

        $output = '';

        $output .= mikado_core_get_core_shortcode_template_part('templates/accordion-holder', 'accordions', '', $params);

        return $output;
    }

    /**
     * Generates accordion classes
     *
     * @param $params
     *
     * @return string
     */
    private function getAccordionClasses($params) {

        $accordion_classes = array(
            'mkd-' . $params['layout'],
            'mkd-' . $params['type'],
        );

        if ($params['skin'] !== '') {
            switch ($params['skin']) {
                case 'light':
                    $accordion_classes[] = 'mkd-light';
                    break;
                case 'dark':
                    $accordion_classes[] = 'mkd-dark';
                    break;
            }
        }

        $accordion_classes = implode(' ', $accordion_classes);

        return $accordion_classes;
    }


    /**
     * Generates accordion data
     *
     * @param $params
     *
     * @return string
     */
    private function getAccordionData($params) {

        $accordion_data = array();

        $accordion_data[] = ($params['title_active_color'] !== '') ? 'data-title_active_color=' . $params['title_active_color'] : '';

        $accordion_data = implode(' ', $accordion_data);

        return $accordion_data;
    }
}
