<?php

namespace Sparks\Modules\Shortcodes\ContentSlider;

use Sparks\Modules\Shortcodes\Lib\ShortcodeInterface;

/**
 * class Content Slider
 */
class ContentSlider implements ShortcodeInterface
{
    /**
     * @var string
     */
    private $base;

    function __construct() {
        $this->base = 'mkd_content_slider';
        add_action('vc_before_init', array($this, 'vcMap'));
    }

    public function getBase() {
        return $this->base;
    }

    public function vcMap() {
        if (function_exists('vc_map')) {
            vc_map(array(
                'name' => esc_html__('Content Slider Item', 'mkd-core'),
                'base' => $this->base,
                'icon' => 'icon-wpb-content-slider-item extended-custom-icon',
                'category' => esc_html__('by MIKADO', 'mkd-core'),
                'allowed_container_element' => 'vc_row',
                'as_child' => array('only' => 'mkd_content_slider_holder'),
                'params' => array(
                    array(
                        'type' => 'attach_image',
                        'admin_label' => true,
                        'heading' => esc_html__('Slide Image', 'mkd-core'),
                        'param_name' => 'image',
                        'value' => '',
                        'description' => esc_html__('Select image from media library.', 'mkd-core'),
                    ),
                    array(
                        'type' => 'dropdown',
                        'class' => '',
                        'heading' => esc_html__('Image Position', 'mkd-core'),
                        'param_name' => 'image_position',
                        'value' => array(
                            esc_html__('Left', 'mkd-core') => 'left',
                            esc_html__('Right', 'mkd-core') => 'right',
                        ),
                        'save_always' => true,
                        'description' => ''
                    ),
                    array(
                        'type' => 'colorpicker',
                        'heading' => esc_html__('Content Background', 'mkd-core'),
                        'param_name' => 'content_background',
                        'description' => '',
                    ),

                    array(
                        'type' => 'dropdown',
                        'heading' => esc_html__('Content Align', 'mkd-core'),
                        'param_name' => 'content_align',
                        'value' => array(
                            esc_html__('Left', 'mkd-core') => 'left',
                            esc_html__('Center', 'mkd-core') => 'center',
                            esc_html__('Right', 'mkd-core') => 'right'
                        ),
                        'save_always' => true,
                    ),
                    array(
                        'type' => 'textfield',
                        'heading' => esc_html__('Title', 'mkd-core'),
                        'param_name' => 'title',
                        'value' => '',
                        'save_always' => true,
                        'admin_label' => true
                    ),
                    array(
                        'type' => 'dropdown',
                        'heading' => esc_html__('Tag', 'mkd-core'),
                        'param_name' => 'title_tag',
                        'value' => array(
                            'h2' => 'h2',
                            'h3' => 'h3',
                            'h4' => 'h4',
                            'h5' => 'h5',
                            'h6' => 'h6'
                        ),
                        'save_always' => true,
                        'dependency' => array('element' => 'title', 'not_empty' => true)
                    ),
                    array(
                        'type' => 'dropdown',
                        'admin_label' => true,
                        'heading' => esc_html__('Enable Separator', 'mkd-core'),
                        'param_name' => 'enable_separator',
                        'value' => array(
                            esc_html__('Yes', 'mkd-core') => 'yes',
                            esc_html__('No', 'mkd-core') => 'no',
                        ),
                        'save_always' => true,
                        'description' => '',
                        'dependency' => array('element' => 'title', 'not_empty' => true)
                    ),
                    array(
                        'type' => 'textarea',
                        'heading' => esc_html__('Content', 'mkd-core'),
                        'param_name' => 'text',
                    ),
                    array(
                        'type' => 'dropdown',
                        'heading' => esc_html__('Show Button', 'mkd-core'),
                        'param_name' => 'show_button',
                        'value' => array(
                            esc_html__('Yes', 'mkd-core') => 'yes',
                            esc_html__('No', 'mkd-core') => 'no'
                        ),
                        'admin_label' => true,
                        'save_always' => true,
                        'description' => ''
                    ),
                    array(
                        'type' => 'dropdown',
                        'heading' => esc_html__('Button Hover Animation', 'mkd-core'),
                        'param_name' => 'button_hover_animation',
                        'value' => array(
                            esc_html__('Yes', 'mkd-core') => 'yes',
                            esc_html__('No', 'mkd-core') => 'no'
                        ),
                        'save_always' => true,
                        'admin_label' => true,
                        'dependency' => array('element' => 'show_button', 'value' => array('yes')),
                    ),
                    array(
                        'type' => 'textfield',
                        'heading' => esc_html__('Button Text', 'mkd-core'),
                        'param_name' => 'button_text',
                        'value' => '',
                        'save_always' => true,
                        'dependency' => array('element' => 'show_button', 'value' => array('yes')),
                    ),
                    array(
                        'type' => 'textfield',
                        'heading' => esc_html__('Button Link', 'mkd-core'),
                        'param_name' => 'button_link',
                        'value' => '',
                        'save_always' => true,
                        'dependency' => array('element' => 'button_text', 'not_empty' => true)
                    ),
                    array(
                        'type' => 'dropdown',
                        'heading' => esc_html__('Button Target', 'mkd-core'),
                        'param_name' => 'button_target',
                        'value' => array(
                            esc_html__('Same Window', 'mkd-core') => '_self',
                            esc_html__('New Window', 'mkd-core') => '_blank'
                        ),
                        'save_always' => true,
                        'dependency' => array('element' => 'button_link', 'not_empty' => true)
                    ),
                    array(
                        'type' => 'dropdown',
                        'heading' => esc_html__('Button Size', 'mkd-core'),
                        'param_name' => 'button_size',
                        'value' => array(
                            esc_html__('Small', 'mkd-core') => 'small',
                            esc_html__('Medium', 'mkd-core') => 'medium',
                            esc_html__('Large', 'mkd-core') => 'large',
                        ),
                        'description' => '',
                        'save_always' => true,
                        'dependency' => array('element' => 'button_link', 'not_empty' => true),
                    ),
                )
            ));
        }
    }

    public function render($atts, $content = null) {
        $args = array(
            'image' => '',
            'image_position' => '',
            'title' => '',
            'title_tag' => 'h2',
            'enable_separator' => 'no',
            'text' => '',
            'content_background' => '',
            'content_align' => 'left',
            'show_button' => 'yes',
            'button_hover_animation' => 'yes',
            'button_text' => '',
            'button_link' => '',
            'button_target' => '',
            'button_size' => '',
        );

        $params = shortcode_atts($args, $atts);

        // extract params for use in method
        extract($params);

        $params['content_style'] = $this->getContentStyle($params);
        $params['separator_params'] = $this->getSeparatorParams($params);
        $params['button_params'] = $this->getButtonParams($params);

        $output = '';

        $output .= mikado_core_get_core_shortcode_template_part('templates/content-slider', 'content-slider', '', $params);

        return $output;
    }

    private function getButtonParams($params) {
        $button_params = array();

        if (!empty($params['button_hover_animation'])) {
            $button_params['hover_animation'] = $params['button_hover_animation'];
        }

        if (!empty($params['button_link'])) {
            $button_params['link'] = $params['button_link'];
        }

        if (!empty($params['button_size'])) {
            $button_params['size'] = $params['button_size'];
        }

        if (!empty($params['button_target'])) {
            $button_params['target'] = $params['button_target'];
        }

        if (!empty($params['button_text'])) {
            $button_params['text'] = $params['button_text'];
        }

        $button_params['type'] = 'solid';

        return $button_params;
    }


    /*
     * Return args for separator shortcode
     *
     * @params $params
     * @return array
    */
    private function getSeparatorParams($params) {
        $separator_styles = array();

        if ($params['content_align'] !== '') {
            $separator_styles['position'] = $params['content_align'];
        }

        /*$separator_styles['width'] = '40';
        $separator_styles['thickness'] = '2';*/
        $separator_styles['top_margin'] = '0';
        $separator_styles['bottom_margin'] = '30';

        return $separator_styles;
    }

    private function getContentStyle($params) {

        $content_style = array();

        if (!empty($params['content_background'])) {
            $content_style[] = 'background-color: ' . $params['content_background'];
        }

        if (!empty($params['content_align'])) {
            $content_style[] = 'text-align:' . $params['content_align'];
        }

        return implode(';', $content_style);
    }
}