<?php
namespace Sparks\Modules\Shortcodes\IntroSection;

use Sparks\Modules\Shortcodes\Lib\ShortcodeInterface;

class IntroSection implements ShortcodeInterface
{
    private $base;

    public function __construct() {
        $this->base = 'mkd_intro_section';

        add_action('vc_before_init', array($this, 'vcMap'));
    }

    public function getBase() {
        return $this->base;
    }

    public function vcMap() {
        vc_map(array(
            'name' => esc_html__('Intro Section', 'mkd-core'),
            'base' => $this->base,
            'category' => esc_html__('by MIKADO', 'mkd-core'),
            'icon' => 'icon-wpb-intro-section extended-custom-icon',
            'allowed_container_element' => 'vc_row',
            'params' => array(
                array(
                    'type' => 'attach_image',
                    'heading' => esc_html__('Logo', 'mkd-core'),
                    'param_name' => 'logo',
                    'value' => '',
                    'save_always' => true,
                ),
                array(
                    'type' => 'textfield',
                    'heading' => esc_html__('Title', 'mkd-core'),
                    'param_name' => 'title',
                    'value' => '',
                    'save_always' => true,
                    'admin_label' => true
                ),
                array(
                    'type' => 'dropdown',
                    'heading' => esc_html__('Tag', 'mkd-core'),
                    'param_name' => 'title_tag',
                    'value' => array(
                        'h2' => 'h2',
                        'h3' => 'h3',
                        'h4' => 'h4',
                        'h5' => 'h5',
                        'h6' => 'h6'
                    ),
                    'save_always' => true,
                    'dependency' => array('element' => 'title', 'not_empty' => true)
                ),
                array(
                    'type' => 'dropdown',
                    'admin_label' => true,
                    'heading' => esc_html__('Enable Separator', 'mkd-core'),
                    'param_name' => 'enable_separator',
                    'value' => array(
                        esc_html__('Yes', 'mkd-core') => 'yes',
                        esc_html__('No', 'mkd-core') => 'no',
                    ),
                    'save_always' => true,
                    'description' => '',
                    'dependency' => array('element' => 'title', 'not_empty' => true)
                ),
                array(
                    'type' => 'textarea',
                    'heading' => esc_html__('Description', 'mkd-core'),
                    'param_name' => 'description',
                    'value' => '',
                    'save_always' => true,
                    'admin_label' => true,
                ),
                array(
                    'type' => 'textfield',
                    'heading' => esc_html__('Button Text', 'mkd-core'),
                    'param_name' => 'button_text',
                    'value' => '',
                    'save_always' => true,
                ),
                array(
                    'type' => 'textfield',
                    'heading' => esc_html__('Button Link', 'mkd-core'),
                    'param_name' => 'button_link',
                    'value' => '',
                    'save_always' => true,
                    'dependency' => array('element' => 'button_text', 'not_empty' => true)
                ),
                array(
                    'type' => 'dropdown',
                    'heading' => esc_html__('Button Target', 'mkd-core'),
                    'param_name' => 'button_target',
                    'value' => array(
                        esc_html__('Same Window', 'mkd-core') => '_self',
                        esc_html__('New Window', 'mkd-core') => '_blank'
                    ),
                    'save_always' => true,
                    'dependency' => array('element' => 'button_link', 'not_empty' => true)
                ),
                array(
                    'type' => 'attach_image',
                    'heading' => esc_html__('Hero Image', 'mkd-core'),
                    'param_name' => 'hero_image',
                    'value' => '',
                    'save_always' => true,
                    'group' => esc_html__('Cascading Images', 'mkd-core')
                ),
                array(
                    'type' => 'textfield',
                    'heading' => esc_html__('Hero Image Height', 'mkd-core'),
                    'param_name' => 'height',
                    'value' => '',
                    'dependency' => array('element' => 'hero_image', 'not_empty' => true),
                    'group' => esc_html__('Cascading Images', 'mkd-core')
                ),
                array(
                    'type' => 'dropdown',
                    'heading' => esc_html__('Hero image proportions', 'mkd-core'),
                    'param_name' => 'proportion',
                    'value' => array(
                        esc_html__('Portrait', 'mkd-core') => 'portrait',
                        esc_html__('Landscape', 'mkd-core') => 'landscape',
                        esc_html__('Square', 'mkd-core') => 'square',
                    ),
                    'std' => 'portrait',
                    'save_always' => true,
                    'admin_label' => true,
                    'group' => esc_html__('Cascading Images', 'mkd-core'),
                    'dependency' => array('element' => 'hero_image', 'not_empty' => true),
                ),
                array(
                    'type' => 'attach_image',
                    'heading' => esc_html__('Additional Image 1', 'mkd-core'),
                    'param_name' => 'additional_image_1',
                    'value' => '',
                    'save_always' => true,
                    'description' => esc_html__('Image to the left of the hero image.', 'mkd-core'),
                    'group' => esc_html__('Cascading Images', 'mkd-core')
                ),
                array(
                    'type' => 'attach_image',
                    'heading' => esc_html__('Additional Image 2', 'mkd-core'),
                    'param_name' => 'additional_image_2',
                    'value' => '',
                    'save_always' => true,
                    'description' => esc_html__('Image to the right of the hero image.', 'mkd-core'),
                    'group' => esc_html__('Cascading Images', 'mkd-core')
                ),
                array(
                    'type' => 'attach_image',
                    'heading' => esc_html__('Additional Image 3', 'mkd-core'),
                    'param_name' => 'additional_image_3',
                    'value' => '',
                    'save_always' => true,
                    'description' => esc_html__('Image to the far left.', 'mkd-core'),
                    'group' => esc_html__('Cascading Images', 'mkd-core')
                ),
                array(
                    'type' => 'attach_image',
                    'heading' => esc_html__('Additional Image 4', 'mkd-core'),
                    'param_name' => 'additional_image_4',
                    'value' => '',
                    'save_always' => true,
                    'description' => esc_html__('Image to the far right.', 'mkd-core'),
                    'group' => esc_html__('Cascading Images', 'mkd-core')
                ),
                array(
                    'type' => 'colorpicker',
                    'heading' => esc_html__('Title Color', 'mkd-core'),
                    'param_name' => 'title_color',
                    'value' => '',
                    'save_always' => true,
                    'group' => esc_html__('Design Options', 'mkd-core')
                ),
                array(
                    'type' => 'colorpicker',
                    'heading' => esc_html__('Description Color', 'mkd-core'),
                    'param_name' => 'description_color',
                    'value' => '',
                    'save_always' => true,
                    'group' => esc_html__('Design Options', 'mkd-core')
                ),
                array(
                    'type' => 'colorpicker',
                    'heading' => esc_html__('Background Color', 'mkd-core'),
                    'param_name' => 'background_color',
                    'value' => '',
                    'save_always' => true,
                    'group' => esc_html__('Design Options', 'mkd-core')
                ),
                array(
                    'type' => 'dropdown',
                    'heading' => esc_html__('Button Type', 'mkd-core'),
                    'param_name' => 'button_type',
                    'value' => array(
                        esc_html__('Solid', 'mkd-core') => 'solid',
                        esc_html__('Outline', 'mkd-core') => 'outline',
                        esc_html__('Transparent', 'mkd-core') => 'transparent'
                    ),
                    'save_always' => true,
                    'dependency' => array('element' => 'button_link', 'not_empty' => true),
                    'group' => esc_html__('Design Options', 'mkd-core')
                ),
                array(
                    'type' => 'colorpicker',
                    'heading' => esc_html__('Button Hover Background Color', 'mkd-core'),
                    'param_name' => 'button_hover_bg_color',
                    'value' => '',
                    'save_always' => true,
                    'group' => esc_html__('Design Options', 'mkd-core'),
                    'dependency' => array('element' => 'button_link', 'not_empty' => true)
                ),
                array(
                    'type' => 'colorpicker',
                    'heading' => esc_html__('Button Hover Text Color', 'mkd-core'),
                    'param_name' => 'button_hover_color',
                    'value' => '',
                    'save_always' => true,
                    'group' => esc_html__('Design Options', 'mkd-core'),
                    'dependency' => array('element' => 'button_link', 'not_empty' => true)
                ),
                array(
                    'type' => 'colorpicker',
                    'heading' => esc_html__('Button Hover Border Color', 'mkd-core'),
                    'param_name' => 'button_hover_border_color',
                    'value' => '',
                    'save_always' => true,
                    'group' => esc_html__('Design Options', 'mkd-core'),
                    'dependency' => array('element' => 'button_link', 'not_empty' => true)
                ),
                array(
                    'type' => 'dropdown',
                    'heading' => esc_html__('Animate Images', 'mkd-core'),
                    'param_name' => 'animate_images',
                    'value' => array(
                        esc_html__('Yes', 'mkd-core') => 'yes',
                        esc_html__('No', 'mkd-core') => 'no'
                    ),
                    'save_always' => true,
                    'admin_label' => true,
                    'description' => '',
                    'group' => esc_html__('Advanced Options', 'mkd-core'),
                    'dependency' => array('element' => 'hero_image', 'not_empty' => true),
                ),
                array(
                    'type' => 'dropdown',
                    'heading' => esc_html__('One Scroll Hide', 'mkd-core'),
                    'param_name' => 'one_scroll_hide',
                    'value' => array(
                        esc_html__('Yes', 'mkd-core') => 'yes',
                        esc_html__('No', 'mkd-core') => 'no'
                    ),
                    'std' => 'no',
                    'save_always' => true,
                    'admin_label' => true,
                    'description' => esc_html__('This feature requires that Intro Section shortcode is placed as your first element on the page.', 'mkd-core'),
                    'group' => esc_html__('Advanced Options', 'mkd-core'),
                    'dependency' => array('element' => 'hero_image', 'not_empty' => true),
                ),
            )
        ));
    }

    public function render($atts, $content = null) {
        $defaultAtts = array(
            'logo' => '',
            'title' => '',
            'title_tag' => 'h2',
            'title_color' => '',
            'enable_separator' => 'no',
            'description' => '',
            'description_color' => '',
            'button_text' => '',
            'button_link' => '',
            'button_target' => '',
            'button_type' => 'solid',
            'background_color' => '',
            'button_hover_bg_color' => '',
            'button_hover_color' => '',
            'button_hover_border_color' => '',
            'hero_image' => '',
            'height' => '400',
            'proportion' => 'portrait',
            'additional_image_1' => '',
            'additional_image_2' => '',
            'additional_image_3' => '',
            'additional_image_4' => '',
            'animate_images' => 'yes',
            'one_scroll_hide' => 'yes',
        );

        $params = shortcode_atts($defaultAtts, $atts);

        $params['holder_classes'] = $this->getHolderClasses($params);
        $params['holder_styles'] = $this->getHolderStyles($params);
        $params['title_styles'] = $this->getTitleStyles($params);
        $params['title_tag'] = $this->getTitleTag($params, $defaultAtts);
        $params['description_styles'] = $this->getDescriptionStyles($params);
        $params['button_params'] = $this->getButtonParams($params);
        $params['separator_params'] = $this->getSeparatorParams($params);
        $params['data'] = $this->getDataAttribute($params);

        return mikado_core_get_core_shortcode_template_part('templates/intro-section', 'intro-section', '', $params);
    }


    /*
     * create data attribute for inline print in html
     *
     * @return string
     */
    private function getDataAttribute($params) {
        $data = array();

        if ($params['height'] !== '') {
            $data['height'] = 'data-height=' . $params['height'];
        }

        if ($params['proportion'] !== '') {
            $data['proportion'] = 'data-proportion=' . $params['proportion'];
        }

        return implode(' ', $data);
    }

    /**
     * Return Title Tag. If provided heading isn't valid get the default one
     *
     * @param $params
     * @return string
     */
    private function getTitleTag($params, $args) {

        $tag_array = array('h2', 'h3', 'h4', 'h5', 'h6');

        return (in_array($params['title_tag'], $tag_array)) ? $params['title_tag'] : $args['title_tag'];
    }


    /*
     * Return args for separator shortcode
     *
     * @params $params
     * @return array
     */

    private function getSeparatorParams($params) {
        $separator_styles = array();

        /*$separator_styles['width'] = '40';
        $separator_styles['thickness'] = '2';*/
        $separator_styles['top_margin'] = '0';
        $separator_styles['bottom_margin'] = '30';

        return $separator_styles;
    }


    /**
     * Return holder classes
     *
     */
    private function getHolderClasses($params) {
        $classes = array();

        $classes[] = 'mkd-intro-section';

        if ($params['animate_images'] == 'yes') {
            $classes[] = 'mkd-intro-animate-images';
        }

        if ($params['one_scroll_hide'] == 'yes') {
            $classes[] = 'mkd-intro-one-scroll-hide';
        }

        return $classes;
    }


    /**
     * Return holder styles
     *
     */
    private function getHolderStyles($params) {
        $styles = array();

        if ($params['background_color'] !== '') {
            $styles[] = 'background-color: ' . $params['background_color'];
        }

        return $styles;
    }

    /**
     * Return title styles
     *
     */
    private function getTitleStyles($params) {
        $styles = array();

        if ($params['title_color'] !== '') {
            $styles[] = 'color: ' . $params['title_color'];
        }

        return $styles;
    }

    /**
     * Return title styles
     *
     */
    private function getDescriptionStyles($params) {
        $styles = array();

        if ($params['description_color'] !== '') {
            $styles[] = 'color: ' . $params['description_color'];
        }

        return $styles;
    }


    /**
     * Return button data params
     *
     */
    private function getButtonParams($params) {
        $button_params = array();

        if (!empty($params['button_link'])) {
            $button_params['link'] = $params['button_link'];
        }

        if (!empty($params['button_text'])) {
            $button_params['text'] = $params['button_text'];
        }

        if (!empty($params['button_target'])) {
            $button_params['target'] = $params['button_target'];
        }

        if (!empty($params['button_type'])) {
            $button_params['type'] = $params['button_type'];
        }

        if (!empty($params['button_hover_bg_color'])) {
            $button_params['hover_background_color'] = $params['button_hover_bg_color'];
        }

        if (!empty($params['button_hover_color'])) {
            $button_params['hover_color'] = $params['button_hover_color'];
        }

        if (!empty($params['button_hover_border_color'])) {
            $button_params['hover_border_color'] = $params['button_hover_border_color'];
        }

        return $button_params;
    }

}