<?php
namespace Sparks\Modules\Shortcodes\PricingTableHolder;

use Sparks\Modules\Shortcodes\Lib\ShortcodeInterface;

class PricingTableHolder implements ShortcodeInterface
{
    private $base;

    function __construct() {
        $this->base = 'mkd_pricing_table_holder';
        add_action('vc_before_init', array($this, 'vcMap'));
    }

    public function getBase() {
        return $this->base;
    }

    public function vcMap() {

        if (function_exists('vc_map')) {
            vc_map(array(
                'name' => esc_html__('Pricing Table', 'mkd-core'),
                'base' => $this->base,
                'as_parent' => array('only' => 'mkd_pricing_table'),
                'content_element' => true,
                'category' => esc_html__('by MIKADO', 'mkd-core'),
                'icon' => 'icon-wpb-pricing-table-holder extended-custom-icon',
                'show_settings_on_create' => true,
                'js_view' => 'VcColumnView',
                'params' => array(
                    array(
                        'type' => 'dropdown',
                        'class' => '',
                        'heading' => esc_html__('Columns', 'mkd-core'),
                        'param_name' => 'columns',
                        'value' => array(
                            esc_html__('Two', 'mkd-core') => 'mkd-two-columns',
                            esc_html__('Three', 'mkd-core') => 'mkd-three-columns',
                            esc_html__('Four', 'mkd-core') => 'mkd-four-columns',
                        ),
                        'save_always' => true,
                        'description' => ''
                    ),
                    array(
                        'type' => 'dropdown',
                        'class' => '',
                        'heading' => esc_html__('Layout', 'mkd-core'),
                        'param_name' => 'layout',
                        'value' => array(
                            esc_html__('Equal size', 'mkd-core') => '',
                            esc_html__('Larger active', 'mkd-core') => 'mkd-larger-active',
                        ),
                        'save_always' => true,
                        'description' => ''
                    ),
                    array(
                        'type' => 'dropdown',
                        'class' => '',
                        'heading' => esc_html__('Skin', 'mkd-core'),
                        'param_name' => 'skin',
                        'value' => array(
                            esc_html__('Default', 'mkd-core') => '',
                            esc_html__('Light', 'mkd-core') => 'light',
                            esc_html__('Dark', 'mkd-core') => 'dark',
                        ),
                        'save_always' => true,
                        'description' => ''
                    ),

                ),
            ));
        }
    }

    public function render($atts, $content = null) {
        $args = array(
            'columns' => 'mkd-two-columns',
            'layout' => '',
            'skin' => '',
        );

        $params = shortcode_atts($args, $atts);
        extract($params);

        $params['pricing_tables_classes'] = $this->getPricingTablesClasses($params);

        $html = '<div class="mkd-pricing-tables clearfix ' . $params['pricing_tables_classes'] . '">';
        $html .= do_shortcode($content);
        $html .= '</div>';

        return $html;
    }

    /**
     * Returns array of pricing tables classes
     *
     * @param $params
     *
     * @return string
     */
    private function getPricingTablesClasses($params) {
        $pricing_tables_classes = array();

        $pricing_tables_classes[] = $params['columns'];
        if (!empty($params['layout'])) {
            $pricing_tables_classes[] = $params['layout'];
        }
        if (!empty($params['skin'])) {
            $pricing_tables_classes[] = $params['skin'];
        }

        $pricing_tables_classes[] = '';

        return implode(' ', $pricing_tables_classes);
    }
}