<?php

namespace Sparks\Modules\Shortcodes\ProductListCarousel;

use Sparks\Modules\Shortcodes\Lib\ShortcodeInterface;


/**
 * Class ProductListCarousel
 */
class ProductListCarousel implements ShortcodeInterface
{
    /**
     * @var string
     */
    private $base;

    function __construct() {
        $this->base = 'mkd_product_list_carousel';

        add_action('vc_before_init', array($this, 'vcMap'));
    }

    public function getBase() {
        return $this->base;
    }

    public function vcMap() {
        vc_map(array(
            'name' => esc_html__('Product List Carousel', 'mkd-core'),
            'base' => $this->base,
            'icon' => 'icon-wpb-product-list-carousel extended-custom-icon',
            'category' => esc_html__('by MIKADO', 'mkd-core'),
            'allowed_container_element' => 'vc_row',
            'params' => array(
                array(
                    'type' => 'dropdown',
                    'param_name' => 'type',
                    'heading' => esc_html__('Type', 'mkd-core'),
                    'value' => array(
                        esc_html__('Standard', 'mkd-core') => 'standard',
                        esc_html__('Simple', 'mkd-core') => 'simple'
                    )
                ),
                array(
                    'type' => 'textfield',
                    'param_name' => 'number_of_posts',
                    'heading' => esc_html__('Number of Products', 'mkd-core')
                ),
                array(
                    'type' => 'dropdown',
                    'heading' => esc_html__('Number of Visible Items', 'mkd-core'),
                    'param_name' => 'number_of_visible_items',
                    'value' => array(
                        esc_html__('One', 'mkd-core') => '1',
                        esc_html__('Two', 'mkd-core') => '2',
                        esc_html__('Three', 'mkd-core') => '3',
                        esc_html__('Four', 'mkd-core') => '4',
                        esc_html__('Five', 'mkd-core') => '5'
                    ),
                    'save_always' => true,
                    'std' => '3',
                ),
                array(
                    'type' => 'dropdown',
                    'param_name' => 'space_between_items',
                    'heading' => esc_html__('Space Between Items', 'mkd-core'),
                    'value' => array(
                        esc_html__('Normal', 'mkd-core') => 'normal',
                        esc_html__('Small', 'mkd-core') => 'small',
                        esc_html__('Tiny', 'mkd-core') => 'tiny',
                        esc_html__('No Space', 'mkd-core') => 'no'
                    ),
                    'dependency' => array('element' => 'type', 'value' => array('standard'))
                ),
                array(
                    'type' => 'dropdown',
                    'param_name' => 'order_by',
                    'heading' => esc_html__('Order By', 'mkd-core'),
                    'value' => array(
                        esc_html__('Title', 'mkd-core') => 'title',
                        esc_html__('Date', 'mkd-core') => 'date',
                        esc_html__('Random', 'mkd-core') => 'rand',
                        esc_html__('Post Name', 'mkd-core') => 'name',
                        esc_html__('ID', 'mkd-core') => 'id',
                        esc_html__('Menu Order', 'mkd-core') => 'menu_order'
                    )
                ),
                array(
                    'type' => 'dropdown',
                    'param_name' => 'order',
                    'heading' => esc_html__('Order', 'mkd-core'),
                    'value' => array(
                        esc_html__('ASC', 'mkd-core') => 'ASC',
                        esc_html__('DESC', 'mkd-core') => 'DESC'
                    )
                ),
                array(
                    'type' => 'dropdown',
                    'param_name' => 'taxonomy_to_display',
                    'heading' => esc_html__('Choose Sorting Taxonomy', 'mkd-core'),
                    'value' => array(
                        esc_html__('Category', 'mkd-core') => 'category',
                        esc_html__('Tag', 'mkd-core') => 'tag',
                        esc_html__('Id', 'mkd-core') => 'id'
                    ),
                    'description' => esc_html__('If you would like to display only certain products, this is where you can select the criteria by which you would like to choose which products to display', 'mkd-core')
                ),
                array(
                    'type' => 'textfield',
                    'param_name' => 'taxonomy_values',
                    'heading' => esc_html__('Enter Taxonomy Values', 'mkd-core'),
                    'description' => esc_html__('Separate values (category slugs, tags, or post IDs) with a comma', 'mkd-core')
                ),
                array(
                    'type' => 'dropdown',
                    'heading' => esc_html__('Image Proportions', 'mkd-core'),
                    'param_name' => 'image_size',
                    'value' => array(
                        esc_html__('Default', 'mkd-core') => '',
                        esc_html__('Original', 'mkd-core') => 'full',
                        esc_html__('Square', 'mkd-core') => 'square',
                        esc_html__('Landscape', 'mkd-core') => 'landscape',
                        esc_html__('Portrait', 'mkd-core') => 'portrait',
                        esc_html__('Medium', 'mkd-core') => 'medium',
                        esc_html__('Large', 'mkd-core') => 'large'
                    ),
                    'save_always' => true
                ),
                array(
                    'type' => 'dropdown',
                    'param_name' => 'display_title',
                    'heading' => esc_html__('Display Title', 'mkd-core'),
                    'value' => array(
                        esc_html__('Yes', 'mkd-core') => 'yes',
                        esc_html__('No', 'mkd-core') => 'no'
                    ),
                    'save_always' => true,
                    'group' => esc_html__('Product Info', 'mkd-core')
                ),
                array(
                    'type' => 'dropdown',
                    'param_name' => 'title_tag',
                    'heading' => esc_html__('Title Tag', 'mkd-core'),
                    'value' => array(
                        '' => '',
                        'h2' => 'h2',
                        'h3' => 'h3',
                        'h4' => 'h4',
                        'h5' => 'h5',
                        'h6' => 'h6',
                    ),
                    'save_always' => true,
                    'dependency' => array('element' => 'display_title', 'value' => array('yes')),
                    'group' => esc_html__('Product Info Style', 'mkd-core')
                ),
                array(
                    'type' => 'dropdown',
                    'param_name' => 'title_transform',
                    'heading' => esc_html__('Title Text Transform', 'mkd-core'),
                    'value' => array_flip(sparks_mikado_get_text_transform_array(true)),
                    'save_always' => true,
                    'dependency' => array(
                        'element' => 'display_title',
                        'value' => array('yes')
                    ),
                    'group' => esc_html__('Product Info Style', 'mkd-core')
                ),
                array(
                    'type' => 'dropdown',
                    'param_name' => 'display_category',
                    'heading' => esc_html__('Display Category', 'mkd-core'),
                    'value' => array(
                        esc_html__('Yes', 'mkd-core') => 'yes',
                        esc_html__('No', 'mkd-core') => 'no'
                    ),
                    'save_always' => true,
                    'group' => esc_html__('Product Info', 'mkd-core')
                ),
                array(
                    'type' => 'dropdown',
                    'param_name' => 'display_excerpt',
                    'heading' => esc_html__('Display Excerpt', 'mkd-core'),
                    'value' => array(
                        esc_html__('Yes', 'mkd-core') => 'yes',
                        esc_html__('No', 'mkd-core') => 'no'
                    ),
                    'save_always' => true,
                    'group' => esc_html__('Product Info', 'mkd-core')
                ),
                array(
                    'type' => 'textfield',
                    'param_name' => 'excerpt_length',
                    'heading' => esc_html__('Excerpt Length', 'mkd-core'),
                    'description' => esc_html__('Number of characters', 'mkd-core'),
                    'dependency' => array(
                        'element' => 'display_excerpt',
                        'value' => array('yes')
                    ),
                    'save_always' => true,
                    'group' => esc_html__('Product Info Style', 'mkd-core')
                ),
                array(
                    'type' => 'dropdown',
                    'param_name' => 'display_rating',
                    'heading' => esc_html__('Display Rating', 'mkd-core'),
                    'value' => array(
                        esc_html__('Yes', 'mkd-core') => 'yes',
                        esc_html__('No', 'mkd-core') => 'no'
                    ),
                    'save_always' => true,
                    'group' => esc_html__('Product Info', 'mkd-core')
                ),
                array(
                    'type' => 'dropdown',
                    'param_name' => 'display_price',
                    'heading' => esc_html__('Display Price', 'mkd-core'),
                    'value' => array(
                        esc_html__('Yes', 'mkd-core') => 'yes',
                        esc_html__('No', 'mkd-core') => 'no'
                    ),
                    'save_always' => true,
                    'group' => esc_html__('Product Info', 'mkd-core')
                ),
                array(
                    'type' => 'dropdown',
                    'param_name' => 'display_button',
                    'heading' => esc_html__('Display Button', 'mkd-core'),
                    'value' => array(
                        esc_html__('Yes', 'mkd-core') => 'yes',
                        esc_html__('No', 'mkd-core') => 'no'
                    ),
                    'save_always' => true,
                    'group' => esc_html__('Product Info', 'mkd-core')
                ),
                array(
                    'type' => 'dropdown',
                    'param_name' => 'button_skin',
                    'heading' => esc_html__('Button Skin', 'mkd-core'),
                    'value' => array(
                        esc_html__('Default', 'mkd-core') => 'default',
                        esc_html__('Light', 'mkd-core') => 'light',
                        esc_html__('Dark', 'mkd-core') => 'dark'
                    ),
                    'dependency' => array(
                        'element' => 'display_button',
                        'value' => array('yes')
                    ),
                    'save_always' => true,
                    'group' => esc_html__('Product Info Style', 'mkd-core')
                ),
                array(
                    'type' => 'colorpicker',
                    'param_name' => 'shader_background_color',
                    'heading' => esc_html__('Shader Background Color', 'mkd-core'),
                    'group' => esc_html__('Product Info Style', 'mkd-core')
                ),
                array(
                    'type' => 'dropdown',
                    'heading' => esc_html__('Slide duration', 'mkd-core'),
                    'admin_label' => true,
                    'param_name' => 'autoplay',
                    'value' => array(
                        esc_html__('3', 'mkd-core') => '3',
                        esc_html__('5', 'mkd-core') => '5',
                        esc_html__('10', 'mkd-core') => '10',
                        esc_html__('Disable', 'mkd-core') => 'disable'
                    ),
                    'save_always' => true,
                    'description' => esc_html__('Auto rotate slides each X seconds', 'mkd-core'),
                    'group' => esc_html__('Slider', 'mkd-core'),
                ),
                array(
                    'type' => 'dropdown',
                    'heading' => esc_html__('Pause on hover', 'mkd-core'),
                    'param_name' => 'pause',
                    'value' => array(
                        esc_html__('Yes', 'mkd-core') => 'yes',
                        esc_html__('No', 'mkd-core') => 'no'
                    ),
                    'save_always' => true,
                    'dependency' => array(
                        'element' => 'autoplay',
                        'value' => array(
                            '3', '5', '10'
                        )
                    ),
                    'group' => esc_html__('Slider', 'mkd-core'),
                ),
                array(
                    'type' => 'dropdown',
                    'heading' => esc_html__('Loop', 'mkd-core'),
                    'param_name' => 'loop',
                    'value' => array(
                        esc_html__('Yes', 'mkd-core') => 'yes',
                        esc_html__('No', 'mkd-core') => 'no'
                    ),
                    'save_always' => true,
                    'group' => esc_html__('Slider', 'mkd-core'),
                ),
                array(
                    'type' => 'dropdown',
                    'heading' => esc_html__('Show Navigation Arrows', 'mkd-core'),
                    'param_name' => 'navigation',
                    'value' => array(
                        esc_html__('Yes', 'mkd-core') => 'yes',
                        esc_html__('No', 'mkd-core') => 'no'
                    ),
                    'save_always' => true,
                    'group' => esc_html__('Slider', 'mkd-core'),
                ),
                array(
                    'type' => 'dropdown',
                    'heading' => esc_html__('Navigation Position', 'mkd-core'),
                    'param_name' => 'navigation_position',
                    'value' => array(
                        esc_html__('Inside', 'mkd-core') => 'inside',
                        esc_html__('Outside', 'mkd-core') => 'outside'
                    ),
                    'std' => 'inside',
                    'save_always' => true,
                    'dependency' => array(
                        'element' => 'navigation',
                        'value' => array(
                            'yes'
                        )
                    ),
                    'group' => esc_html__('Slider', 'mkd-core'),
                ),
                array(
                    'type' => 'dropdown',
                    'heading' => esc_html__('Show Pagination', 'mkd-core'),
                    'param_name' => 'pagination',
                    'value' => array(
                        esc_html__('Yes', 'mkd-core') => 'yes',
                        esc_html__('No', 'mkd-core') => 'no'
                    ),
                    'save_always' => true,
                    'group' => esc_html__('Slider', 'mkd-core'),
                ),
            )
        ));
    }

    public function render($atts, $content = null) {
        $default_atts = array(
            'type' => 'standard',
            'number_of_posts' => '5',
            'number_of_visible_items' => '3',
            'space_between_items' => 'normal',
            'order_by' => 'date',
            'order' => 'ASC',
            'taxonomy_to_display' => 'category',
            'taxonomy_values' => '',
            'image_size' => '',
            'display_title' => 'yes',
            'title_tag' => 'h4',
            'title_transform' => '',
            'display_category' => 'yes',
            'display_excerpt' => 'no',
            'excerpt_length' => '20',
            'display_rating' => 'yes',
            'display_price' => 'yes',
            'display_button' => 'yes',
            'button_skin' => 'default',
            'shader_background_color' => '',
            'autoplay' => '',
            'pause' => '',
            'loop' => '',
            'navigation' => '',
            'navigation_position' => '',
            'pagination' => '',
        );

        $params = shortcode_atts($default_atts, $atts);
        extract($params);

        $params['holder_classes'] = $this->getHolderClasses($params);
        $params['holder_inner_classes'] = $this->getHolderInnerClasses($params);
        $params['holder_data'] = $this->getProductListCarouselData($params);

        $params['title_tag'] = !empty($params['title_tag']) ? $params['title_tag'] : $default_atts['title_tag'];
        $params['title_styles'] = $this->getTitleStyles($params);

        $params['shader_styles'] = $this->getShaderStyles($params);

        $queryArray = $this->generateProductQueryArray($params);
        $query_result = new \WP_Query($queryArray);
        $params['query_result'] = $query_result;

        //$html = mikado_core_get_core_shortcode_template_part('templates/product-list-carousel', 'product-list-carousel', '', $params);

        if ($params['type'] === 'standard') {
            $html = mikado_core_get_core_shortcode_template_part('templates/standard', 'product-list-carousel', '', $params);
        } elseif ($params['type'] === 'simple') {
            $html = mikado_core_get_core_shortcode_template_part('templates/simple', 'product-list-carousel', '', $params);
        }

        return $html;
    }

    /**
     * Generates holder classes
     *
     * @param $params
     *
     * @return string
     */
    private function getHolderClasses($params) {
        $holder_classes = array();

        $holder_classes[] = $this->getCarouselTypeClass($params);

        $holder_classes[] = $this->getColumnsSpaceClass($params);

        $holder_classes[] = $this->getCarouselClasses($params);

        return implode(' ', $holder_classes);
    }

    /**
     * Generates holder inner classes
     *
     * @param $params
     *
     * @return string
     */
    private function getHolderInnerClasses($params) {
        $holder_inner_classes = array();

        $holder_inner_classes[] = ($params['navigation_position'] == 'inside') ? 'mkd-nav-inside' : '';

        return implode(' ', $holder_inner_classes);
    }

    /**
     * Generates carousel type classes for product list holder
     *
     * @param $params
     *
     * @return string
     */
    private function getCarouselTypeClass($params) {
        $carouselType = '';
        $type = $params['type'];

        switch ($type) {
            case 'standard':
                $carouselType = 'mkd-standard-type';
                break;
            case 'simple':
                $carouselType = 'mkd-simple-type';
                break;
            default:
                $carouselType = 'mkd-standard-type';
                break;
        }

        return $carouselType;
    }

    /**
     * Generates space between columns classes for product list holder
     *
     * @param $params
     *
     * @return string
     */
    private function getColumnsSpaceClass($params) {
        $columnsSpace = '';
        $spaceBetweenItems = $params['space_between_items'];

        switch ($spaceBetweenItems) {
            case 'normal':
                $columnsSpace = 'mkd-normal-space';
                break;
            case 'small':
                $columnsSpace = 'mkd-small-space';
                break;
            case 'tiny':
                $columnsSpace = 'mkd-tiny-space';
                break;
            case 'no':
                $columnsSpace = 'mkd-no-space';
                break;
            default:
                $columnsSpace = 'mkd-normal-space';
                break;
        }

        return $columnsSpace;
    }

    /**
     * Generates carousel classes for product list holder
     *
     * @param $params
     *
     * @return string
     */
    private function getCarouselClasses($params) {
        $carouselClasses = '';

        /*if (!empty($params['carousel_navigation_skin'])) {
            $carouselClasses .= ' mkd-plc-nav-' . $params['carousel_navigation_skin'] . '-skin';
        }

        if (!empty($params['carousel_pagination_pos'])) {
            $carouselClasses .= ' mkd-plc-pag-' . $params['carousel_pagination_pos'];
        }

        if ($params['carousel_pagination'] === 'yes' && $params['carousel_pagination_pos'] === 'bellow-slider') {
            $carouselClasses .= ' mkd-plc-pag-enabled';
        }

        if (!empty($params['carousel_pagination_skin'])) {
            $carouselClasses .= ' mkd-plc-pag-' . $params['carousel_pagination_skin'] . '-skin';
        }*/

        return $carouselClasses;
    }

    /**
     * Return all data that product list carousel needs
     *
     * @param $params
     * @return array
     */
    private function getProductListCarouselData($params) {
        $product_slider_data = array();

        $product_slider_data['data-number-of-visible-items'] = ($params['number_of_visible_items'] !== '') ? $params['number_of_visible_items'] : 1;
        $product_slider_data['data-autoplay'] = ($params['autoplay'] !== '') ? $params['autoplay'] : '';
        $product_slider_data['data-pause'] = ($params['pause'] != '') ? $params['pause'] : '';
        $product_slider_data['data-loop'] = ($params['loop'] !== '') ? $params['loop'] : '';
        $product_slider_data['data-navigation'] = ($params['navigation'] !== '') ? $params['navigation'] : '';
        $product_slider_data['data-pagination'] = ($params['pagination'] !== '') ? $params['pagination'] : '';

        return $product_slider_data;
    }

    /**
     * Generates query array
     *
     * @param $params
     *
     * @return array
     */
    public function generateProductQueryArray($params) {
        $queryArray = array(
            'post_status' => 'publish',
            'post_type' => 'product',
            'ignore_sticky_posts' => 1,
            'posts_per_page' => $params['number_of_posts'],
            'orderby' => $params['order_by'],
            'order' => $params['order'],
            'meta_query' => WC()->query->get_meta_query()
        );

        if ($params['taxonomy_to_display'] !== '' && $params['taxonomy_to_display'] === 'category') {
            $queryArray['product_cat'] = $params['taxonomy_values'];
        }

        if ($params['taxonomy_to_display'] !== '' && $params['taxonomy_to_display'] === 'tag') {
            $queryArray['product_tag'] = $params['taxonomy_values'];
        }

        if ($params['taxonomy_to_display'] !== '' && $params['taxonomy_to_display'] === 'id') {
            $idArray = $params['taxonomy_values'];
            $ids = explode(',', $idArray);
            $queryArray['post__in'] = $ids;
        }

        return $queryArray;
    }

    /**
     * Return Style for Title
     *
     * @param $params
     * @return string
     */
    private function getTitleStyles($params) {
        $styles = array();

        if ($params['title_transform'] !== '') {
            $styles[] = 'text-transform: ' . $params['title_transform'];
        }

        return implode(';', $styles);
    }

    /**
     * Return Style for Shader
     *
     * @param $params
     * @return string
     */
    private function getShaderStyles($params) {
        $styles = array();

        if ($params['shader_background_color'] !== '') {
            $styles[] = 'background-color: ' . $params['shader_background_color'];
        }

        return implode(';', $styles);
    }
}