<?php
if(!defined('ABSPATH')) exit;

class MikadoInstagramWidget extends WP_Widget {

	protected $params;

	public function __construct() {
		parent::__construct(
			'mikado_instagram_widget',
            esc_html__('Mikado Instagram Widget', 'mkd-instagram-feed'),
			array(
				'description' => esc_html__( 'Display your Instagram feed', 'mkd-instagram-feed')
			)
		);

		$this->setParams();
	}

	protected function setParams() {
		$this->params = array(
			array(
				'name' => 'title',
				'type' => 'textfield',
				'title' => esc_html__('Title', 'mkd-instagram-feed')
			),
			array(
				'name' => 'tag',
				'type' => 'textfield',
				'title' => esc_html__('Tag', 'mkd-instagram-feed')
			),
			array(
				'name'	=> 'type',
				'type'	=> 'dropdown',
				'title'	=> esc_html__('Type', 'mkd-instagram-feed'),
				'options' => array(
					'gallery' => esc_html__('Gallery', 'mkd-instagram-feed'),
					'carousel' => esc_html__('Carousel', 'mkd-instagram-feed')
				)
			),
			array(
				'name' => 'number_of_cols',
				'type' => 'dropdown',
				'title' => esc_html__('Number of Columns', 'mkd-instagram-feed'),
				'options' => array(
					'2' => esc_html__('Two', 'mkd-instagram-feed'),
					'3' => esc_html__('Three', 'mkd-instagram-feed'),
					'4' => esc_html__('Four', 'mkd-instagram-feed'),
					'6' => esc_html__('Six', 'mkd-instagram-feed'),
					'9' => esc_html__('Nine', 'mkd-instagram-feed')
				)
			),
			array(
				'name' => 'number_of_photos',
				'type' => 'textfield',
				'title' => esc_html__('Number of Photos', 'mkd-instagram-feed'),
			),
			array(
				'name' => 'image_size',
				'type' => 'dropdown',
				'title' => esc_html__('Image Size', 'mkd-instagram-feed'),
				'options' => array(
					'thumbnail' => esc_html__('Small', 'mkd-instagram-feed'),
					'low_resolution' => esc_html__('Medium', 'mkd-instagram-feed'),
					'standard_resolution' => esc_html__('Large', 'mkd-instagram-feed'),
				)
			),
			array(
				'name' => 'space_between_items',
				'type' => 'dropdown',
				'title' => esc_html__('Space Between Items', 'mkd-instagram-feed'),
				'options' => array(
					'normal' => esc_html__('Normal', 'mkd-instagram-feed'),
					'small' => esc_html__('Small', 'mkd-instagram-feed'),
					'tiny' => esc_html__('Tiny', 'mkd-instagram-feed'),
					'no' => esc_html__('No Space', 'mkd-instagram-feed')
				)
			),
			array(
				'name' => 'transient_time',
				'type' => 'textfield',
				'title' => esc_html__('Images Cache Time', 'mkd-instagram-feed')
			),
		);
	}
	public function getParams() {
		return $this->params;
	}

	public function widget($args, $instance) {
		extract($instance);

		echo sparks_mikado_get_module_part($args['before_widget']);
		if(!empty($title)) {
			echo sparks_mikado_get_module_part($args['before_title'].$title.$args['after_title']);
		}

		$instagram_api = MikadoInstagramApi::getInstance();
		$images_array = $instagram_api->getImages($number_of_photos, $tag, array(
			'use_transients' => true,
			'transient_name' => $args['widget_id'],
			'transient_time' => $transient_time
		));

		$type = !empty($type) ? $type : 'gallery';
		$number_of_cols = $number_of_cols == '' ? 3 : $number_of_cols;
		$space_between_items = !empty($space_between_items) ? $space_between_items : 'normal';

		$widget_class = '';
		$widget_data = '';

		if ($type === 'carousel') {
			$widget_class = 'mkd-instagram-carousel';
			$widget_data = ' data-items='.esc_attr($number_of_cols). ' data-space-between-items='.esc_attr($space_between_items);
		} else if ($type == 'gallery') {
			$widget_class = 'mkd-instagram-gallery mkd-'.esc_attr($space_between_items).'-space';
		}

		if(is_array($images_array) && count($images_array)) { ?>
			<ul class="mkd-instagram-feed clearfix mkd-col-<?php echo esc_attr($number_of_cols); ?> <?php echo esc_attr($widget_class);?>" <?php echo esc_attr($widget_data); ?>>
				<?php
				foreach ($images_array as $image) { ?>
					<li>
						<a href="<?php echo esc_url($instagram_api->getHelper()->getImageLink($image)); ?>" target="_blank">
							<?php echo sparks_mikado_kses_img($instagram_api->getHelper()->getImageHTML($image, $image_size)); ?>
						</a>
					</li>
				<?php } ?>
			</ul>
		<?php }

		echo sparks_mikado_get_module_part($args['after_widget']);
	}

	public function form($instance) {
		foreach ($this->params as $param_array) {
			$param_name = $param_array['name'];
			${$param_name} = isset( $instance[$param_name] ) ? esc_attr( $instance[$param_name] ) : '';
		}

		//user has connected with instagram. Show form
		if(get_option('mkd_instagram_code')) {
			foreach ($this->params as $param) {
				switch($param['type']) {
					case 'textfield':
						?>
						<p>
							<label for="<?php echo esc_attr($this->get_field_id( $param['name'] )); ?>"><?php echo
								esc_html($param['title']); ?></label>
							<input class="widefat" id="<?php echo esc_attr($this->get_field_id( $param['name'] )); ?>" name="<?php echo esc_attr($this->get_field_name( $param['name'] )); ?>" type="text" value="<?php echo esc_attr( ${$param['name']} ); ?>" />
						</p>
						<?php
						break;
					case 'dropdown':
						?>
						<p>
							<label for="<?php echo esc_attr($this->get_field_id( $param['name'] )); ?>"><?php echo
								esc_html($param['title']); ?></label>
							<?php if(isset($param['options']) && is_array($param['options']) && count($param['options'])) { ?>
								<select class="widefat" name="<?php echo esc_attr($this->get_field_name( $param['name'] )); ?>" id="<?php echo esc_attr($this->get_field_id( $param['name'] )); ?>">
									<?php foreach ($param['options'] as $param_option_key => $param_option_val) {
										$option_selected = '';
										if(${$param['name']} == $param_option_key) {
											$option_selected = 'selected';
										}
										?>
										<option <?php echo esc_attr($option_selected); ?> value="<?php echo esc_attr($param_option_key); ?>"><?php echo esc_attr($param_option_val); ?></option>
									<?php } ?>
								</select>
							<?php } ?>
						</p>

						<?php
						break;
				}
			}
		}
	}
}

function mikado_instagram_widget_load(){
	register_widget('MikadoInstagramWidget');
}

add_action('widgets_init', 'mikado_instagram_widget_load');