<?php
namespace Sparks\Modules\Shortcodes\AdvancedVerticalSliderHolder;

use Sparks\Modules\Shortcodes\Lib\ShortcodeInterface;

/**
 * Class AdvancedVerticalSliderHolder
 */
class AdvancedVerticalSliderHolder implements ShortcodeInterface
{

    /**
     * @var string
     */
    private $base;

    public function __construct() {
        $this->base = 'mkd_advanced_vertical_slider_holder';

        add_action('vc_before_init', array($this, 'vcMap'));
    }

    /**
     * Returns base for shortcode
     * @return string
     */
    public function getBase() {
        return $this->base;
    }

    /**
     * Maps shortcode to Visual Composer. Hooked on vc_before_init
     *
     * @see qode_core_get_carousel_slider_array_vc()
     */
    public function vcMap() {
        vc_map(array(
            'name' => esc_html__('Advanced Vertical Slider', 'mkd-core'),
            'base' => $this->getBase(),
            'category' => esc_html__('by MIKADO', 'mkd-core'),
            'icon' => 'icon-wpb-advanced-vertical-slider-holder extended-custom-icon',
            'as_parent' => array('only' => 'mkd_advanced_vertical_slider'),
            'js_view' => 'VcColumnView',
            'show_settings_on_create' => false,
            'params' => array()
        ));
    }

    /**
     * Renders shortcodes HTML
     *
     * @param $atts array of shortcode params
     * @param $content string shortcode content
     * @return string
     */
    public function render($atts, $content = null) {

        $args = array();

        $params = shortcode_atts($args, $atts);
        $params['content'] = $content;
        $params['mobile_images'] = $this->getMobileImages($params);
        $params['background_styles'] = $this->getBackgroundStyles($params);

        $html = '';
        $html .= '<div class="mkd-avs">'; //open mkd-avs

        //content part
        $html .= '<div class="mkd-avs-fixed-content mkd-avs-overlay-section">'; //open mkd-avs-fixed-content
        $html .= '<div class="mkd-avs-fixed-content-inner">';
        $html .= '<div class="mkd-avs-fixed-content-container">';

        $html .= mikado_core_get_core_shortcode_template_part('templates/avs-mobile-image-template', 'advanced-vertical-slider', '', $params); //render scrolling images and mobile holder

        $html .= '<div class="mkd-avs-fixed-content-text">';
        $html .= do_shortcode($content); //render textual content right of mobile with scrolling images
        $html .= '</div>';

        $html .= '</div>';
        $html .= '</div>';
        $html .= ' <a href="#" class="mkd-avs-down-arrow"><span aria-hidden="true" class="arrow_down"></span></a>';
        $html .= '</div>'; //close mkd-avs-fixed-content

        //background part
        $html .= '<div class="mkd-avs-scroll-content mkd-avs-overlay-section">';
        $html .= '<div class="mkd-avs-scroll-content-inner">';

        $html .= mikado_core_get_core_shortcode_template_part('templates/avs-background-image-template', 'advanced-vertical-slider', '', $params); //render fullscreen sections with background styles

        $html .= '</div>';
        $html .= '</div>';


        $html .= '</div>'; //close mkd-avs

        return $html;
    }

    private function getMobileImages($params) {

        $mobile_images_array = array();

        preg_match_all('/avs_mobile_image="([^\"]+)"/i', $params['content'], $mobile_images_matches, PREG_OFFSET_CAPTURE);

        if (isset($mobile_images_matches[0])) {
            $mobile_images = $mobile_images_matches[0];
        }

        foreach ($mobile_images as $mobile_image) {
            preg_match('/avs_mobile_image="([^\"]+)"/i', $mobile_image[0], $slide_mobile_images_matches, PREG_OFFSET_CAPTURE);
            $mobile_images_array[] = $slide_mobile_images_matches[1][0];
        }

        return $mobile_images_array;
    }

    private function getBackgroundStyles($params) {

        $background_images_array = array();

        preg_match_all('/avs_background_image="([^\"]+)"/i', $params['content'], $background_images_matches, PREG_OFFSET_CAPTURE);
        preg_match_all('/avs_background_color="([^\"]+)"/i', $params['content'], $background_color_matches, PREG_OFFSET_CAPTURE);
        preg_match_all('/\[mkd_advanced_vertical_slider/i', $params['content'], $items, PREG_OFFSET_CAPTURE);

        if (count($background_images_matches[1]) > 0) {
            foreach ($background_images_matches[1] as $background_image) {
                $image_matches[] = $background_image[0];
            }
        }

        if (count($background_color_matches[1]) > 0) {
            foreach ($background_color_matches[1] as $color) {
                $color_matches[] = $color[0];
            }
        }

        if (isset($items) && sizeof($items[0]) > 0) {
            for ($i = 0; $i < sizeof($items[0]); $i++) {
                $temp_style = array();
                if (isset($color_matches[$i]) && $color_matches[$i] != '') {
                    $temp_style[] = 'background-color: ' . $color_matches[$i];
                }
                if (isset($image_matches[$i]) && $image_matches[$i] != '') {
                    $temp_style[] = 'background-image: url(' . wp_get_attachment_url($image_matches[$i]) . ')';
                }

                $background_images_array[] = $temp_style;
            }
        }

        return $background_images_array;
    }
}