<?php
namespace Sparks\Modules\Shortcodes\AdvancedVerticalSlider;

use Sparks\Modules\Shortcodes\Lib\ShortcodeInterface;

/**
 * Class AdvancedVerticalSlider
 */
class AdvancedVerticalSlider implements ShortcodeInterface
{

    /**
     * @var string
     */
    private $base;

    public function __construct() {
        $this->base = 'mkd_advanced_vertical_slider';

        add_action('vc_before_init', array($this, 'vcMap'));
    }

    /**
     * Returns base for shortcode
     * @return string
     */
    public function getBase() {
        return $this->base;
    }

    /**
     * Maps shortcode to Visual Composer. Hooked on vc_before_init
     *
     * @see qode_core_get_carousel_slider_array_vc()
     */
    public function vcMap() {
        vc_map(array(
            'name' => esc_html__('AVS Item', 'mkd-core'),
            'base' => $this->getBase(),
            'category' => esc_html__('by MIKADO', 'mkd-core'),
            'as_child' => array('only' => 'mkd_advanced_vertical_slider_holder'),
            'as_parent' => array('only' => 'vc_single_image, mkd_button, mkd_icon, mkd_list, mkd_icon_with_text, mkd_progress_bar, mkd_separator, mkd_video_button, vc_empty_space, vc_column_text, mkd_custom_font'),
            'content_element' => true,
            'icon' => 'icon-wpb-advanced-vertical-slider extended-custom-icon',
            'js_view' => 'VcColumnView',
            'params' => array(
                array(
                    'type' => 'attach_image',
                    'heading' => esc_html__('Mobile Slider Image', 'mkd-core'),
                    'param_name' => 'avs_mobile_image'
                ),
                array(
                    'type' => 'colorpicker',
                    'class' => '',
                    'heading' => esc_html__('Background Color', 'mkd-core'),
                    'param_name' => 'avs_background_color',
                    'value' => '',
                    'description' => ''
                ),
                array(
                    'type' => 'attach_image',
                    'class' => '',
                    'heading' => esc_html__('Background Image', 'mkd-core'),
                    'param_name' => 'avs_background_image',
                    'value' => '',
                    'description' => ''
                ),
                array(
                    'type' => 'dropdown',
                    'heading' => esc_html__('Header Skin', 'mkd-core'),
                    'param_name' => 'header_skin',
                    'admin_label' => true,
                    'value' => array(
                        esc_html__('Default', 'mkd-core') => 'default',
                        esc_html__('Light', 'mkd-core') => 'light',
                        esc_html__('Dark', 'mkd-core') => 'dark'
                    ),
                    'save_always' => true,
                    'description' => '',
                ),
            )
        ));
    }

    /**
     * Renders shortcodes HTML
     *
     * @param $atts array of shortcode params
     * @param $content string shortcode content
     * @return string
     */
    public function render($atts, $content = null) {
        $args = array(
            'avs_mobile_image' => '',
            'avs_background_color' => '',
            'avs_background_image' => '',
            'header_skin' => 'default',
        );

        $params = shortcode_atts($args, $atts);
        extract($params);
        $params['content'] = $content;

        $html = '';

        $html .= mikado_core_get_core_shortcode_template_part('templates/avs-item-template', 'advanced-vertical-slider', '', $params);

        return $html;
    }
}