<?php
namespace Sparks\Modules\Shortcodes\Lib;

use Sparks\Modules\Shortcodes\AccordionHolder\AccordionHolder;
use Sparks\Modules\Shortcodes\Accordion\Accordion;
use Sparks\Modules\Shortcodes\AdvancedVerticalSliderHolder\AdvancedVerticalSliderHolder;
use Sparks\Modules\Shortcodes\AdvancedVerticalSlider\AdvancedVerticalSlider;
use Sparks\Modules\Shortcodes\AnimationHolder\AnimationHolder;
use Sparks\Modules\Shortcodes\Blockquote\Blockquote;
use Sparks\Modules\Shortcodes\BlogList\BlogList;
use Sparks\Modules\Shortcodes\Button\Button;
use Sparks\Modules\Shortcodes\CallToAction\CallToAction;
use Sparks\Modules\Shortcodes\Charts\Charts;
use Sparks\Modules\Shortcodes\ContentSliderHolder\ContentSliderHolder;
use Sparks\Modules\Shortcodes\ContentSlider\ContentSlider;
use Sparks\Modules\Shortcodes\Counter\Countdown;
use Sparks\Modules\Shortcodes\Counter\Counter;
use Sparks\Modules\Shortcodes\CustomFont\CustomFont;
use Sparks\Modules\Shortcodes\Dropcaps\Dropcaps;
use Sparks\Modules\Shortcodes\ElementsHolder\ElementsHolder;
use Sparks\Modules\Shortcodes\ElementsHolderItem\ElementsHolderItem;
use Sparks\Modules\Shortcodes\FrameSlider\FrameSlider;
use Sparks\Modules\Shortcodes\GoogleMap\GoogleMap;
use Sparks\Modules\Shortcodes\Highlight\Highlight;
use Sparks\Modules\Shortcodes\Icon\Icon;
use Sparks\Modules\Shortcodes\IconWithText\IconWithText;
use Sparks\Modules\Shortcodes\ImageGallery\ImageGallery;
use Sparks\Modules\Shortcodes\ImageWithHoverInfo\ImageWithHoverInfo;
use Sparks\Modules\Shortcodes\ImageWithHoverInfoItem\ImageWithHoverInfoItem;
use Sparks\Modules\Shortcodes\InfoBox\InfoBox;
use Sparks\Modules\Shortcodes\InteractiveBanner\InteractiveBanner;
use Sparks\Modules\Shortcodes\IntroSection\IntroSection;
use Sparks\Modules\Shortcodes\Lists\Lists;
use Sparks\Modules\Shortcodes\TextMarquee\TextMarquee;
use Sparks\Modules\Shortcodes\Message\Message;
use Sparks\Modules\Shortcodes\PricingSlider\PricingSlider;
use Sparks\Modules\Shortcodes\PricingTableHolder\PricingTableHolder;
use Sparks\Modules\Shortcodes\PricingTable\PricingTable;
use Sparks\Modules\Shortcodes\ProcessHolder\ProcessHolder;
use Sparks\Modules\Shortcodes\Process\Process;
use Sparks\Modules\Shortcodes\ProductListCarousel\ProductListCarousel;
use Sparks\Modules\Shortcodes\ProgressBar\ProgressBar;
use Sparks\Modules\Shortcodes\ProgressCircle\ProgressCircle;
use Sparks\Modules\Shortcodes\SectionTitle\SectionTitle;
use Sparks\Modules\Shortcodes\Separator\Separator;
use Sparks\Modules\Shortcodes\ServiceTable\ServiceTable;
use Sparks\Modules\Shortcodes\SocialShare\SocialShare;
use Sparks\Modules\Shortcodes\TabHolder\TabHolder;
use Sparks\Modules\Shortcodes\Tab\Tab;
use Sparks\Modules\Shortcodes\Team\Team;
use Sparks\Modules\Shortcodes\TwitterSlider\TwitterSlider;
use Sparks\Modules\Shortcodes\VideoBanner\VideoBanner;
use Sparks\Modules\Shortcodes\VideoButton\VideoButton;
use Sparks\Modules\Shortcodes\Workflow\Workflow;
use Sparks\Modules\Shortcodes\WorkflowItem\WorkflowItem;

/**
 * Class ShortcodeLoader
 */
class ShortcodeLoader
{
    /**
     * @var private instance of current class
     */
    private static $instance;
    /**
     * @var array
     */
    private $loadedShortcodes = array();

    /**
     * Private constuct because of Singletone
     */
    private function __construct() {
    }

    /**
     * Private sleep because of Singletone
     */
    private function __wakeup() {
    }

    /**
     * Private clone because of Singletone
     */
    private function __clone() {
    }

    /**
     * Returns current instance of class
     * @return ShortcodeLoader
     */
    public static function getInstance() {
        if (self::$instance == null) {
            return new self;
        }

        return self::$instance;
    }

    /**
     * Adds new shortcode. Object that it takes must implement ShortcodeInterface
     * @param ShortcodeInterface $shortcode
     */
    private function addShortcode(ShortcodeInterface $shortcode) {
        if (!array_key_exists($shortcode->getBase(), $this->loadedShortcodes)) {
            $this->loadedShortcodes[$shortcode->getBase()] = $shortcode;
        }
    }

    /**
     * Adds all shortcodes.
     *
     * @see ShortcodeLoader::addShortcode()
     */
    private function addShortcodes() {
        $this->addShortcode(new AccordionHolder());
        $this->addShortcode(new Accordion());
        $this->addShortcode(new AdvancedVerticalSliderHolder());
        $this->addShortcode(new AdvancedVerticalSlider());
        $this->addShortcode(new AnimationHolder());
        $this->addShortcode(new Blockquote());
        $this->addShortcode(new BlogList());
        $this->addShortcode(new Button());
        $this->addShortcode(new CallToAction());
        $this->addShortcode(new Charts());
        $this->addShortcode(new ContentSliderHolder());
        $this->addShortcode(new ContentSlider());
        $this->addShortcode(new Counter());
        $this->addShortcode(new Countdown());
        $this->addShortcode(new CustomFont());
        $this->addShortcode(new Dropcaps());
        $this->addShortcode(new ElementsHolder());
        $this->addShortcode(new ElementsHolderItem());
        $this->addShortcode(new FrameSlider());
        $this->addShortcode(new GoogleMap());
        $this->addShortcode(new Highlight());
        $this->addShortcode(new Icon());
        $this->addShortcode(new IconWithText());
        $this->addShortcode(new ImageGallery());
        $this->addShortcode(new ImageWithHoverInfo());
        $this->addShortcode(new ImageWithHoverInfoItem());
        $this->addShortcode(new InfoBox());
        $this->addShortcode(new InteractiveBanner());
        $this->addShortcode(new IntroSection());
        $this->addShortcode(new Lists());
        $this->addShortcode(new TextMarquee());
        $this->addShortcode(new Message());
        $this->addShortcode(new PricingSlider());
        $this->addShortcode(new PricingTableHolder());
        $this->addShortcode(new PricingTable());
        $this->addShortcode(new ProcessHolder());
        $this->addShortcode(new Process());
        if (sparks_mikado_is_woocommerce_installed()) {
            $this->addShortcode(new ProductListCarousel());
        }
        $this->addShortcode(new ProgressBar());
        $this->addShortcode(new ProgressCircle());
        $this->addShortcode(new SectionTitle());
        $this->addShortcode(new Separator());
        $this->addShortcode(new ServiceTable());
        $this->addShortcode(new SocialShare());
        $this->addShortcode(new TabHolder());
        $this->addShortcode(new Tab());
        $this->addShortcode(new Team());
        $this->addShortcode(new TwitterSlider());
        $this->addShortcode(new VideoBanner());
        $this->addShortcode(new VideoButton());
        $this->addShortcode(new Workflow());
        $this->addShortcode(new WorkflowItem());
    }

    /**
     * Calls ShortcodeLoader::addShortcodes and than loops through added shortcodes and calls render method
     * of each shortcode object
     */
    public function load() {
        $this->addShortcodes();

        foreach ($this->loadedShortcodes as $shortcode) {
            add_shortcode($shortcode->getBase(), array($shortcode, 'render'));
        }
    }
}

$shortcodeLoader = ShortcodeLoader::getInstance();
$shortcodeLoader->load();