<?php
namespace Sparks\Modules\Shortcodes\PricingTable;

use Sparks\Modules\Shortcodes\Lib\ShortcodeInterface;

class PricingTable implements ShortcodeInterface
{
    private $base;

    function __construct() {
        $this->base = 'mkd_pricing_table';
        add_action('vc_before_init', array($this, 'vcMap'));
    }

    public function getBase() {
        return $this->base;
    }

    public function vcMap() {
        if (function_exists('vc_map')) {
            vc_map(array(
                'name' => esc_html__('Pricing Table Item', 'mkd-core'),
                'base' => $this->base,
                'icon' => 'icon-wpb-pricing-table-item extended-custom-icon',
                'category' => esc_html__('by MIKADO', 'mkd-core'),
                'allowed_container_element' => 'vc_row',
                'as_child' => array('only' => 'mkd_pricing_table_holder'),
                'params' => array(
                    array(
                        'type' => 'textfield',
                        'admin_label' => true,
                        'heading' => esc_html__('Title', 'mkd-core'),
                        'param_name' => 'title',
                        'value' => esc_html__('Basic Plan', 'mkd-core'),
                        'description' => ''
                    ),
                    array(
                        'type' => 'textfield',
                        'admin_label' => true,
                        'heading' => esc_html__('Price', 'mkd-core'),
                        'param_name' => 'price',
                        'description' => esc_html__('Default value is 100', 'mkd-core'),
                    ),
                    array(
                        'type' => 'textfield',
                        'admin_label' => true,
                        'heading' => esc_html__('Currency', 'mkd-core'),
                        'param_name' => 'currency',
                        'description' => esc_html__('Default mark is $', 'mkd-core'),
                    ),
                    array(
                        'type' => 'textfield',
                        'admin_label' => true,
                        'heading' => esc_html__('Price Period', 'mkd-core'),
                        'param_name' => 'price_period',
                        'description' => esc_html__('Default label is monthly', 'mkd-core'),
                    ),
                    array(
                        'type' => 'dropdown',
                        'admin_label' => true,
                        'heading' => esc_html__('Show Button', 'mkd-core'),
                        'param_name' => 'show_button',
                        'value' => array(
                            esc_html__('Default', 'mkd-core') => '',
                            esc_html__('Yes', 'mkd-core') => 'yes',
                            esc_html__('No', 'mkd-core') => 'no'
                        ),
                        'description' => ''
                    ),
                    array(
                        'type' => 'textfield',
                        'admin_label' => true,
                        'heading' => esc_html__('Button Text', 'mkd-core'),
                        'param_name' => 'button_text',
                        'dependency' => array('element' => 'show_button', 'value' => 'yes')
                    ),
                    array(
                        'type' => 'dropdown',
                        'heading' => esc_html__('Button Hover Animation', 'mkd-core'),
                        'param_name' => 'button_hover_animation',
                        'value' => array(
                            esc_html__('Yes', 'mkd-core') => 'yes',
                            esc_html__('No', 'mkd-core') => 'no'
                        ),
                        'save_always' => true,
                        'admin_label' => true,
                        'dependency' => array('element' => 'show_button', 'value' => array('yes')),
                    ),
                    array(
                        'type' => 'textfield',
                        'admin_label' => true,
                        'heading' => esc_html__('Button Link', 'mkd-core'),
                        'param_name' => 'button_link',
                        'dependency' => array('element' => 'button_text', 'not_empty' => true)
                    ),
                    array(
                        'type' => 'dropdown',
                        'heading' => esc_html__('Button Target', 'mkd-core'),
                        'param_name' => 'button_target',
                        'value' => array(
                            esc_html__('Same Window', 'mkd-core') => '_self',
                            esc_html__('New Window', 'mkd-core') => '_blank'
                        ),
                        'save_always' => true,
                        'dependency' => array('element' => 'button_link', 'not_empty' => true)
                    ),
                    array(
                        'type' => 'dropdown',
                        'admin_label' => true,
                        'heading' => esc_html__('Active', 'mkd-core'),
                        'param_name' => 'active',
                        'value' => array(
                            esc_html__('No', 'mkd-core') => 'no',
                            esc_html__('Yes', 'mkd-core') => 'yes'
                        ),
                        'save_always' => true,
                        'description' => ''
                    ),
                    array(
                        'type' => 'textarea_html',
                        'holder' => 'div',
                        'class' => '',
                        'heading' => esc_html__('Content', 'mkd-core'),
                        'param_name' => 'content',
                        'value' => '<li>content content content</li><li>content content content</li><li>content content content</li>',
                        'description' => ''
                    ),
                    ///
                    array(
                        'type' => 'dropdown',
                        'heading' => esc_html__('Button Size', 'mkd-core'),
                        'param_name' => 'button_size',
                        'value' => array(
                            esc_html__('Default', 'mkd-core') => '',
                            esc_html__('Small', 'mkd-core') => 'small',
                            esc_html__('Medium', 'mkd-core') => 'medium',
                            esc_html__('Large', 'mkd-core') => 'large',
                        ),
                        'save_always' => true,
                        'admin_label' => true,
                        'group' => esc_html__('Design Options', 'mkd-core'),
                    ),
                    array(
                        'type' => 'colorpicker',
                        'heading' => esc_html__('Button Color', 'mkd-core'),
                        'param_name' => 'button_color',
                        'group' => esc_html__('Design Options', 'mkd-core'),
                        'admin_label' => true
                    ),
                    array(
                        'type' => 'colorpicker',
                        'heading' => esc_html__('Button Hover Color', 'mkd-core'),
                        'param_name' => 'button_hover_color',
                        'group' => esc_html__('Design Options', 'mkd-core'),
                        'admin_label' => true
                    ),
                    array(
                        'type' => 'colorpicker',
                        'heading' => esc_html__('Button Background Color', 'mkd-core'),
                        'param_name' => 'button_background_color',
                        'admin_label' => true,
                        'group' => esc_html__('Design Options', 'mkd-core')
                    ),
                    array(
                        'type' => 'colorpicker',
                        'heading' => esc_html__('Button Hover Background Color', 'mkd-core'),
                        'param_name' => 'button_hover_background_color',
                        'admin_label' => true,
                        'group' => esc_html__('Design Options', 'mkd-core')
                    ),
                    ///
                )
            ));
        }
    }

    public function render($atts, $content = null) {

        $args = array(
            'title' => 'Basic Plan',
            'price' => '100',
            'currency' => '$',
            'price_period' => 'Monthly',
            'active' => 'no',
            'active_text' => 'Best choice',
            'show_button' => 'yes',
            'button_link' => '',
            'button_hover_animation' => 'yes',
            'button_text' => 'button',
            'button_target' => '_self',
            'button_size' => 'small',
            'button_color' => '',
            'button_hover_color' => '',
            'button_background_color' => '',
            'button_hover_background_color' => '',
        );
        $params = shortcode_atts($args, $atts);
        extract($params);

        $html = '';
        $pricing_table_clasess = 'mkd-price-table';

        if ($active == 'yes') {
            $pricing_table_clasess .= ' mkd-active';
        }

        $params['pricing_table_classes'] = $pricing_table_clasess;
        $params['button_params'] = $this->getButtonParams($params);
        $params['content'] = preg_replace('#^<\/p>|<p>$#', '', $content);

        $html .= mikado_core_get_core_shortcode_template_part('templates/pricing-table', 'pricing-table', '', $params);
        return $html;
    }

    /**
     * Return button data params
     *
     */
    private function getButtonParams($params) {
        $button_params = array();

        if (!empty($params['button_hover_animation'])) {
            $button_params['hover_animation'] = $params['button_hover_animation'];
        }

        $button_params['link'] = (!empty($params['button_link'])) ? $params['button_link'] : '';
        $button_params['text'] = (!empty($params['button_text'])) ? $params['button_text'] : '';
        $button_params['target'] = (!empty($params['button_target'])) ? $params['button_target'] : '';
        $button_params['size'] = (!empty($params['button_size'])) ? $params['button_size'] : 'small';
        $button_params['color'] = (!empty($params['button_color'])) ? $params['button_color'] : '';
        $button_params['hover_color'] = (!empty($params['button_hover_color'])) ? $params['button_hover_color'] : '';
        $button_params['background_color'] = (!empty($params['button_background_color'])) ? $params['button_background_color'] : '';
        $button_params['hover_background_color'] = (!empty($params['button_hover_background_color'])) ? $params['button_hover_background_color'] : '';
        $button_params['type'] = 'solid';

        return $button_params;
    }
}
