<?php

class SparksMikadoLatestPosts extends SparksMikadoWidget
{
    protected $params;

    public function __construct() {
        parent::__construct(
            'mkd_latest_posts_widget', // Base ID
            esc_html__('Mikado Latest Post', 'mkd-core'), // Name
            array('description' => esc_html__('Display posts from your blog', 'mkd-core'),) // Args
        );

        $this->setParams();
    }

    protected function setParams() {
        $this->params = array(
            array(
                'type' => 'dropdown',
                'title' => esc_html__('Type', 'mkd-core'),
                'name' => 'type',
                'options' => array(
                    'minimal' => esc_html__('Minimal', 'mkd-core'),
                    'image_in_box' => esc_html__('Image in box', 'mkd-core')
                ),
            ),
            array(
                'type' => 'textfield',
                'title' => esc_html__('Number of Posts', 'mkd-core'),
                'name' => 'number_of_posts',
            ),
            array(
                'type' => 'dropdown',
                'title' => esc_html__('Order By', 'mkd-core'),
                'name' => 'order_by',
                'options' => array(
                    'title' => esc_html__('Title', 'mkd-core'),
                    'date' => esc_html__('Date', 'mkd-core')
                ),
            ),
            array(
                'type' => 'dropdown',
                'title' => esc_html__('Order', 'mkd-core'),
                'name' => 'order',
                'options' => array(
                    'ASC' => esc_html__('ASC', 'mkd-core'),
                    'DESC' => esc_html__('DESC', 'mkd-core')
                ),
            ),
            array(
                'type' => 'textfield',
                'title' => esc_html__('Category Slug', 'mkd-core'),
                'name' => 'category',
                'description' => esc_html__('Leave empty for all or use comma for list', 'mkd-core'),
            ),
            array(
                'type' => 'dropdown',
                'title' => esc_html__('Image Size', 'mkd-core'),
                'name' => 'image_size',
                'options' => array(
                    'original' => esc_html__('Original', 'mkd-core'),
                    'landscape' => esc_html__('Landscape', 'mkd-core'),
                    'square' => esc_html__('Square', 'mkd-core')
                ),
                'description' => esc_html__('Applied only to Image in Box type', 'mkd-core'),
            ),
            array(
                'type' => 'dropdown',
                'title' => esc_html__('Title Tag', 'mkd-core'),
                'name' => 'title_tag',
                'options' => array(
                    '' => '',
                    'h2' => 'h2',
                    'h3' => 'h3',
                    'h4' => 'h4',
                    'h5' => 'h5',
                    'h6' => 'h6',
                ),
            ),
            array(
                'type' => 'dropdown',
                'title' => esc_html__('Display Date', 'mkd-core'),
                'name' => 'display_date',
                'options' => array(
                    '' => esc_html__('Default', 'mkd-core'),
                    'yes' => esc_html__('Yes', 'mkd-core'),
                    'no' => esc_html__('No', 'mkd-core'),
                ),
            ),


        );
    }

    public function widget($args, $instance) {

        $title = apply_filters('title', $instance['title']);
        // before and after widget arguments are defined by themes
		echo sparks_mikado_get_module_part(($args['before_widget']));
        if (!empty($title))
			echo sparks_mikado_get_module_part(($args['before_title']) . esc_attr($title) . ($args['after_title']));

        extract($args);

        //prepare variables
        $content = '';
        $params = array();
        $params['number_of_columns'] = '1';

        //is instance empty?
        if (is_array($instance) && count($instance)) {
            //generate shortcode params
            foreach ($instance as $key => $options) {
                $params[$key] = $options;
            }
        }

        if (empty($params['number_of_posts'])) {
            $params['number_of_posts'] = 4;
        }
        if (empty($params['title_tag'])) {
            $params['title_tag'] = 'h5';
        }
        if (empty($params['display_excerpt'])) {
            $params['display_excerpt'] = 'no';
        }
        if (empty($params['excerpt_length'])) {
            $params['excerpt_length'] = '90';
        }
        if (empty($params['display_categories'])) {
            $params['display_categories'] = 'no';
        }
        if (empty($params['display_date'])) {
            $params['display_date'] = 'yes';
        }
        if (empty($params['display_share'])) {
            $params['display_share'] = 'no';
        }
        if (empty($params['display_read_more'])) {
            $params['display_read_more'] = 'no';
        }

        echo '<div class="mkd-latest-posts-widget">';

        echo sparks_mikado_execute_shortcode('mkd_blog_list', $params);

        echo '</div>'; // close mkd-latest-posts-widget

		echo sparks_mikado_get_module_part(($args['after_widget']));
    }
}

