<?php

/**
 * Widget that adds search icon that triggers opening of search form
 *
 * Class Mikado_Search_Opener
 */
class SparksMikadoSearchOpener extends SparksMikadoWidget
{
    /**
     * Set basic widget options and call parent class construct
     */
    public function __construct() {
        parent::__construct(
            'mkd_search_opener', // Base ID
            esc_html__('Mikado Search Opener', 'mkd-core') // Name
        );

        $this->setParams();
    }

    /**
     * Sets widget options
     */
    protected function setParams() {
        $this->params = array(
            array(
                'name' => 'search_icon_size',
                'type' => 'textfield',
                'title' => esc_html__('Search Icon Size (px)', 'mkd-core'),
                'description' => esc_html__('Define size for Search icon', 'mkd-core')
            ),
            array(
                'name' => 'search_icon_color',
                'type' => 'textfield',
                'title' => esc_html__('Search Icon Color', 'mkd-core'),
                'description' => esc_html__('Define color for Search icon', 'mkd-core')
            ),
            array(
                'name' => 'search_icon_hover_color',
                'type' => 'textfield',
                'title' => esc_html__('Search Icon Hover Color', 'mkd-core'),
                'description' => esc_html__('Define hover color for Search icon', 'mkd-core')
            ),
            array(
                'name' => 'show_label',
                'type' => 'dropdown',
                'title' => esc_html__('Enable Search Icon Text', 'mkd-core'),
                'description' => esc_html__('Enable this option to show \'Search\' text next to search icon in header', 'mkd-core'),
                'options' => array(
                    '' => '',
                    'yes' => esc_html__('Yes', 'mkd-core'),
                    'no' => esc_html__('No', 'mkd-core')
                )
            ),
            array(
                'name' => 'close_icon_position',
                'type' => 'dropdown',
                'title' => esc_html__('Close icon stays on opener place', 'mkd-core'),
                'description' => esc_html__('Enable this option to set close icon on same position like opener icon', 'mkd-core'),
                'options' => array(
                    'yes' => esc_html__('Yes', 'mkd-core'),
                    'no' => esc_html__('No', 'mkd-core')
                )
            ),
            array(
                'name' => 'enable_separator',
                'type' => 'dropdown',
                'title' => esc_html__('Enable Separator on Left Side', 'mkd-core'),
                'description' => esc_html__('Enable this option to show separator before search icon in header', 'mkd-core'),
                'options' => array(
                    '' => '',
                    'yes' => esc_html__('Yes', 'mkd-core'),
                    'no' => esc_html__('No', 'mkd-core')
                )
            )

        );
    }

    /**
     * Generates widget's HTML
     *
     * @param array $args args from widget area
     * @param array $instance widget's options
     */
    public function widget($args, $instance) {
        global $sparks_options, $sparks_IconCollections;

        $search_type_class = 'mkd-search-opener';
        $fullscreen_search_overlay = false;
        $search_opener_styles = array();
        $show_search_text = $instance['show_label'] == 'yes' || $sparks_options['enable_search_icon_text'] == 'yes' ? true : false;
        $close_icon_on_same_position = $instance['close_icon_position'] == 'yes' ? true : false;

        if (isset($sparks_options['search_type']) && $sparks_options['search_type'] == 'fullscreen-search') {
            if (isset($sparks_options['search_animation']) && $sparks_options['search_animation'] == 'search-from-circle') {
                $fullscreen_search_overlay = true;
            }
        }

        if (isset($sparks_options['search_type']) && $sparks_options['search_type'] == 'search_covers_header') {
            if (isset($sparks_options['search_cover_only_bottom_yesno']) && $sparks_options['search_cover_only_bottom_yesno'] == 'yes') {
                $search_type_class .= ' search_covers_only_bottom';
            }
        }

        if (!empty($instance['enable_separator']) && $instance['enable_separator'] === 'yes') {
            $search_type_class .= ' mkd-widget-separator';
        }

        if (!empty($instance['search_icon_size'])) {
            $search_opener_styles[] = 'font-size: ' . $instance['search_icon_size'] . 'px';
        }

        if (!empty($instance['search_icon_color'])) {
            $search_opener_styles[] = 'color: ' . $instance['search_icon_color'];
        }

		echo sparks_mikado_get_module_part($args['before_widget']);

        ?>

        <a <?php echo sparks_mikado_get_inline_attr($instance['search_icon_hover_color'], 'data-hover-color'); ?>
            <?php if ($close_icon_on_same_position) {
                echo sparks_mikado_get_inline_attr('yes', 'data-icon-close-same-position');
            } ?>
            <?php sparks_mikado_inline_style($search_opener_styles); ?>
            <?php sparks_mikado_class_attribute($search_type_class); ?> href="javascript:void(0)">
            <?php if (isset($sparks_options['search_icon_pack'])) {
                $sparks_IconCollections->getSearchIcon($sparks_options['search_icon_pack'], false);
            } ?>
            <?php if ($show_search_text) { ?>
                <span class="mkd-search-icon-text"><?php esc_html_e('Search', 'mkd-core'); ?></span>
            <?php } ?>
        </a>

        <?php if ($fullscreen_search_overlay) { ?>
            <div class="mkd-fullscreen-search-overlay"></div>
        <?php } ?>

        <?php do_action('sparks_mikado_after_search_opener'); ?>

        <?php echo sparks_mikado_get_module_part($args['after_widget']); ?>
    <?php }

    /*
     * override widget title interface rendering
    */
    protected function widget_title($title) {
        return '';
    }
}