<?php
if (!function_exists('sparks_mikado_design_styles')) {
    /**
     * Generates general custom styles
     */
    function sparks_mikado_design_styles() {

        $preload_background_styles = array();

        if (sparks_mikado_options()->getOptionValue('preload_pattern_image') !== '') {
            $preload_background_styles['background-image'] = 'url(' . sparks_mikado_options()->getOptionValue('preload_pattern_image') . ') !important';
        } else {
            $preload_background_styles['background-image'] = 'url(' . esc_url(MIKADO_ASSETS_ROOT . '/img/preload-pattern.png') . ') !important';
        }

        echo sparks_mikado_dynamic_css('.mkd-preload-background', $preload_background_styles);

        if (sparks_mikado_options()->getOptionValue('google_fonts')) {
            $font_family = sparks_mikado_options()->getOptionValue('google_fonts');
            if (sparks_mikado_is_font_option_valid($font_family)) {
                echo sparks_mikado_dynamic_css('body', array('font-family' => sparks_mikado_get_font_option_val($font_family)));
            }
        }

        if (sparks_mikado_options()->getOptionValue('page_background_color')) {
            $background_color_selector = array(
                '.mkd-content .mkd-content-inner > .mkd-container',
                '.mkd-content .mkd-content-inner > .mkd-full-width'
            );
            echo sparks_mikado_dynamic_css($background_color_selector, array('background-color' => sparks_mikado_options()->getOptionValue('page_background_color')));
        }

        if (sparks_mikado_options()->getOptionValue('selection_color')) {
            echo sparks_mikado_dynamic_css('::selection', array('background' => sparks_mikado_options()->getOptionValue('selection_color')));
            echo sparks_mikado_dynamic_css('::-moz-selection', array('background' => sparks_mikado_options()->getOptionValue('selection_color')));
        }

        $boxed_background_style = array();
        if (sparks_mikado_options()->getOptionValue('page_background_color_in_box')) {
            $boxed_background_style['background-color'] = sparks_mikado_options()->getOptionValue('page_background_color_in_box');
        }

        if (sparks_mikado_options()->getOptionValue('boxed_background_image')) {
            $boxed_background_style['background-image'] = 'url(' . esc_url(sparks_mikado_options()->getOptionValue('boxed_background_image')) . ')';
            $boxed_background_style['background-position'] = 'center 0px';
            $boxed_background_style['background-repeat'] = 'no-repeat';
        }

        if (sparks_mikado_options()->getOptionValue('boxed_pattern_background_image')) {
            $boxed_background_style['background-image'] = 'url(' . esc_url(sparks_mikado_options()->getOptionValue('boxed_pattern_background_image')) . ')';
            $boxed_background_style['background-position'] = '0px 0px';
            $boxed_background_style['background-repeat'] = 'repeat';
        }

        if (sparks_mikado_options()->getOptionValue('boxed_background_image_attachment')) {
            $boxed_background_style['background-attachment'] = (sparks_mikado_options()->getOptionValue('boxed_background_image_attachment'));
        }

        echo sparks_mikado_dynamic_css('.mkd-boxed .mkd-wrapper', $boxed_background_style);
    }

    add_action('sparks_mikado_style_dynamic', 'sparks_mikado_design_styles');
}

if (!function_exists('sparks_mikado_h1_styles')) {

    function sparks_mikado_h1_styles() {

        $h1_styles = array();

        if (sparks_mikado_options()->getOptionValue('h1_color') !== '') {
            $h1_styles['color'] = sparks_mikado_options()->getOptionValue('h1_color');
        }
        if (sparks_mikado_options()->getOptionValue('h1_google_fonts') !== '-1') {
            $h1_styles['font-family'] = sparks_mikado_get_formatted_font_family(sparks_mikado_options()->getOptionValue('h1_google_fonts'));
        }
        if (sparks_mikado_options()->getOptionValue('h1_fontsize') !== '') {
            $h1_styles['font-size'] = sparks_mikado_filter_px(sparks_mikado_options()->getOptionValue('h1_fontsize')) . 'px';
        }
        if (sparks_mikado_options()->getOptionValue('h1_lineheight') !== '') {
            $h1_styles['line-height'] = sparks_mikado_filter_px(sparks_mikado_options()->getOptionValue('h1_lineheight')) . 'px';
        }
        if (sparks_mikado_options()->getOptionValue('h1_texttransform') !== '') {
            $h1_styles['text-transform'] = sparks_mikado_options()->getOptionValue('h1_texttransform');
        }
        if (sparks_mikado_options()->getOptionValue('h1_fontstyle') !== '') {
            $h1_styles['font-style'] = sparks_mikado_options()->getOptionValue('h1_fontstyle');
        }
        if (sparks_mikado_options()->getOptionValue('h1_fontweight') !== '') {
            $h1_styles['font-weight'] = sparks_mikado_options()->getOptionValue('h1_fontweight');
        }
        if (sparks_mikado_options()->getOptionValue('h1_letterspacing') !== '') {
            $h1_styles['letter-spacing'] = sparks_mikado_filter_px(sparks_mikado_options()->getOptionValue('h1_letterspacing')) . 'px';
        }

        $h1_selector = array(
            'h1'
        );

        if (!empty($h1_styles)) {
            echo sparks_mikado_dynamic_css($h1_selector, $h1_styles);
        }
    }

    add_action('sparks_mikado_style_dynamic', 'sparks_mikado_h1_styles');
}

if (!function_exists('sparks_mikado_h2_styles')) {

    function sparks_mikado_h2_styles() {

        $h2_styles = array();

        if (sparks_mikado_options()->getOptionValue('h2_color') !== '') {
            $h2_styles['color'] = sparks_mikado_options()->getOptionValue('h2_color');
        }
        if (sparks_mikado_options()->getOptionValue('h2_google_fonts') !== '-1') {
            $h2_styles['font-family'] = sparks_mikado_get_formatted_font_family(sparks_mikado_options()->getOptionValue('h2_google_fonts'));
        }
        if (sparks_mikado_options()->getOptionValue('h2_fontsize') !== '') {
            $h2_styles['font-size'] = sparks_mikado_filter_px(sparks_mikado_options()->getOptionValue('h2_fontsize')) . 'px';
        }
        if (sparks_mikado_options()->getOptionValue('h2_lineheight') !== '') {
            $h2_styles['line-height'] = sparks_mikado_filter_px(sparks_mikado_options()->getOptionValue('h2_lineheight')) . 'px';
        }
        if (sparks_mikado_options()->getOptionValue('h2_texttransform') !== '') {
            $h2_styles['text-transform'] = sparks_mikado_options()->getOptionValue('h2_texttransform');
        }
        if (sparks_mikado_options()->getOptionValue('h2_fontstyle') !== '') {
            $h2_styles['font-style'] = sparks_mikado_options()->getOptionValue('h2_fontstyle');
        }
        if (sparks_mikado_options()->getOptionValue('h2_fontweight') !== '') {
            $h2_styles['font-weight'] = sparks_mikado_options()->getOptionValue('h2_fontweight');
        }
        if (sparks_mikado_options()->getOptionValue('h2_letterspacing') !== '') {
            $h2_styles['letter-spacing'] = sparks_mikado_filter_px(sparks_mikado_options()->getOptionValue('h2_letterspacing')) . 'px';
        }

        $h2_selector = array(
            'h2'
        );

        if (!empty($h2_styles)) {
            echo sparks_mikado_dynamic_css($h2_selector, $h2_styles);
        }
    }

    add_action('sparks_mikado_style_dynamic', 'sparks_mikado_h2_styles');
}

if (!function_exists('sparks_mikado_h3_styles')) {

    function sparks_mikado_h3_styles() {

        $h3_styles = array();

        if (sparks_mikado_options()->getOptionValue('h3_color') !== '') {
            $h3_styles['color'] = sparks_mikado_options()->getOptionValue('h3_color');
        }
        if (sparks_mikado_options()->getOptionValue('h3_google_fonts') !== '-1') {
            $h3_styles['font-family'] = sparks_mikado_get_formatted_font_family(sparks_mikado_options()->getOptionValue('h3_google_fonts'));
        }
        if (sparks_mikado_options()->getOptionValue('h3_fontsize') !== '') {
            $h3_styles['font-size'] = sparks_mikado_filter_px(sparks_mikado_options()->getOptionValue('h3_fontsize')) . 'px';
        }
        if (sparks_mikado_options()->getOptionValue('h3_lineheight') !== '') {
            $h3_styles['line-height'] = sparks_mikado_filter_px(sparks_mikado_options()->getOptionValue('h3_lineheight')) . 'px';
        }
        if (sparks_mikado_options()->getOptionValue('h3_texttransform') !== '') {
            $h3_styles['text-transform'] = sparks_mikado_options()->getOptionValue('h3_texttransform');
        }
        if (sparks_mikado_options()->getOptionValue('h3_fontstyle') !== '') {
            $h3_styles['font-style'] = sparks_mikado_options()->getOptionValue('h3_fontstyle');
        }
        if (sparks_mikado_options()->getOptionValue('h3_fontweight') !== '') {
            $h3_styles['font-weight'] = sparks_mikado_options()->getOptionValue('h3_fontweight');
        }
        if (sparks_mikado_options()->getOptionValue('h3_letterspacing') !== '') {
            $h3_styles['letter-spacing'] = sparks_mikado_filter_px(sparks_mikado_options()->getOptionValue('h3_letterspacing')) . 'px';
        }

        $h3_selector = array(
            'h3'
        );

        if (!empty($h3_styles)) {
            echo sparks_mikado_dynamic_css($h3_selector, $h3_styles);
        }
    }

    add_action('sparks_mikado_style_dynamic', 'sparks_mikado_h3_styles');
}

if (!function_exists('sparks_mikado_h4_styles')) {

    function sparks_mikado_h4_styles() {

        $h4_styles = array();

        if (sparks_mikado_options()->getOptionValue('h4_color') !== '') {
            $h4_styles['color'] = sparks_mikado_options()->getOptionValue('h4_color');
        }
        if (sparks_mikado_options()->getOptionValue('h4_google_fonts') !== '-1') {
            $h4_styles['font-family'] = sparks_mikado_get_formatted_font_family(sparks_mikado_options()->getOptionValue('h4_google_fonts'));
        }
        if (sparks_mikado_options()->getOptionValue('h4_fontsize') !== '') {
            $h4_styles['font-size'] = sparks_mikado_filter_px(sparks_mikado_options()->getOptionValue('h4_fontsize')) . 'px';
        }
        if (sparks_mikado_options()->getOptionValue('h4_lineheight') !== '') {
            $h4_styles['line-height'] = sparks_mikado_filter_px(sparks_mikado_options()->getOptionValue('h4_lineheight')) . 'px';
        }
        if (sparks_mikado_options()->getOptionValue('h4_texttransform') !== '') {
            $h4_styles['text-transform'] = sparks_mikado_options()->getOptionValue('h4_texttransform');
        }
        if (sparks_mikado_options()->getOptionValue('h4_fontstyle') !== '') {
            $h4_styles['font-style'] = sparks_mikado_options()->getOptionValue('h4_fontstyle');
        }
        if (sparks_mikado_options()->getOptionValue('h4_fontweight') !== '') {
            $h4_styles['font-weight'] = sparks_mikado_options()->getOptionValue('h4_fontweight');
        }
        if (sparks_mikado_options()->getOptionValue('h4_letterspacing') !== '') {
            $h4_styles['letter-spacing'] = sparks_mikado_filter_px(sparks_mikado_options()->getOptionValue('h4_letterspacing')) . 'px';
        }

        $h4_selector = array(
            'h4'
        );

        if (!empty($h4_styles)) {
            echo sparks_mikado_dynamic_css($h4_selector, $h4_styles);
        }
    }

    add_action('sparks_mikado_style_dynamic', 'sparks_mikado_h4_styles');
}

if (!function_exists('sparks_mikado_h5_styles')) {

    function sparks_mikado_h5_styles() {

        $h5_styles = array();

        if (sparks_mikado_options()->getOptionValue('h5_color') !== '') {
            $h5_styles['color'] = sparks_mikado_options()->getOptionValue('h5_color');
        }
        if (sparks_mikado_options()->getOptionValue('h5_google_fonts') !== '-1') {
            $h5_styles['font-family'] = sparks_mikado_get_formatted_font_family(sparks_mikado_options()->getOptionValue('h5_google_fonts'));
        }
        if (sparks_mikado_options()->getOptionValue('h5_fontsize') !== '') {
            $h5_styles['font-size'] = sparks_mikado_filter_px(sparks_mikado_options()->getOptionValue('h5_fontsize')) . 'px';
        }
        if (sparks_mikado_options()->getOptionValue('h5_lineheight') !== '') {
            $h5_styles['line-height'] = sparks_mikado_filter_px(sparks_mikado_options()->getOptionValue('h5_lineheight')) . 'px';
        }
        if (sparks_mikado_options()->getOptionValue('h5_texttransform') !== '') {
            $h5_styles['text-transform'] = sparks_mikado_options()->getOptionValue('h5_texttransform');
        }
        if (sparks_mikado_options()->getOptionValue('h5_fontstyle') !== '') {
            $h5_styles['font-style'] = sparks_mikado_options()->getOptionValue('h5_fontstyle');
        }
        if (sparks_mikado_options()->getOptionValue('h5_fontweight') !== '') {
            $h5_styles['font-weight'] = sparks_mikado_options()->getOptionValue('h5_fontweight');
        }
        if (sparks_mikado_options()->getOptionValue('h5_letterspacing') !== '') {
            $h5_styles['letter-spacing'] = sparks_mikado_filter_px(sparks_mikado_options()->getOptionValue('h5_letterspacing')) . 'px';
        }

        $h5_selector = array(
            'h5'
        );

        if (!empty($h5_styles)) {
            echo sparks_mikado_dynamic_css($h5_selector, $h5_styles);
        }
    }

    add_action('sparks_mikado_style_dynamic', 'sparks_mikado_h5_styles');
}

if (!function_exists('sparks_mikado_h6_styles')) {

    function sparks_mikado_h6_styles() {

        $h6_styles = array();

        if (sparks_mikado_options()->getOptionValue('h6_color') !== '') {
            $h6_styles['color'] = sparks_mikado_options()->getOptionValue('h6_color');
        }
        if (sparks_mikado_options()->getOptionValue('h6_google_fonts') !== '-1') {
            $h6_styles['font-family'] = sparks_mikado_get_formatted_font_family(sparks_mikado_options()->getOptionValue('h6_google_fonts'));
        }
        if (sparks_mikado_options()->getOptionValue('h6_fontsize') !== '') {
            $h6_styles['font-size'] = sparks_mikado_filter_px(sparks_mikado_options()->getOptionValue('h6_fontsize')) . 'px';
        }
        if (sparks_mikado_options()->getOptionValue('h6_lineheight') !== '') {
            $h6_styles['line-height'] = sparks_mikado_filter_px(sparks_mikado_options()->getOptionValue('h6_lineheight')) . 'px';
        }
        if (sparks_mikado_options()->getOptionValue('h6_texttransform') !== '') {
            $h6_styles['text-transform'] = sparks_mikado_options()->getOptionValue('h6_texttransform');
        }
        if (sparks_mikado_options()->getOptionValue('h6_fontstyle') !== '') {
            $h6_styles['font-style'] = sparks_mikado_options()->getOptionValue('h6_fontstyle');
        }
        if (sparks_mikado_options()->getOptionValue('h6_fontweight') !== '') {
            $h6_styles['font-weight'] = sparks_mikado_options()->getOptionValue('h6_fontweight');
        }
        if (sparks_mikado_options()->getOptionValue('h6_letterspacing') !== '') {
            $h6_styles['letter-spacing'] = sparks_mikado_filter_px(sparks_mikado_options()->getOptionValue('h6_letterspacing')) . 'px';
        }

        $h6_selector = array(
            'h6'
        );

        if (!empty($h6_styles)) {
            echo sparks_mikado_dynamic_css($h6_selector, $h6_styles);
        }
    }

    add_action('sparks_mikado_style_dynamic', 'sparks_mikado_h6_styles');
}

if (!function_exists('sparks_mikado_text_styles')) {

    function sparks_mikado_text_styles() {

        $text_styles = array();

        if (sparks_mikado_options()->getOptionValue('text_color') !== '') {
            $text_styles['color'] = sparks_mikado_options()->getOptionValue('text_color');
        }
        if (sparks_mikado_options()->getOptionValue('text_google_fonts') !== '-1') {
            $text_styles['font-family'] = sparks_mikado_get_formatted_font_family(sparks_mikado_options()->getOptionValue('text_google_fonts'));
        }
        if (sparks_mikado_options()->getOptionValue('text_fontsize') !== '') {
            $text_styles['font-size'] = sparks_mikado_filter_px(sparks_mikado_options()->getOptionValue('text_fontsize')) . 'px';
        }
        if (sparks_mikado_options()->getOptionValue('text_lineheight') !== '') {
            $text_styles['line-height'] = sparks_mikado_filter_px(sparks_mikado_options()->getOptionValue('text_lineheight')) . 'px';
        }
        if (sparks_mikado_options()->getOptionValue('text_texttransform') !== '') {
            $text_styles['text-transform'] = sparks_mikado_options()->getOptionValue('text_texttransform');
        }
        if (sparks_mikado_options()->getOptionValue('text_fontstyle') !== '') {
            $text_styles['font-style'] = sparks_mikado_options()->getOptionValue('text_fontstyle');
        }
        if (sparks_mikado_options()->getOptionValue('text_fontweight') !== '') {
            $text_styles['font-weight'] = sparks_mikado_options()->getOptionValue('text_fontweight');
        }
        if (sparks_mikado_options()->getOptionValue('text_letterspacing') !== '') {
            $text_styles['letter-spacing'] = sparks_mikado_filter_px(sparks_mikado_options()->getOptionValue('text_letterspacing')) . 'px';
        }

        $text_selector = array(
            'p'
        );

        if (!empty($text_styles)) {
            echo sparks_mikado_dynamic_css($text_selector, $text_styles);
        }
    }

    add_action('sparks_mikado_style_dynamic', 'sparks_mikado_text_styles');
}

if (!function_exists('sparks_mikado_link_styles')) {

    function sparks_mikado_link_styles() {

        $link_styles = array();

        if (sparks_mikado_options()->getOptionValue('link_color') !== '') {
            $link_styles['color'] = sparks_mikado_options()->getOptionValue('link_color');
        }
        if (sparks_mikado_options()->getOptionValue('link_fontstyle') !== '') {
            $link_styles['font-style'] = sparks_mikado_options()->getOptionValue('link_fontstyle');
        }
        if (sparks_mikado_options()->getOptionValue('link_fontweight') !== '') {
            $link_styles['font-weight'] = sparks_mikado_options()->getOptionValue('link_fontweight');
        }
        if (sparks_mikado_options()->getOptionValue('link_fontdecoration') !== '') {
            $link_styles['text-decoration'] = sparks_mikado_options()->getOptionValue('link_fontdecoration');
        }

        $link_selector = array(
            'a',
            'p a'
        );

        if (!empty($link_styles)) {
            echo sparks_mikado_dynamic_css($link_selector, $link_styles);
        }
    }

    add_action('sparks_mikado_style_dynamic', 'sparks_mikado_link_styles');
}

if (!function_exists('sparks_mikado_link_hover_styles')) {

    function sparks_mikado_link_hover_styles() {

        $link_hover_styles = array();

        if (sparks_mikado_options()->getOptionValue('link_hovercolor') !== '') {
            $link_hover_styles['color'] = sparks_mikado_options()->getOptionValue('link_hovercolor');
        }
        if (sparks_mikado_options()->getOptionValue('link_hover_fontdecoration') !== '') {
            $link_hover_styles['text-decoration'] = sparks_mikado_options()->getOptionValue('link_hover_fontdecoration');
        }

        $link_hover_selector = array(
            'a:hover',
            'p a:hover'
        );

        if (!empty($link_hover_styles)) {
            echo sparks_mikado_dynamic_css($link_hover_selector, $link_hover_styles);
        }

        $link_heading_hover_styles = array();

        if (sparks_mikado_options()->getOptionValue('link_hovercolor') !== '') {
            $link_heading_hover_styles['color'] = sparks_mikado_options()->getOptionValue('link_hovercolor');
        }

        $link_heading_hover_selector = array(
            'h1 a:hover',
            'h2 a:hover',
            'h3 a:hover',
            'h4 a:hover',
            'h5 a:hover',
            'h6 a:hover'
        );

        if (!empty($link_heading_hover_styles)) {
            echo sparks_mikado_dynamic_css($link_heading_hover_selector, $link_heading_hover_styles);
        }
    }

    add_action('sparks_mikado_style_dynamic', 'sparks_mikado_link_hover_styles');
}

if (!function_exists('sparks_mikado_smooth_page_transition_styles')) {

    function sparks_mikado_smooth_page_transition_styles() {

        $loader_style = array();

        if (sparks_mikado_options()->getOptionValue('smooth_pt_bgnd_color') !== '') {
            $loader_style['background-color'] = sparks_mikado_options()->getOptionValue('smooth_pt_bgnd_color');
        }

        $loader_selector = array('.mkd-smooth-transition-loader');

        if (!empty($loader_style)) {
            echo sparks_mikado_dynamic_css($loader_selector, $loader_style);
        }

        $spinner_style = array();

        if (sparks_mikado_options()->getOptionValue('smooth_pt_spinner_color') !== '') {
            $spinner_style['background-color'] = sparks_mikado_options()->getOptionValue('smooth_pt_spinner_color');
        }

        $spinner_selectors = array(
            '.mkd-st-loader .pulse',
            '.mkd-st-loader .double_pulse .double-bounce1',
            '.mkd-st-loader .double_pulse .double-bounce2',
            '.mkd-st-loader .cube',
            '.mkd-st-loader .rotating_cubes .cube1',
            '.mkd-st-loader .rotating_cubes .cube2',
            '.mkd-st-loader .stripes > div',
            '.mkd-st-loader .wave > div',
            '.mkd-st-loader .two_rotating_circles .dot1',
            '.mkd-st-loader .two_rotating_circles .dot2',
            '.mkd-st-loader .five_rotating_circles .container1 > div',
            '.mkd-st-loader .five_rotating_circles .container2 > div',
            '.mkd-st-loader .five_rotating_circles .container3 > div',
            '.mkd-st-loader .atom .ball-1:before',
            '.mkd-st-loader .atom .ball-2:before',
            '.mkd-st-loader .atom .ball-3:before',
            '.mkd-st-loader .atom .ball-4:before',
            '.mkd-st-loader .clock .ball:before',
            '.mkd-st-loader .mitosis .ball',
            '.mkd-st-loader .lines .line1',
            '.mkd-st-loader .lines .line2',
            '.mkd-st-loader .lines .line3',
            '.mkd-st-loader .lines .line4',
            '.mkd-st-loader .fussion .ball',
            '.mkd-st-loader .fussion .ball-1',
            '.mkd-st-loader .fussion .ball-2',
            '.mkd-st-loader .fussion .ball-3',
            '.mkd-st-loader .fussion .ball-4',
            '.mkd-st-loader .wave_circles .ball',
            '.mkd-st-loader .pulse_circles .ball'
        );

        if (!empty($spinner_style)) {
            echo sparks_mikado_dynamic_css($spinner_selectors, $spinner_style);
        }
    }

    add_action('sparks_mikado_style_dynamic', 'sparks_mikado_smooth_page_transition_styles');
}

if (!function_exists('sparks_mikado_sidebar_styles')) {

    function sparks_mikado_sidebar_styles() {

        $sidebar_styles = array();

        if (sparks_mikado_options()->getOptionValue('sidebar_background_color') !== '') {
            $sidebar_styles['background-color'] = sparks_mikado_options()->getOptionValue('sidebar_background_color');
        }

        if (sparks_mikado_options()->getOptionValue('sidebar_padding_top') !== '') {
            $sidebar_styles['padding-top'] = sparks_mikado_filter_px(sparks_mikado_options()->getOptionValue('sidebar_padding_top')) . 'px';
        }

        if (sparks_mikado_options()->getOptionValue('sidebar_padding_right') !== '') {
            $sidebar_styles['padding-right'] = sparks_mikado_filter_px(sparks_mikado_options()->getOptionValue('sidebar_padding_right')) . 'px';
        }

        if (sparks_mikado_options()->getOptionValue('sidebar_padding_bottom') !== '') {
            $sidebar_styles['padding-bottom'] = sparks_mikado_filter_px(sparks_mikado_options()->getOptionValue('sidebar_padding_bottom')) . 'px';
        }

        if (sparks_mikado_options()->getOptionValue('sidebar_padding_left') !== '') {
            $sidebar_styles['padding-left'] = sparks_mikado_filter_px(sparks_mikado_options()->getOptionValue('sidebar_padding_left')) . 'px';
        }

        if (sparks_mikado_options()->getOptionValue('sidebar_alignment') !== '') {
            $sidebar_styles['text-align'] = sparks_mikado_options()->getOptionValue('sidebar_alignment');
        }

        if (!empty($sidebar_styles)) {
            echo sparks_mikado_dynamic_css('aside.mkd-sidebar', $sidebar_styles);
        }
    }

    add_action('sparks_mikado_style_dynamic', 'sparks_mikado_sidebar_styles');
}