(function ($) {
    'use strict';

    var woocommerce = {};
    mkd.modules.woocommerce = woocommerce;

    woocommerce.mkdInitQuantityButtons = mkdInitQuantityButtons;
    woocommerce.mkdInitSelect2 = mkdInitSelect2;

    woocommerce.mkdOnDocumentReady = mkdOnDocumentReady;
    woocommerce.mkdOnWindowLoad = mkdOnWindowLoad;
    woocommerce.mkdOnWindowResize = mkdOnWindowResize;
    woocommerce.mkdOnWindowScroll = mkdOnWindowScroll;

    $(document).ready(mkdOnDocumentReady);
    $(window).load(mkdOnWindowLoad);
    $(window).resize(mkdOnWindowResize);
    $(window).scroll(mkdOnWindowScroll);

    /* 
     All functions to be called on $(document).ready() should be in this function
     */
    function mkdOnDocumentReady() {
        mkdInitQuantityButtons();
        mkdInitSelect2();
        mkdReInitSelect2CartAjax();
        mkdInitProductListCarousel();
    }

    /* 
     All functions to be called on $(window).load() should be in this function
     */
    function mkdOnWindowLoad() {
        mkdInitButtonLoading();
    }

    /* 
     All functions to be called on $(window).resize() should be in this function
     */
    function mkdOnWindowResize() {

    }

    /* 
     All functions to be called on $(window).scroll() should be in this function
     */
    function mkdOnWindowScroll() {

    }

    /*
     ** Init quantity buttons to increase/decrease products for cart
     */
    function mkdInitQuantityButtons() {

        $(document).on('click', '.mkd-quantity-minus, .mkd-quantity-plus', function (e) {
            e.stopPropagation();

            var button = $(this),
                inputField = button.siblings('.mkd-quantity-input'),
                step = parseFloat(inputField.data('step')),
                max = parseFloat(inputField.data('max')),
                minus = false,
                inputValue = parseFloat(inputField.val()),
                newInputValue;

            if (button.hasClass('mkd-quantity-minus')) {
                minus = true;
            }

            if (minus) {
                newInputValue = inputValue - step;
                if (newInputValue >= 1) {
                    inputField.val(newInputValue);
                } else {
                    inputField.val(1);
                }
            } else {
                newInputValue = inputValue + step;
                if (max === undefined) {
                    inputField.val(newInputValue);
                } else {
                    if (newInputValue >= max) {
                        inputField.val(max);
                    } else {
                        inputField.val(newInputValue);
                    }
                }
            }

            inputField.trigger('change');
        });
    }

    /*  
     Adding to cart text when button is clicked
     */
    function mkdInitButtonLoading() {
        $('.add_to_cart_button').on('click', function () {
            $(this).text(mkdGlobalVars.vars.mkdAddingToCart);
        });
    }

    /*
     ** Init select2 script for select html dropdowns
     */
    function mkdInitSelect2() {

        if ($('.woocommerce-ordering .orderby').length || $('#calc_shipping_country').length) {

            $('.woocommerce-ordering .orderby').select2({
                minimumResultsForSearch: Infinity
            });

            $('#calc_shipping_country').select2();
        }
    }

    /*
     ** Re Init select2 script for select html dropdowns
     */
    function mkdReInitSelect2CartAjax() {

        $(document).ajaxComplete(function () {
            if ($('#calc_shipping_country').length) {

                $('#calc_shipping_country').select2();
            }
        });
    }

    /*
     ** Init Product List Carousel Shortcode
     */
    function mkdInitProductListCarousel() {
        var carouselHolder = $('.mkd-plc-holder');

        if (carouselHolder.length) {
            carouselHolder.each(function () {
                var thisCarousels = $(this),
                    carousel = thisCarousels.children('.mkd-plc-outer'),
                    numberOfItems = (thisCarousels.data('number-of-visible-items') !== '') ? parseInt(thisCarousels.data('number-of-visible-items')) : 3,
                    loop = (thisCarousels.data('loop') == 'yes'),
                    pause = (thisCarousels.data('pause') == 'yes'),
                    navigation = (thisCarousels.data('navigation') == 'yes'),
                    pagination = (thisCarousels.data('pagination') == 'yes'),
                    autoplay = (thisCarousels.data('autoplay') != 'disable'),
                    autoplayTimeout = 0;

                if (autoplay === true) {
                    autoplayTimeout = thisCarousels.data('autoplay') * 1000;
                }

                var margin = 30;
                if (thisCarousels.hasClass('mkd-small-space')) {
                    margin = 10;
                } else if (thisCarousels.hasClass('mkd-no-space')) {
                    margin = 0;
                }

                var responsiveItems1 = numberOfItems;
                var responsiveItems2 = 3;
                var responsiveItems3 = 2;

                if (numberOfItems > 4) {
                    responsiveItems1 = 4;
                }

                if (numberOfItems < 3) {
                    responsiveItems2 = numberOfItems;
                    responsiveItems3 = numberOfItems;
                }

                if (numberOfItems === 1) {
                    margin = 0;
                }

                carousel.owlCarousel({
                    items: numberOfItems,
                    loop: loop,
                    autoplayHoverPause: pause,
                    autoplay: autoplay,
                    autoplayTimeout: autoplayTimeout,
                    dots: pagination,
                    nav: navigation,
                    margin: margin,
                    navText: [
                        '<span class="mkd-prev-icon"><i class="arrow_carrot-left"></i></span>',
                        '<span class="mkd-next-icon"><i class="arrow_carrot-right"></i></span>'
                    ],
                    responsive: {
                        1200: {
                            items: numberOfItems
                        },
                        1024: {
                            items: responsiveItems1
                        },
                        769: {
                            items: responsiveItems2
                        },
                        601: {
                            items: responsiveItems3
                        },
                        0: {
                            items: 1
                        }
                    },
                    onInitialized: function () {
                        carousel.css({'opacity': '1'});
                    },
                    onInitialize: function () {

                        console.log(carousel.find('.mkd-plc-item'));

                        /*if (carousel.find('.mkd-plc-item').length <= 1) {
                         this.settings.loop = false;
                         }*/
                    }
                });
            });
        }
    }

})(jQuery);