<?php

if (!function_exists('sparks_mikado_blog_options_map')) {

    function sparks_mikado_blog_options_map() {

        sparks_mikado_add_admin_page(
            array(
                'slug' => '_blog_page',
                'title' => esc_html__('Blog', 'sparks'),
                'icon' => 'fa fa-files-o'
            )
        );

        /**
         * Blog Lists
         */

        $custom_sidebars = sparks_mikado_get_custom_sidebars();

        $panel_blog_lists = sparks_mikado_add_admin_panel(
            array(
                'page' => '_blog_page',
                'name' => 'panel_blog_lists',
                'title' => esc_html__('Blog Lists', 'sparks')
            )
        );

        sparks_mikado_add_admin_section_title(
            array(
                'parent' => $panel_blog_lists,
                'name' => 'templates_title_blog_list',
                'title' => esc_html__('Blog Templates', 'sparks')
            )
        );

        sparks_mikado_add_admin_field(array(
            'name' => 'blog_list_standard_enable',
            'type' => 'yesno',
            'default_value' => 'no',
            'label' => esc_html__('Enable Standard List Options', 'sparks'),
            'description' => esc_html__('Enabling this option will display options for Standard Blog List', 'sparks'),
            'parent' => $panel_blog_lists,
            'args' => array(
                'dependence' => true,
                'dependence_hide_on_yes' => '',
                'dependence_show_on_yes' => '#mkd_panel_blog_standard'
            )
        ));

        sparks_mikado_add_admin_field(array(
            'name' => 'blog_list_masonry_enable',
            'type' => 'yesno',
            'default_value' => 'no',
            'label' => esc_html__('Enable Masonry List Options', 'sparks'),
            'description' => esc_html__('Enabling this option will display options for Masonry Blog List', 'sparks'),
            'parent' => $panel_blog_lists,
            'args' => array(
                'dependence' => true,
                'dependence_hide_on_yes' => '',
                'dependence_show_on_yes' => '#mkd_panel_blog_masonry'
            )
        ));

        sparks_mikado_add_admin_section_title(
            array(
                'parent' => $panel_blog_lists,
                'name' => 'archive_title_blog_list',
                'title' => esc_html__('Archive - All Posts', 'sparks')
            )
        );

        sparks_mikado_add_admin_field(array(
            'name' => 'blog_list_type',
            'type' => 'select',
            'label' => esc_html__('Blog Layout for Archive Pages', 'sparks'),
            'description' => esc_html__('Choose a default blog layout', 'sparks'),
            'default_value' => 'standard',
            'parent' => $panel_blog_lists,
            'options' => array(
                'standard' => esc_html__('Blog: Standard', 'sparks'),
                'masonry' => esc_html__('Blog: Masonry', 'sparks'),
                'masonry-full-width' => esc_html__('Blog: Masonry Full Width', 'sparks'),
                'standard-whole-post' => esc_html__('Blog: Standard Whole Post', 'sparks')
            )
        ));

        sparks_mikado_add_admin_field(array(
            'name' => 'archive_sidebar_layout',
            'type' => 'select',
            'label' => esc_html__('Archive and Category Sidebar', 'sparks'),
            'description' => esc_html__('Choose a sidebar layout for archived Blog Post Lists and Category Blog Lists', 'sparks'),
            'parent' => $panel_blog_lists,
            'options' => array(
                'default' => esc_html__('No Sidebar', 'sparks'),
                'sidebar-33-right' => esc_html__('Sidebar 1/3 Right', 'sparks'),
                'sidebar-25-right' => esc_html__('Sidebar 1/4 Right', 'sparks'),
                'sidebar-33-left' => esc_html__('Sidebar 1/3 Left', 'sparks'),
                'sidebar-25-left' => esc_html__('Sidebar 1/4 Left', 'sparks'),
            )
        ));


        if (count($custom_sidebars) > 0) {
            sparks_mikado_add_admin_field(array(
                'name' => 'blog_custom_sidebar',
                'type' => 'selectblank',
                'label' => esc_html__('Sidebar to Display', 'sparks'),
                'description' => esc_html__('Choose a sidebar to display on Blog Post Lists and Category Blog Lists. Default sidebar is "Sidebar Page"', 'sparks'),
                'parent' => $panel_blog_lists,
                'options' => sparks_mikado_get_custom_sidebars(),
                'args' => array(
                    'select2' => true
                )
            ));
        }

        sparks_mikado_add_admin_field(
            array(
                'type' => 'text',
                'name' => 'number_of_chars',
                'default_value' => '',
                'label' => esc_html__('Number of Words in Excerpt', 'sparks'),
                'parent' => $panel_blog_lists,
                'description' => esc_html__('Enter a number of words in excerpt (article summary)', 'sparks'),
                'args' => array(
                    'col_width' => 3
                )
            )
        );

        sparks_mikado_add_admin_section_title(
            array(
                'parent' => $panel_blog_lists,
                'name' => 'pagination_title_blog_list',
                'title' => esc_html__('Pagination', 'sparks')
            )
        );

        sparks_mikado_add_admin_field(
            array(
                'type' => 'yesno',
                'name' => 'pagination',
                'default_value' => 'yes',
                'label' => esc_html__('Pagination', 'sparks'),
                'parent' => $panel_blog_lists,
                'description' => esc_html__('Enabling this option will display pagination links on bottom of Blog Post List', 'sparks'),
                'args' => array(
                    'dependence' => true,
                    'dependence_hide_on_yes' => '',
                    'dependence_show_on_yes' => '#mkd_mkd_pagination_container'
                )
            )
        );

        $pagination_container = sparks_mikado_add_admin_container(
            array(
                'name' => 'mkd_pagination_container',
                'hidden_property' => 'pagination',
                'hidden_value' => 'no',
                'parent' => $panel_blog_lists,
            )
        );

        sparks_mikado_add_admin_field(
            array(
                'parent' => $pagination_container,
                'type' => 'text',
                'name' => 'blog_page_range',
                'default_value' => '',
                'label' => esc_html__('Pagination Range limit', 'sparks'),
                'description' => esc_html__('Enter a number that will limit pagination to a certain range of links', 'sparks'),
                'args' => array(
                    'col_width' => 3
                )
            )
        );
        sparks_mikado_add_admin_field(
            array(
                'type' => 'selectblank',
                'name' => 'pagination_type',
                'default_value' => 'standard_pagination',
                'label' => esc_html__('Pagination Type', 'sparks'),
                'parent' => $pagination_container,
                'description' => esc_html__('Choose Pagination Type', 'sparks'),
                'options' => array(
                    'standard_paginaton' => esc_html__('Standard Pagination', 'sparks'),
                    'load_more_pagination' => esc_html__('Load More', 'sparks')
                ),
                'args' => array(
                    'col_width' => 3
                )
            )
        );

        /* standard options */

        $panel_blog_standard = sparks_mikado_add_admin_panel(
            array(
                'page' => '_blog_page',
                'name' => 'panel_blog_standard',
                'title' => esc_html__('Blog Standard', 'sparks'),
                'hidden_property' => 'blog_list_standard_enable',
                'hidden_value' => 'no',
            )
        );

        sparks_mikado_add_admin_field(
            array(
                'name' => 'blog_list_standard_date_position',
                'type' => 'yesno',
                'label' => esc_html__('Date outside', 'sparks'),
                'description' => esc_html__('Date outside', 'sparks'),
                'parent' => $panel_blog_standard,
                'default_value' => 'yes',
            )
        );

        sparks_mikado_add_admin_field(array(
            'name' => 'blog_list_standard_separator',
            'type' => 'yesno',
            'label' => esc_html__('Show Separator', 'sparks'),
            'description' => esc_html__('Enabling this option will show separator below title on your blog list.', 'sparks'),
            'parent' => $panel_blog_standard,
            'default_value' => 'yes'
        ));

        sparks_mikado_add_admin_field(
            array(
                'type' => 'text',
                'name' => 'blog_list_standard_number_of_chars',
                'default_value' => '45',
                'label' => esc_html__('Number of Words in Excerpt', 'sparks'),
                'parent' => $panel_blog_standard,
                'description' => esc_html__('Enter a number of words in excerpt (article summary)', 'sparks'),
                'args' => array(
                    'col_width' => 3
                )
            )
        );

        sparks_mikado_add_admin_section_title(
            array(
                'parent' => $panel_blog_standard,
                'name' => 'post_info_title_blog_list_standard',
                'title' => esc_html__('Post Info', 'sparks')
            )
        );

        sparks_mikado_add_admin_field(array(
            'name' => 'blog_list_standard_category',
            'type' => 'yesno',
            'label' => esc_html__('Show Category', 'sparks'),
            'description' => esc_html__('Enabling this option will show category post info on your blog page.', 'sparks'),
            'parent' => $panel_blog_standard,
            'default_value' => 'yes'
        ));

        sparks_mikado_add_admin_field(array(
            'name' => 'blog_list_standard_date',
            'type' => 'yesno',
            'label' => esc_html__('Show Date', 'sparks'),
            'description' => esc_html__('Enabling this option will show date post info on your blog page.', 'sparks'),
            'parent' => $panel_blog_standard,
            'default_value' => 'yes'
        ));

        sparks_mikado_add_admin_field(array(
            'name' => 'blog_list_standard_author',
            'type' => 'yesno',
            'label' => esc_html__('Show Author', 'sparks'),
            'description' => esc_html__('Enabling this option will show author post info on your blog page.', 'sparks'),
            'parent' => $panel_blog_standard,
            'default_value' => 'no'
        ));

        sparks_mikado_add_admin_field(array(
            'name' => 'blog_list_standard_comment',
            'type' => 'yesno',
            'label' => esc_html__('Show Comments', 'sparks'),
            'description' => esc_html__('Enabling this option will show comments post info on your blog page.', 'sparks'),
            'parent' => $panel_blog_standard,
            'default_value' => 'yes'
        ));

        sparks_mikado_add_admin_field(array(
            'name' => 'blog_list_standard_like',
            'type' => 'yesno',
            'label' => esc_html__('Show Like', 'sparks'),
            'description' => esc_html__('Enabling this option will show like post info on your blog page.', 'sparks'),
            'parent' => $panel_blog_standard,
            'default_value' => 'no'
        ));

        sparks_mikado_add_admin_field(array(
            'name' => 'blog_list_standard_share',
            'type' => 'yesno',
            'label' => esc_html__('Show Share', 'sparks'),
            'description' => esc_html__('Enabling this option will show share post info on your blog page.', 'sparks'),
            'parent' => $panel_blog_standard,
            'default_value' => 'no'
        ));

        sparks_mikado_add_admin_field(array(
            'name' => 'blog_list_standard_read_more',
            'type' => 'yesno',
            'label' => esc_html__('Show Read More', 'sparks'),
            'description' => esc_html__('Enabling this option will show read more button on your blog page.', 'sparks'),
            'parent' => $panel_blog_standard,
            'default_value' => 'no'
        ));

        /* masonry options */

        $panel_blog_masonry = sparks_mikado_add_admin_panel(
            array(
                'page' => '_blog_page',
                'name' => 'panel_blog_masonry',
                'title' => esc_html__('Blog Masonry', 'sparks'),
                'hidden_property' => 'blog_list_masonry_enable',
                'hidden_value' => 'no'
            )
        );

        sparks_mikado_add_admin_field(array(
            'name' => 'blog_list_masonry_column',
            'type' => 'select',
            'label' => esc_html__('Number of Columns', 'sparks'),
            'description' => esc_html__('Choose number of columns for Blog Masonry', 'sparks'),
            'parent' => $panel_blog_masonry,
            'options' => array(
                'one' => esc_html__('One', 'sparks'),
                'two' => esc_html__('Two', 'sparks'),
                'three' => esc_html__('Three', 'sparks'),
                'four' => esc_html__('Four', 'sparks'),
                'five' => esc_html__('Five', 'sparks')
            ),
            'default_value' => 'three'
        ));

        sparks_mikado_add_admin_field(
            array(
                'type' => 'yesno',
                'name' => 'masonry_filter',
                'default_value' => 'no',
                'label' => esc_html__('Masonry Filter', 'sparks'),
                'parent' => $panel_blog_masonry,
                'description' => esc_html__('Enabling this option will display category filter on Masonry and Masonry Full Width Templates', 'sparks'),
                'args' => array(
                    'col_width' => 3
                )
            )
        );

        sparks_mikado_add_admin_field(array(
            'name' => 'blog_list_masonry_separator',
            'type' => 'yesno',
            'label' => esc_html__('Show Separator', 'sparks'),
            'description' => esc_html__('Enabling this option will show separator below title on your blog list.', 'sparks'),
            'parent' => $panel_blog_masonry,
            'default_value' => 'yes'
        ));

        sparks_mikado_add_admin_field(
            array(
                'type' => 'text',
                'name' => 'blog_list_masonry_number_of_chars',
                'default_value' => '45',
                'label' => esc_html__('Number of Words in Excerpt', 'sparks'),
                'parent' => $panel_blog_masonry,
                'description' => esc_html__('Enter a number of words in excerpt (article summary)', 'sparks'),
                'args' => array(
                    'col_width' => 3
                )
            )
        );

        sparks_mikado_add_admin_section_title(
            array(
                'parent' => $panel_blog_masonry,
                'name' => 'post_info_title_blog_list_masonry',
                'title' => esc_html__('Post Info', 'sparks')
            )
        );

        sparks_mikado_add_admin_field(array(
            'name' => 'blog_list_masonry_category',
            'type' => 'yesno',
            'label' => esc_html__('Show Category', 'sparks'),
            'description' => esc_html__('Enabling this option will show category post info on your blog page.', 'sparks'),
            'parent' => $panel_blog_masonry,
            'default_value' => 'yes'
        ));

        sparks_mikado_add_admin_field(array(
            'name' => 'blog_list_masonry_date',
            'type' => 'yesno',
            'label' => esc_html__('Show Date', 'sparks'),
            'description' => esc_html__('Enabling this option will show date post info on your blog page.', 'sparks'),
            'parent' => $panel_blog_masonry,
            'default_value' => 'yes'
        ));

        sparks_mikado_add_admin_field(array(
            'name' => 'blog_list_masonry_author',
            'type' => 'yesno',
            'label' => esc_html__('Show Author', 'sparks'),
            'description' => esc_html__('Enabling this option will show author post info on your blog page.', 'sparks'),
            'parent' => $panel_blog_masonry,
            'default_value' => 'no'
        ));

        sparks_mikado_add_admin_field(array(
            'name' => 'blog_list_masonry_comment',
            'type' => 'yesno',
            'label' => esc_html__('Show Comments', 'sparks'),
            'description' => esc_html__('Enabling this option will show comments post info on your blog page.', 'sparks'),
            'parent' => $panel_blog_masonry,
            'default_value' => 'yes'
        ));

        sparks_mikado_add_admin_field(array(
            'name' => 'blog_list_masonry_like',
            'type' => 'yesno',
            'label' => esc_html__('Show Like', 'sparks'),
            'description' => esc_html__('Enabling this option will show like post info on your blog page.', 'sparks'),
            'parent' => $panel_blog_masonry,
            'default_value' => 'no'
        ));

        sparks_mikado_add_admin_field(array(
            'name' => 'blog_list_masonry_share',
            'type' => 'yesno',
            'label' => esc_html__('Show Share', 'sparks'),
            'description' => esc_html__('Enabling this option will show share post info on your blog page.', 'sparks'),
            'parent' => $panel_blog_masonry,
            'default_value' => 'yes'
        ));

        sparks_mikado_add_admin_field(array(
            'name' => 'blog_list_masonry_read_more',
            'type' => 'yesno',
            'label' => esc_html__('Show Read More', 'sparks'),
            'description' => esc_html__('Enabling this option will show read more button on your blog page.', 'sparks'),
            'parent' => $panel_blog_masonry,
            'default_value' => 'no'
        ));

        /**
         * Blog Single
         */
        $panel_blog_single = sparks_mikado_add_admin_panel(
            array(
                'page' => '_blog_page',
                'name' => 'panel_blog_single',
                'title' => esc_html__('Blog Single', 'sparks')
            )
        );


        sparks_mikado_add_admin_field(array(
            'name' => 'blog_single_sidebar_layout',
            'type' => 'select',
            'label' => esc_html__('Sidebar Layout', 'sparks'),
            'description' => esc_html__('Choose a sidebar layout for Blog Single pages', 'sparks'),
            'parent' => $panel_blog_single,
            'options' => array(
                'default' => esc_html__('No Sidebar', 'sparks'),
                'sidebar-33-right' => esc_html__('Sidebar 1/3 Right', 'sparks'),
                'sidebar-25-right' => esc_html__('Sidebar 1/4 Right', 'sparks'),
                'sidebar-33-left' => esc_html__('Sidebar 1/3 Left', 'sparks'),
                'sidebar-25-left' => esc_html__('Sidebar 1/4 Left', 'sparks')
            ),
            'default_value' => 'default'
        ));


        if (count($custom_sidebars) > 0) {
            sparks_mikado_add_admin_field(array(
                'name' => 'blog_single_custom_sidebar',
                'type' => 'selectblank',
                'label' => esc_html__('Sidebar to Display', 'sparks'),
                'description' => esc_html__('Choose a sidebar to display on Blog Single pages. Default sidebar is "Sidebar"', 'sparks'),
                'parent' => $panel_blog_single,
                'options' => sparks_mikado_get_custom_sidebars(),
                'args' => array(
                    'select2' => true
                )
            ));
        }

        sparks_mikado_add_admin_field(array(
            'name' => 'blog_single_title_in_title_area',
            'type' => 'yesno',
            'label' => esc_html__('Show Post Title in Title Area', 'sparks'),
            'description' => esc_html__('Enabling this option will show post title in title area on single post pages', 'sparks'),
            'parent' => $panel_blog_single,
            'default_value' => 'no'
        ));

        sparks_mikado_add_admin_field(array(
            'name' => 'blog_single_separator',
            'type' => 'yesno',
            'label' => esc_html__('Show Separator', 'sparks'),
            'description' => esc_html__('Enabling this option will show separator post info on your single post page.', 'sparks'),
            'parent' => $panel_blog_single,
            'default_value' => 'yes'
        ));

        //Post Info
        sparks_mikado_add_admin_section_title(
            array(
                'parent' => $panel_blog_single,
                'name' => 'post_info_title_blog_single',
                'title' => esc_html__('Post Info', 'sparks')
            )
        );

        sparks_mikado_add_admin_field(array(
            'name' => 'blog_single_date',
            'type' => 'yesno',
            'label' => esc_html__('Show Date', 'sparks'),
            'description' => esc_html__('Enabling this option will show date post info on your single post page.', 'sparks'),
            'parent' => $panel_blog_single,
            'default_value' => 'yes'
        ));

        sparks_mikado_add_admin_field(array(
            'name' => 'blog_single_author',
            'type' => 'yesno',
            'label' => esc_html__('Show Author', 'sparks'),
            'description' => esc_html__('Enabling this option will show author post info on your single post page.', 'sparks'),
            'parent' => $panel_blog_single,
            'default_value' => 'yes'
        ));

        sparks_mikado_add_admin_field(array(
            'name' => 'blog_single_comments',
            'type' => 'yesno',
            'label' => esc_html__('Show Comments', 'sparks'),
            'description' => esc_html__('Enabling this option will show comments post info on your single post page.', 'sparks'),
            'parent' => $panel_blog_single,
            'default_value' => 'yes'
        ));

        sparks_mikado_add_admin_field(array(
            'name' => 'blog_single_like',
            'type' => 'yesno',
            'label' => esc_html__('Show Like', 'sparks'),
            'description' => esc_html__('Enabling this option will show like post info on your single post page.', 'sparks'),
            'parent' => $panel_blog_single,
            'default_value' => 'yes'
        ));

        sparks_mikado_add_admin_field(array(
            'name' => 'blog_single_share',
            'type' => 'yesno',
            'label' => esc_html__('Show Share', 'sparks'),
            'description' => esc_html__('Enabling this option will show share post info on your single post page.', 'sparks'),
            'parent' => $panel_blog_single,
            'default_value' => 'yes'
        ));

        sparks_mikado_add_admin_field(array(
            'name' => 'blog_single_tags',
            'type' => 'yesno',
            'label' => esc_html__('Show Tags', 'sparks'),
            'description' => esc_html__('Enabling this option will show post tags on your single post page.', 'sparks'),
            'parent' => $panel_blog_single,
            'default_value' => 'yes'
        ));

        //Post Info Category

        sparks_mikado_add_admin_section_title(
            array(
                'parent' => $panel_blog_single,
                'name' => 'post_info_category_title_blog_single',
                'title' => esc_html__('Category', 'sparks')
            )
        );

        sparks_mikado_add_admin_field(array(
            'name' => 'blog_single_category',
            'type' => 'yesno',
            'label' => esc_html__('Show Category', 'sparks'),
            'description' => esc_html__('Enabling this option will show category post info on your single post page.', 'sparks'),
            'parent' => $panel_blog_single,
            'default_value' => 'yes',
        ));

        sparks_mikado_add_admin_section_title(
            array(
                'parent' => $panel_blog_single,
                'name' => 'navigation_title_blog_single',
                'title' => esc_html__('Navigation', 'sparks')
            )
        );

        sparks_mikado_add_admin_field(
            array(
                'type' => 'yesno',
                'name' => 'blog_single_navigation',
                'default_value' => 'no',
                'label' => esc_html__('Enable Prev/Next Single Post Navigation Links', 'sparks'),
                'parent' => $panel_blog_single,
                'description' => esc_html__('Enable navigation links through the blog posts (left and right arrows will appear)', 'sparks'),
                'args' => array(
                    'dependence' => true,
                    'dependence_hide_on_yes' => '',
                    'dependence_show_on_yes' => '#mkd_mkd_blog_single_navigation_container'
                )
            )
        );

        $blog_single_navigation_container = sparks_mikado_add_admin_container(
            array(
                'name' => 'mkd_blog_single_navigation_container',
                'hidden_property' => 'blog_single_navigation',
                'hidden_value' => 'no',
                'parent' => $panel_blog_single,
            )
        );

        sparks_mikado_add_admin_field(
            array(
                'type' => 'yesno',
                'name' => 'blog_navigation_through_same_category',
                'default_value' => 'no',
                'label' => esc_html__('Enable Navigation Only in Current Category', 'sparks'),
                'description' => esc_html__('Limit your navigation only through current category', 'sparks'),
                'parent' => $blog_single_navigation_container,
                'args' => array(
                    'col_width' => 3
                )
            )
        );

        sparks_mikado_add_admin_section_title(
            array(
                'parent' => $panel_blog_single,
                'name' => 'author_info_box_title_blog_single',
                'title' => esc_html__('Author', 'sparks')
            )
        );

        sparks_mikado_add_admin_field(
            array(
                'type' => 'yesno',
                'name' => 'blog_author_info',
                'default_value' => 'no',
                'label' => esc_html__('Show Author Info Box', 'sparks'),
                'parent' => $panel_blog_single,
                'description' => esc_html__('Enabling this option will display author name and descriptions on Blog Single pages', 'sparks'),
                'args' => array(
                    'dependence' => true,
                    'dependence_hide_on_yes' => '',
                    'dependence_show_on_yes' => '#mkd_mkd_blog_single_author_info_container'
                )
            )
        );

        $blog_single_author_info_container = sparks_mikado_add_admin_container(
            array(
                'name' => 'mkd_blog_single_author_info_container',
                'hidden_property' => 'blog_author_info',
                'hidden_value' => 'no',
                'parent' => $panel_blog_single,
            )
        );

        sparks_mikado_add_admin_field(
            array(
                'type' => 'yesno',
                'name' => 'blog_author_info_email',
                'default_value' => 'no',
                'label' => esc_html__('Show Author Email', 'sparks'),
                'description' => esc_html__('Enabling this option will show author email', 'sparks'),
                'parent' => $blog_single_author_info_container,
                'args' => array(
                    'col_width' => 3
                )
            )
        );

        sparks_mikado_add_admin_section_title(
            array(
                'parent' => $panel_blog_single,
                'name' => 'related_posts_blog_single',
                'title' => esc_html__('Related Posts', 'sparks')
            )
        );


        sparks_mikado_add_admin_field(array(
            'name' => 'blog_single_related_posts',
            'type' => 'yesno',
            'label' => esc_html__('Show Related Posts', 'sparks'),
            'description' => esc_html__('Enabling this option will show related posts on your single post page.', 'sparks'),
            'parent' => $panel_blog_single,
            'default_value' => 'no',
            'args' => array(
                'dependence' => true,
                'dependence_hide_on_yes' => '',
                'dependence_show_on_yes' => '#mkd_related_image_container'
            )
        ));

        $related_image_container = sparks_mikado_add_admin_container(
            array(
                'name' => 'related_image_container',
                'hidden_property' => 'blog_single_related_posts',
                'hidden_value' => 'no',
                'parent' => $panel_blog_single,
            )
        );

        sparks_mikado_add_admin_field(
            array(
                'type' => 'text',
                'name' => 'blog_single_related_image_size',
                'default_value' => '',
                'label' => esc_html__('Related Posts Image Max Width', 'sparks'),
                'parent' => $related_image_container,
                'description' => esc_html__('Define maximum width for related posts images on your single post pages. Default value is 1200', 'sparks'),
                'args' => array(
                    'col_width' => 3
                )
            )
        );
    }

    add_action('sparks_mikado_options_map', 'sparks_mikado_blog_options_map', 11);

}











