<?php

if (!function_exists('sparks_mikado_woocommerce_products_per_page')) {
    /**
     * Function that sets number of products per page. Default is 12
     * @return int number of products to be shown per page
     */
    function sparks_mikado_woocommerce_products_per_page() {

        $products_per_page = 12;

        if (sparks_mikado_options()->getOptionValue('mkd_woo_products_per_page')) {
            $products_per_page = sparks_mikado_options()->getOptionValue('mkd_woo_products_per_page');
        }
        if (isset($_GET['woo-products-count']) && $_GET['woo-products-count'] === 'view-all') {
            $products_per_page = 9999;
        }

        return $products_per_page;
    }
}

if (!function_exists('sparks_mikado_woocommerce_related_products_args')) {
    /**
     * Function that sets number of displayed related products. Hooks to woocommerce_output_related_products_args filter
     * @param $args array array of args for the query
     * @return mixed array of changed args
     */
    function sparks_mikado_woocommerce_related_products_args($args) {

        if (sparks_mikado_options()->getOptionValue('mkd_woo_product_list_columns')) {

            $related = sparks_mikado_options()->getOptionValue('mkd_woo_product_list_columns');
            switch ($related) {
                case 'mkd-woocommerce-columns-4':
                    $args['posts_per_page'] = 4;
                    break;
                case 'mkd-woocommerce-columns-3':
                    $args['posts_per_page'] = 3;
                    break;
                default:
                    $args['posts_per_page'] = 3;
            }

        } else {
            $args['posts_per_page'] = 3;
        }

        return $args;
    }
}

if (!function_exists('sparks_mikado_woocommerce_template_loop_product_title')) {
    /**
     * Function for overriding product title template in Product List Loop
     */
    function sparks_mikado_woocommerce_template_loop_product_title() {

        $tag = sparks_mikado_options()->getOptionValue('mkd_products_list_title_tag');
        if ($tag === '') {
            $tag = 'h4';
        }
        the_title('<' . $tag . ' class="mkd-product-list-title"><a href="' . get_the_permalink() . '">', '</a></' . $tag . '>');
    }
}

if (!function_exists('sparks_mikado_woocommerce_single_add_pretty_photo_for_images')) {
    /**
     * Function that add necessary html attributes for prettyPhoto
     */
    function sparks_mikado_woocommerce_single_add_pretty_photo_for_images($html, $attachment_id) {
        $our_html = '';

        if (!empty($html)) {
            $full_size_image = wp_get_attachment_image_src($attachment_id, 'full');

            $attributes = array(
                'data-src' => $full_size_image[0],
                'data-large_image' => $full_size_image[0],
                'data-large_image_width' => $full_size_image[1],
                'data-large_image_height' => $full_size_image[2],
            );

            $our_html .= '<div class="woocommerce-product-gallery__image"><a href="' . esc_url($full_size_image[0]) . '" data-rel="prettyPhoto[woo_single_pretty_photo]">';
            $our_html .= wp_get_attachment_image($attachment_id, 'shop_single', false, $attributes);
            $our_html .= '</a></div>';

            $html = $our_html;
        }

        return $html;
    }

    add_filter('woocommerce_single_product_image_thumbnail_html', 'sparks_mikado_woocommerce_single_add_pretty_photo_for_images', 10, 2);
}

if (!function_exists('sparks_mikado_woocommerce_template_single_title')) {
    /**
     * Function for overriding product title template in Single Product template
     */
    function sparks_mikado_woocommerce_template_single_title() {

        $tag = sparks_mikado_options()->getOptionValue('mkd_single_product_title_tag');
        if ($tag === '') {
            $tag = 'h1';
        }
        the_title('<' . $tag . '  itemprop="name" class="mkd-single-product-title">', '</' . $tag . '>');
    }
}

if (!function_exists('sparks_mikado_woocommerce_sale_flash')) {
    /**
     * Function for overriding Sale Flash Template
     *
     * @return string
     */
    function sparks_mikado_woocommerce_sale_flash() {

        return '<span class="mkd-onsale">' . esc_html__('SALE', 'sparks') . '</span>';
    }
}

if (!function_exists('sparks_mikado_woocommerce_product_out_of_stock')) {
    /**
     * Function for adding Out Of Stock Template
     *
     * @return string
     */
    function sparks_mikado_woocommerce_product_out_of_stock() {

        global $product;

        if (!$product->is_in_stock()) {
            print '<span class="mkd-out-of-stock">' . esc_html__('OUT OF STOCK', 'sparks') . '</span>';
        }
    }
}

if (!function_exists('sparks_mikado_woocommerce_view_all_pagination')) {
    /**
     * Function for adding New WooCommerce Pagination Template
     *
     * @return string
     */
    function sparks_mikado_woocommerce_view_all_pagination() {

        global $wp_query;

        if ($wp_query->max_num_pages <= 1) {
            return;
        }

        $html = '';

        if (get_option('woocommerce_shop_page_id')) {
            $html .= '<div class="mkd-woo-view-all-pagination">';
            $html .= '<a href="' . get_permalink(get_option('woocommerce_shop_page_id')) . '?woo-products-count=view-all">' . esc_html__('View All', 'sparks') . '</a>';
            $html .= '</div>';
        }

		echo sparks_mikado_get_module_part($html);
    }
}

if (!function_exists('sparks_mikado_woo_view_all_pagination_additional_tag_before')) {
    function sparks_mikado_woo_view_all_pagination_additional_tag_before() {

        print '<div class="mkd-woo-pagination-holder"><div class="mkd-woo-pagination-inner">';
    }
}

if (!function_exists('sparks_mikado_woo_view_all_pagination_additional_tag_after')) {
    function sparks_mikado_woo_view_all_pagination_additional_tag_after() {

        print '</div></div>';
    }
}

if (!function_exists('sparks_mikado_single_product_content_additional_tag_before')) {
    function sparks_mikado_single_product_content_additional_tag_before() {

        print '<div class="mkd-single-product-content">';
    }
}

if (!function_exists('sparks_mikado_single_product_content_additional_tag_after')) {
    function sparks_mikado_single_product_content_additional_tag_after() {

        print '</div>';
    }
}

if (!function_exists('sparks_mikado_single_product_summary_additional_tag_before')) {
    function sparks_mikado_single_product_summary_additional_tag_before() {

        print '<div class="mkd-single-product-summary">';
    }
}

if (!function_exists('sparks_mikado_single_product_summary_additional_tag_after')) {
    function sparks_mikado_single_product_summary_additional_tag_after() {

        print '</div>';
    }
}

if (!function_exists('sparks_mikado_pl_holder_additional_tag_before')) {
    function sparks_mikado_pl_holder_additional_tag_before() {

        print '<div class="mkd-pl-main-holder">';
    }
}

if (!function_exists('sparks_mikado_pl_holder_additional_tag_after')) {
    function sparks_mikado_pl_holder_additional_tag_after() {

        print '</div>';
    }
}

if (!function_exists('sparks_mikado_pl_inner_additional_tag_before')) {
    function sparks_mikado_pl_inner_additional_tag_before() {

        print '<div class="mkd-pl-inner">';
    }
}

if (!function_exists('sparks_mikado_pl_inner_additional_tag_after')) {
    function sparks_mikado_pl_inner_additional_tag_after() {

        print '</div>';
    }
}

if (!function_exists('sparks_mikado_pl_image_additional_tag_before')) {
    function sparks_mikado_pl_image_additional_tag_before() {

        print '<div class="mkd-pl-image">';
    }
}

if (!function_exists('sparks_mikado_pl_image_additional_tag_after')) {
    function sparks_mikado_pl_image_additional_tag_after() {

        print '</div>';
    }
}

if (!function_exists('sparks_mikado_pl_inner_text_additional_tag_before')) {
    function sparks_mikado_pl_inner_text_additional_tag_before() {

        print '<div class="mkd-pl-text"><div class="mkd-pl-text-outer"><div class="mkd-pl-text-inner">';
    }
}

if (!function_exists('sparks_mikado_pl_inner_text_additional_tag_after')) {
    function sparks_mikado_pl_inner_text_additional_tag_after() {

        print '</div></div></div>';
    }
}

if (!function_exists('sparks_mikado_pl_text_wrapper_additional_tag_before')) {
    function sparks_mikado_pl_text_wrapper_additional_tag_before() {

        print '<div class="mkd-pl-text-wrapper">';
    }
}

if (!function_exists('sparks_mikado_pl_text_wrapper_additional_tag_after')) {
    function sparks_mikado_pl_text_wrapper_additional_tag_after() {

        print '</div>';
    }
}

if (!function_exists('sparks_mikado_pl_rating_additional_tag_before')) {
    function sparks_mikado_pl_rating_additional_tag_before() {
        global $product;

        if (get_option('woocommerce_enable_review_rating') !== 'no') {

            // woo 3.0
            if (function_exists('wc_get_rating_html')) {
                $rating_html = wc_get_rating_html($product->get_average_rating());
            } else {
                $rating_html = $product->get_rating_html();
            }
            if ($rating_html !== '') {
                print '<div class="mkd-pl-rating-holder">';
            }
        }
    }
}

if (!function_exists('sparks_mikado_pl_rating_additional_tag_after')) {
    function sparks_mikado_pl_rating_additional_tag_after() {
        global $product;

        if (get_option('woocommerce_enable_review_rating') !== 'no') {

            // woo 3.0
            if (function_exists('wc_get_rating_html')) {
                $rating_html = wc_get_rating_html($product->get_average_rating());
            } else {
                $rating_html = $product->get_rating_html();
            }
            if ($rating_html !== '') {
                print '</div>';
            }
        }
    }
}

//if (!function_exists('sparks_mikado_woocommerce_add_to_cart_html_part')) {
//    /**
//     * Function for adding Add To Cart Button html part for shortcodes
//     *
//     * @return string
//     */
//    function sparks_mikado_woocommerce_add_to_cart_html_part($class_name = '', $button_skin = '') {
//        global $product;
//
//        $buttonSkinClass = '';
//        if (!empty($button_skin)) {
//            $buttonSkinClass = 'mkd-' . $button_skin . '-skin';
//        }
//
//        if (!$product->is_in_stock()) {
//            $button_classes = 'button ajax_add_to_cart mkd-button';
//        } else if ($product->product_type === 'variable') {
//            $button_classes = 'button product_type_variable add_to_cart_button mkd-button';
//        } else if ($product->product_type === 'external') {
//            $button_classes = 'button product_type_external mkd-button';
//        } else {
//            $button_classes = 'button add_to_cart_button ajax_add_to_cart mkd-button';
//        }
//        $html = '';
//
//        $html .= '<div class="mkd-' . esc_attr($class_name) . '-add-to-cart ' . esc_attr($buttonSkinClass) . '">';
//        $html .= apply_filters('sparks_mikado_product_list_add_to_cart_link',
//            sprintf('<a rel="nofollow" href="%s" data-quantity="%s" data-product_id="%s" data-product_sku="%s" class="%s">%s</a>',
//                esc_url($product->add_to_cart_url()),
//                esc_attr(isset($quantity) ? $quantity : 1),
//                esc_attr($product->id),
//                esc_attr($product->get_sku()),
//                esc_attr($button_classes),
//                esc_html($product->add_to_cart_text())
//            ),
//            $product);
//        $html .= '</div>';
//
//        return $html;
//    }
//}

if (!function_exists('sparks_mikado_woocommerce_image_html_part')) {
    /**
     * Function for adding Image html part for shortcodes
     *
     * @return string
     */
    function sparks_mikado_woocommerce_image_html_part($class_name = '', $image_size = '', $hover_image = '') {

        $html = '';

        /*if ($product->is_on_sale()) {
            $html .= '<span class="mkd-' . esc_attr($class_name) . '-onsale">' . esc_html__('Sale', 'sparks') . '</span>';
        }
        if (!$product->is_in_stock()) {
            $html .= '<span class="mkd-' . esc_attr($class_name) . '-out-of-stock">' . esc_html__('Out of Stock', 'sparks') . '</span>';
        }*/

        $product_image_size = 'shop_catalog';
        if ($image_size === 'full') {
            $product_image_size = 'full';
        } else if ($image_size === 'square') {
            $product_image_size = 'sparks_mikado_image_square';
        } else if ($image_size === 'landscape') {
            $product_image_size = 'sparks_mikado_image_landscape';
        } else if ($image_size === 'portrait') {
            $product_image_size = 'sparks_mikado_image_portrait';
        } else if ($image_size === 'medium') {
            $product_image_size = 'medium';
        } else if ($image_size === 'large') {
            $product_image_size = 'large';
        }

        $html .= get_the_post_thumbnail(get_the_ID(), apply_filters('sparks_mikado_product_list_image_size', $product_image_size));

        if (!empty($hover_image)) {
            $html .= '<img class="mkd-' . esc_attr($class_name) . '-hover-image" src="' . esc_url($hover_image) . '" alt="' . esc_attr__('Product List Hover Image', 'sparks') . '" />';
        }

        return $html;
    }
}


if (!function_exists('sparks_mikado_woocommerce_on_sale_html_part')) {
    /**
     * Function for adding on sale tag
     *
     * @return string
     */
    function sparks_mikado_woocommerce_on_sale_html_part($class_name = '') {
        global $product;

        $html = '';

        if ($product->is_on_sale()) {
            $html .= '<span class="mkd-' . esc_attr($class_name) . '-onsale">' . esc_html__('Sale', 'sparks') . '</span>';
        }
        if (!$product->is_in_stock()) {
            $html .= '<span class="mkd-' . esc_attr($class_name) . '-out-of-stock">' . esc_html__('Out of Stock', 'sparks') . '</span>';
        }

        return $html;
    }
}


if (!function_exists('sparks_mikado_woocommerce_title_html_part')) {
    /**
     * Function for adding Title html part for shortcodes
     *
     * @return string
     */
    function sparks_mikado_woocommerce_title_html_part($class_name = '', $title_tag = '', $has_link = '', $title_styles = '') {

        if ($has_link === 'yes') {
            $html = '<' . esc_attr($title_tag) . ' itemprop="name" class="entry-title mkd-' . esc_attr($class_name) . '-title" ' . sparks_mikado_get_inline_style($title_styles) . '><a itemprop="url" href="' . get_the_permalink() . '">' . get_the_title() . '</a></' . esc_attr($title_tag) . '>';
        } else {
            $html = '<' . esc_attr($title_tag) . ' itemprop="name" class="entry-title mkd-' . esc_attr($class_name) . '-title" ' . sparks_mikado_get_inline_style($title_styles) . '>' . get_the_title() . '</' . esc_attr($title_tag) . '>';
        }

        return $html;
    }
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////

if (!function_exists('sparks_mikado_woocommerce_category_html_part')) {
    /**
     * Function for adding Category html part for shortcodes
     *
     * @return string
     */
    function sparks_mikado_woocommerce_category_html_part($class_name = '') {
        global $product;

        $html = '';

        // woo 3.0
        if (function_exists('wc_get_product_category_list')) {
            $product_categories = wc_get_product_category_list($product->get_id(), ', ');
        } else {
            $product_categories = $product->get_categories(', ');
        }
        if (!empty($product_categories)) {

            $html = '<h6 class="mkd-' . esc_attr($class_name) . '-category">' . $product_categories . '</h6>';
        }

        return $html;
    }
}

if (!function_exists('sparks_mikado_woocommerce_excerpt_html_part')) {
    /**
     * Function for adding Excerpt html part for shortcodes
     *
     * @return string
     */
    function sparks_mikado_woocommerce_excerpt_html_part($class_name = '', $excerpt_length = 0) {

        $excerpt = ($excerpt_length > 0) ? substr(get_the_excerpt(), 0, intval($excerpt_length)) : get_the_excerpt();

        $html = '<p itemprop="description" class="mkd-' . esc_attr($class_name) . '-excerpt">' . esc_html($excerpt) . '</p>';

        return $html;
    }
}

if (!function_exists('sparks_mikado_woocommerce_rating_html_part')) {
    /**
     * Function for adding Rating html part for shortcodes
     *
     * @return string
     */
    function sparks_mikado_woocommerce_rating_html_part($class_name = '') {
        global $product;

        $html = '';

        if (get_option('woocommerce_enable_review_rating') !== 'no') {
            $average = $product->get_average_rating();

            $html = '<div class="mkd-' . esc_attr($class_name) . '-rating-holder"><div class="mkd-' . esc_attr($class_name) . '-rating" title="' . sprintf(esc_attr__("Rated %s out of 5", "sparks"), $average) . '"><span style="width:' . (($average / 5) * 100) . '%"></span></div></div>';
        }

        return $html;
    }
}

if (!function_exists('sparks_mikado_woocommerce_price_html_part')) {
    /**
     * Function for adding Price html part for shortcodes
     *
     * @return string
     */
    function sparks_mikado_woocommerce_price_html_part($class_name = '') {
        global $product;

        $html = '';

        if ($price_html = $product->get_price_html()) {
            $html = '<div class="mkd-' . esc_attr($class_name) . '-price">' . $price_html . '</div>';
        }

        return $html;
    }
}

if (!function_exists('sparks_mikado_woocommerce_add_to_cart_html_part')) {
    /**
     * Function for adding Add To Cart Button html part for shortcodes
     *
     * @return string
     */
    function sparks_mikado_woocommerce_add_to_cart_html_part($class_name = '', $button_skin = '') {
        global $product;


        if (version_compare(WOOCOMMERCE_VERSION, '3.0') >= 0) {
            $product_type = $product->get_type();
            $product_id = $product->get_id();
        } else {
            $product_type = $product->product_type;
            $product_id = $product->id;
        }

        $buttonSkinClass = '';
        if (!empty($button_skin)) {
            $buttonSkinClass = 'mkd-' . $button_skin . '-skin';
        }

        if (!$product->is_in_stock()) {
            $button_classes = 'button ajax_add_to_cart mkd-button';
        } else if ($product_type === 'variable') {
            $button_classes = 'button product_type_variable add_to_cart_button mkd-button';
        } else if ($product_type === 'external') {
            $button_classes = 'button product_type_external mkd-button';
        } else {
            $button_classes = 'button add_to_cart_button ajax_add_to_cart mkd-button';
        }
        $html = '';

        $html .= '<div class="mkd-' . esc_attr($class_name) . '-add-to-cart ' . esc_attr($buttonSkinClass) . '">';
        $html .= apply_filters('sparks_mikado_product_list_add_to_cart_link',
            sprintf('<a rel="nofollow" href="%s" data-quantity="%s" data-product_id="%s" data-product_sku="%s" class="%s">%s</a>',
                esc_url($product->add_to_cart_url()),
                esc_attr(isset($quantity) ? $quantity : 1),
                esc_attr($product_id),
                esc_attr($product->get_sku()),
                esc_attr($button_classes),
                esc_html($product->add_to_cart_text())
            ),
            $product);
        $html .= '</div>';

        return $html;
    }
}

if (!function_exists('sparks_mikado_woocommerce_no_products_found_html_part')) {
    /**
     * Function for adding No products were found html part for shortcodes
     *
     * @return string
     */
    function sparks_mikado_woocommerce_no_products_found_html_part($class_name = '') {

        $html = '<div class="mkd-' . esc_attr($class_name) . '-messsage"><p>' . esc_html__('No products were found!', 'sparks') . '</p></div>';

        return $html;
    }
}

if (!function_exists('sparks_mikado_woocommerce_product_thumbnail_columns')) {
    /*
     * set number of columns for thumbs in product single
     */
    function sparks_mikado_woocommerce_product_thumbnail_columns() {
        return 3;
    }

    add_filter('woocommerce_product_thumbnails_columns', 'sparks_mikado_woocommerce_product_thumbnail_columns', 10, 2);
}