<?php
include_once get_template_directory() . '/theme-includes.php';

if (!function_exists('sparks_mikado_styles')) {
    /**
     * Function that includes theme's core styles
     */
    function sparks_mikado_styles() {
        wp_register_style('sparks-mikado-blog', MIKADO_ASSETS_ROOT . '/css/blog.min.css');

        //include theme's core styles
        wp_enqueue_style('sparks-mikado-default-style', MIKADO_ROOT . '/style.css');
        wp_enqueue_style('sparks-mikado-modules-plugins', MIKADO_ASSETS_ROOT . '/css/plugins.min.css');
        wp_enqueue_style('sparks-mikado-modules', MIKADO_ASSETS_ROOT . '/css/modules.min.css');

        sparks_mikado_icon_collections()->enqueueStyles();

        if (sparks_mikado_load_blog_assets()) {
            wp_enqueue_style('sparks-mikado-blog');
        }

        if (sparks_mikado_load_blog_assets() || is_singular('portfolio-item')) {
            wp_enqueue_style('wp-mediaelement');
        }

        //define files afer which style dynamic needs to be included. It should be included last so it can override other files
        $style_dynamic_deps_array = array();

        //is woocommerce installed?
        if (sparks_mikado_is_woocommerce_installed()) {
            if (sparks_mikado_load_woo_assets() || sparks_mikado_is_ajax_enabled()) {

                //include theme's woocommerce styles
                wp_enqueue_style('sparks-mikado-woo', MIKADO_ASSETS_ROOT . '/css/woocommerce.min.css');
            }
        }

        if (sparks_mikado_load_woo_assets() || sparks_mikado_is_ajax_enabled()) {
            $style_dynamic_deps_array = array('sparks-mikado-woo', 'sparks-mikado-woo-responsive');
        }

        if (file_exists(MIKADO_ROOT_DIR . '/assets/css/style_dynamic.css') && sparks_mikado_is_css_folder_writable() && !is_multisite()) {
            wp_enqueue_style('sparks-mikado-style-dynamic', MIKADO_ASSETS_ROOT . '/css/style_dynamic.css', $style_dynamic_deps_array, filemtime(MIKADO_ROOT_DIR . '/assets/css/style_dynamic.css')); //it must be included after woocommerce styles so it can override it
        }

        //is responsive option turned on?
        if (sparks_mikado_is_responsive_on()) {
            wp_enqueue_style('sparks-mikado-modules-responsive', MIKADO_ASSETS_ROOT . '/css/modules-responsive.min.css');
            wp_enqueue_style('sparks-mikado-blog-responsive', MIKADO_ASSETS_ROOT . '/css/blog-responsive.min.css');

            //is woocommerce installed?
            if (sparks_mikado_is_woocommerce_installed()) {
                if (sparks_mikado_load_woo_assets() || sparks_mikado_is_ajax_enabled()) {

                    //include theme's woocommerce responsive styles
                    wp_enqueue_style('sparks-mikado-woo-responsive', MIKADO_ASSETS_ROOT . '/css/woocommerce-responsive.min.css');
                }
            }

            //include proper styles
            if (file_exists(MIKADO_ROOT_DIR . '/assets/css/style_dynamic_responsive.css') && sparks_mikado_is_css_folder_writable() && !is_multisite()) {
                wp_enqueue_style('sparks-mikado-style-dynamic-responsive', MIKADO_ASSETS_ROOT . '/css/style_dynamic_responsive.css', array(), filemtime(MIKADO_ROOT_DIR . '/assets/css/style_dynamic_responsive.css'));
            }
        }

        //include Visual Composer styles
        if (class_exists('WPBakeryVisualComposerAbstract')) {
            wp_enqueue_style('js_composer_front');
        }
    }

    add_action('wp_enqueue_scripts', 'sparks_mikado_styles');
}

if (!function_exists('sparks_mikado_google_fonts_styles')) {
    /**
     * Function that includes google fonts defined anywhere in the theme
     */
    function sparks_mikado_google_fonts_styles() {
        $font_simple_field_array = sparks_mikado_options()->getOptionsByType('fontsimple');
        if (!(is_array($font_simple_field_array) && count($font_simple_field_array) > 0)) {
            $font_simple_field_array = array();
        }

        $font_field_array = sparks_mikado_options()->getOptionsByType('font');
        if (!(is_array($font_field_array) && count($font_field_array) > 0)) {
            $font_field_array = array();
        }

        $available_font_options = array_merge($font_simple_field_array, $font_field_array);

        $google_font_weight_array = sparks_mikado_options()->getOptionValue('google_font_weight');
        if (!empty($google_font_weight_array)) {
            $google_font_weight_array = array_slice(sparks_mikado_options()->getOptionValue('google_font_weight'), 1);
        }

        $font_weight_str = '100,300,400,500,700';
        if (!empty($google_font_weight_array) && $google_font_weight_array !== '') {
            $font_weight_str = implode(',', $google_font_weight_array);
        }

        $google_font_subset_array = sparks_mikado_options()->getOptionValue('google_font_subset');
        if (!empty($google_font_subset_array)) {
            $google_font_subset_array = array_slice(sparks_mikado_options()->getOptionValue('google_font_subset'), 1);
        }

        $font_subset_str = 'latin-ext';
        if (!empty($google_font_subset_array) && $google_font_subset_array !== '') {
            $font_subset_str = implode(',', $google_font_subset_array);
        }

        //define available font options array
        $fonts_array = array();
        foreach ($available_font_options as $font_option) {
            //is font set and not set to default and not empty?
            $font_option_value = sparks_mikado_options()->getOptionValue($font_option);
            if (sparks_mikado_is_font_option_valid($font_option_value) && !sparks_mikado_is_native_font($font_option_value)) {
                $font_option_string = $font_option_value . ':' . $font_weight_str;
                if (!in_array($font_option_string, $fonts_array)) {
                    $fonts_array[] = $font_option_string;
                }
            }
        }

        wp_reset_postdata();

        $fonts_array = array_diff($fonts_array, array('-1:' . $font_weight_str));
        $google_fonts_string = implode('|', $fonts_array);

        //default fonts should be separated with %7C because of HTML validation
        $default_font_string = 'Rubik:' . $font_weight_str . '|Roboto:' . $font_weight_str;
        $protocol = is_ssl() ? 'https:' : 'http:';

        //is google font option checked anywhere in theme?
        if (count($fonts_array) > 0) {

            //include all checked fonts
            $fonts_full_list = $default_font_string . '|' . str_replace('+', ' ', $google_fonts_string);
            $fonts_full_list_args = array(
                'family' => urlencode($fonts_full_list),
                'subset' => urlencode($font_subset_str),
            );

            $sparks_fonts = add_query_arg($fonts_full_list_args, $protocol . '//fonts.googleapis.com/css');
            wp_enqueue_style('sparks-mikado-google-fonts', esc_url_raw($sparks_fonts), array(), '1.0.0');

        } else {
            //include default google font that theme is using
            $default_fonts_args = array(
                'family' => urlencode($default_font_string),
                'subset' => urlencode($font_subset_str),
            );
            $sparks_fonts = add_query_arg($default_fonts_args, $protocol . '//fonts.googleapis.com/css');
            wp_enqueue_style('sparks-mikado-google-fonts', esc_url_raw($sparks_fonts), array(), '1.0.0');
        }

    }

    add_action('wp_enqueue_scripts', 'sparks_mikado_google_fonts_styles');
}

if (!function_exists('sparks_mikado_scripts')) {
    /**
     * Function that includes all necessary scripts
     */
    function sparks_mikado_scripts() {
        global $wp_scripts;

        //init theme core scripts
        wp_enqueue_script('jquery-ui-core');
        wp_enqueue_script('jquery-ui-tabs');
        wp_enqueue_script('jquery-ui-accordion');
        wp_enqueue_script('wp-mediaelement');

        wp_enqueue_script('isotope', MIKADO_ASSETS_ROOT . '/js/jquery.isotope.min.js', array('jquery'), false, true);
        wp_enqueue_script('packery', MIKADO_ASSETS_ROOT . '/js/packery-mode.pkgd.min.js', array('isotope'), false, true);

        if (sparks_mikado_is_smoth_scroll_enabled()) {
            wp_enqueue_script('sparks-mikado-smooth-page-scroll', MIKADO_ASSETS_ROOT . '/js/smoothPageScroll.js', array(), false, true);
        }

        if (sparks_mikado_is_woocommerce_installed()) {
            wp_enqueue_script('select2');
        }

        //include google map api script
        if (sparks_mikado_options()->getOptionValue('google_maps_api_key') != '') {
            $google_maps_api_key = sparks_mikado_options()->getOptionValue('google_maps_api_key');
            wp_enqueue_script('google-map-api', '//maps.googleapis.com/maps/api/js?key=' . $google_maps_api_key, array(), false, true);
        }

        //wp_enqueue_script('mkd_default', MIKADO_ASSETS_ROOT.'/js/default.js', array(), false, true);
        wp_enqueue_script('sparks-mikado-modules', MIKADO_ASSETS_ROOT . '/js/modules.min.js', array('jquery'), false, true);

        if (sparks_mikado_load_blog_assets()) {
            wp_enqueue_script('sparks-mikado-blog', MIKADO_ASSETS_ROOT . '/js/blog.min.js', array('jquery'), false, true);
        }

        //include comment reply script
        $wp_scripts->add_data('comment-reply', 'group', 1);
        if (is_singular() && comments_open() && get_option('thread_comments')) {
            wp_enqueue_script('comment-reply');
        }

        //include Visual Composer script
        if (class_exists('WPBakeryVisualComposerAbstract')) {
            wp_enqueue_script('wpb_composer_front_js');
        }

		// 3rd party JavaScripts that we used in our theme
		wp_enqueue_script( 'appear', MIKADO_ASSETS_ROOT . '/js/modules/plugins/jquery.appear.js', array( 'jquery' ), false, true );
		wp_enqueue_script( 'modernizr', MIKADO_ASSETS_ROOT . '/js/modules/plugins/modernizr.custom.85257.js', array( 'jquery' ), false, true );
		wp_enqueue_script( 'hoverIntent', MIKADO_ASSETS_ROOT . '/js/modules/plugins/jquery.hoverIntent.min.js', array( 'jquery' ), false, true );
		wp_enqueue_script( 'jquery-plugin', MIKADO_ASSETS_ROOT . '/js/modules/plugins/jquery.plugin.js', array( 'jquery' ), false, true );
		wp_enqueue_script( 'countdown', MIKADO_ASSETS_ROOT . '/js/modules/plugins/jquery.countdown.min.js', array( 'jquery' ), false, true );
		wp_enqueue_script( 'owl-carousel', MIKADO_ASSETS_ROOT . '/js/modules/plugins/owl.carousel.js', array( 'jquery' ), false, true );
		wp_enqueue_script( 'parallax', MIKADO_ASSETS_ROOT . '/js/modules/plugins/parallax.min.js', array( 'jquery' ), false, true );
		wp_enqueue_script( 'easypiechart', MIKADO_ASSETS_ROOT . '/js/modules/plugins/easypiechart.js', array( 'jquery' ), false, true );
		wp_enqueue_script( 'waypoints', MIKADO_ASSETS_ROOT . '/js/modules/plugins/jquery.waypoints.min.js', array( 'jquery' ), false, true );
		wp_enqueue_script( 'counter', MIKADO_ASSETS_ROOT . '/js/modules/plugins/counter.js', array( 'jquery' ), false, true );
		wp_enqueue_script( 'fluidvids', MIKADO_ASSETS_ROOT . '/js/modules/plugins/fluidvids.min.js', array( 'jquery' ), false, true );
		wp_enqueue_script( 'prettyphoto', MIKADO_ASSETS_ROOT . '/js/modules/plugins/jquery.prettyPhoto.js', array( 'jquery' ), false, true );
		wp_enqueue_script( 'nicescroll', MIKADO_ASSETS_ROOT . '/js/modules/plugins/jquery.nicescroll.min.js', array( 'jquery' ), false, true );
		wp_enqueue_script( 'ScrollToPlugin', MIKADO_ASSETS_ROOT . '/js/modules/plugins/ScrollToPlugin.min.js', array( 'jquery' ), false, true );
		wp_enqueue_script( 'tweenlight', MIKADO_ASSETS_ROOT . '/js/modules/plugins/TweenLite.min.js', array( 'jquery' ), false, true );
		wp_enqueue_script( 'mixitup', MIKADO_ASSETS_ROOT . '/js/modules/plugins/jquery.mixitup.min.js', array( 'jquery' ), false, true );
		wp_enqueue_script( 'waitforimages', MIKADO_ASSETS_ROOT . '/js/modules/plugins/jquery.waitforimages.js', array( 'jquery' ), false, true );
		wp_enqueue_script( 'infinitescroll', MIKADO_ASSETS_ROOT . '/js/modules/plugins/jquery.infinitescroll.min.js', array( 'jquery' ), false, true );
		wp_enqueue_script( 'jquery-easing-1.3', MIKADO_ASSETS_ROOT . '/js/modules/plugins/jquery.easing.1.3.js', array( 'jquery' ), false, true );
		wp_enqueue_script( 'skrollr', MIKADO_ASSETS_ROOT . '/js/modules/plugins/skrollr.js', array( 'jquery' ), false, true );
		wp_enqueue_script( 'touchSwipe', MIKADO_ASSETS_ROOT . '/js/modules/plugins/jquery.touchSwipe.min.js', array( 'jquery' ), false, true );
		wp_enqueue_script( 'absoluteCounter', MIKADO_ASSETS_ROOT . '/js/modules/plugins/absoluteCounter.min.js', array( 'jquery' ), false, true );
		wp_enqueue_script( 'TimelineLite', MIKADO_ASSETS_ROOT . '/js/modules/plugins/TimelineLite.min.js', array( 'jquery' ), false, true );
		wp_enqueue_script( 'CSSPlugin', MIKADO_ASSETS_ROOT . '/js/modules/plugins/CSSPlugin.min.js', array( 'jquery' ), false, true );
		wp_enqueue_script( 'EasePack', MIKADO_ASSETS_ROOT . '/js/modules/plugins/EasePack.min.js', array( 'jquery' ), false, true );
		wp_enqueue_script( 'draggable', MIKADO_ASSETS_ROOT . '/js/modules/plugins/jquery.draggable.min.js', array( 'jquery' ), false, true );
		wp_enqueue_script( 'charts', MIKADO_ASSETS_ROOT . '/js/modules/plugins/charts.min.js', array( 'jquery' ), false, true );
		wp_enqueue_script( 'stretch', MIKADO_ASSETS_ROOT . '/js/modules/plugins/jquery.stretch.js', array( 'jquery' ), false, true );
		wp_enqueue_script( 'fullPage', MIKADO_ASSETS_ROOT . '/js/modules/plugins/jquery.fullPage.min.js', array( 'jquery' ), false, true );
		wp_enqueue_script( 'velocity', MIKADO_ASSETS_ROOT.'/js/modules/plugins/velocity.min.js', array('jquery'), false, true);
    }

    add_action('wp_enqueue_scripts', 'sparks_mikado_scripts');
}

if (!function_exists('sparks_mikado_is_ajax_request')) {
    /**
     * Function that checks if the incoming request is made by ajax function
     */
    function sparks_mikado_is_ajax_request() {

        return isset($_POST["ajaxReq"]) && $_POST["ajaxReq"] == 'yes';

    }
}

if (!function_exists('sparks_mikado_is_ajax_enabled')) {
    /**
     * Function that checks if ajax is enabled
     */
    function sparks_mikado_is_ajax_enabled() {

        return sparks_mikado_options()->getOptionValue('smooth_page_transitions') === 'yes' && sparks_mikado_options()->getOptionValue('smooth_pt_true_ajax') != 'no';

    }
}

if (!function_exists('sparks_mikado_ajax_meta')) {
    /**
     * Function that echoes meta data for ajax
     *
     * @since 4.3
     * @version 0.2
     */
    function sparks_mikado_ajax_meta() {

        $id = sparks_mikado_get_page_id();

        $page_transition = get_post_meta($id, "mkd_page_transition_type", true);
        ?>

        <div class="mkd-seo-title"><?php echo wp_get_document_title(); ?></div>

        <?php if ($page_transition !== '') { ?>
            <div class="mkd-page-transition"><?php echo esc_html($page_transition); ?></div>
        <?php } else if (sparks_mikado_options()->getOptionValue('default_page_transition')) { ?>
            <div class="mkd-page-transition"><?php echo esc_html(sparks_mikado_options()->getOptionValue('default_page_transition')); ?></div>
        <?php }
    }

    add_action('sparks_mikado_ajax_meta', 'sparks_mikado_ajax_meta');
}

if (!function_exists('sparks_mikado_no_ajax_pages')) {
    /**
     * Function that echoes pages on which ajax should not be applied
     *
     * @since 4.3
     * @version 0.2
     */
    function sparks_mikado_no_ajax_pages($global_variables) {

        //is ajax enabled?
        if (sparks_mikado_is_ajax_enabled()) {
            $no_ajax_pages = array();

            //get posts that have ajax disabled and merge with main array
            $no_ajax_pages = array_merge($no_ajax_pages, sparks_mikado_get_objects_without_ajax());

            //is wpml installed?
            if (sparks_mikado_is_wpml_installed()) {
                //get translation pages for current page and merge with main array
                $no_ajax_pages = array_merge($no_ajax_pages, sparks_mikado_get_wpml_pages_for_current_page());
            }

            //is woocommerce installed?
            if (sparks_mikado_is_woocommerce_installed()) {
                //get all woocommerce pages and products and merge with main array
                $no_ajax_pages = array_merge($no_ajax_pages, sparks_mikado_get_woocommerce_pages());
            }
            //do we have some internal pages that want to be without ajax?
            if (sparks_mikado_options()->getOptionValue('internal_no_ajax_links') !== '') {
                //get array of those pages
                $options_no_ajax_pages_array = explode(',', sparks_mikado_options()->getOptionValue('internal_no_ajax_links'));

                if (is_array($options_no_ajax_pages_array) && count($options_no_ajax_pages_array)) {
                    $no_ajax_pages = array_merge($no_ajax_pages, $options_no_ajax_pages_array);
                }
            }

            //add logout url to main array
            $no_ajax_pages[] = wp_specialchars_decode(wp_logout_url());

            $global_variables['no_ajax_pages'] = $no_ajax_pages;
        }

        return $global_variables;

    }

    add_filter('sparks_mikado_js_global_variables', 'sparks_mikado_no_ajax_pages');
}

if (!function_exists('sparks_mikado_get_objects_without_ajax')) {
    /**
     * Function that returns urls of objects that have ajax disabled.
     * Works for posts, pages and portfolio pages.
     * @return array array of urls of posts that have ajax disabled
     *
     * @version 0.1
     */
    function sparks_mikado_get_objects_without_ajax() {
        $posts_without_ajax = array();

        $posts_args = array(
            'post_type' => array('post', 'portfolio-item', 'page'),
            'post_status' => 'publish',
            'meta_key' => 'mkd_page_transition_type',
            'meta_value' => 'no-animation'
        );

        $posts_query = new WP_Query($posts_args);

        if ($posts_query->have_posts()) {
            while ($posts_query->have_posts()) {
                $posts_query->the_post();
                $posts_without_ajax[] = get_permalink(get_the_ID());
            }
        }

        wp_reset_postdata();

        return $posts_without_ajax;
    }
}


//defined content width variable
if (!isset($content_width)) $content_width = 1060;

if (!function_exists('sparks_mikado_theme_setup')) {
    /**
     * Function that adds various features to theme. Also defines image sizes that are used in a theme
     */
    function sparks_mikado_theme_setup() {
        //add support for feed links
        add_theme_support('automatic-feed-links');

        //add support for post formats
        add_theme_support('post-formats', array('gallery', 'link', 'quote', 'video', 'audio'));

        //add theme support for post thumbnails
        add_theme_support('post-thumbnails');

        //add theme support for title tag
        add_theme_support('title-tag');

        //define thumbnail sizes
        add_image_size('sparks_mikado_thumb', 110, 80, true);
        add_image_size('sparks_mikado_square', 550, 550, true);
        add_image_size('sparks_mikado_landscape', 800, 600, true);
        add_image_size('sparks_mikado_portrait', 600, 800, true);

        load_theme_textdomain('sparks', get_template_directory() . '/languages');
    }

    add_action('after_setup_theme', 'sparks_mikado_theme_setup');
}

if ( ! function_exists( 'sparks_mikado_enqueue_editor_customizer_styles' ) ) {
	/**
	 * Enqueue supplemental block editor styles
	 */
	function sparks_mikado_enqueue_editor_customizer_styles() {
		wp_enqueue_style( 'sparks-style-modules-admin-styles', MIKADO_FRAMEWORK_ADMIN_ASSETS_ROOT . '/css/mkd-modules-admin.css' );
		wp_enqueue_style( 'sparks-style-handle-editor-customizer-styles', MIKADO_FRAMEWORK_ADMIN_ASSETS_ROOT . '/css/editor-customizer-style.css' );
	}

	// add google font
	add_action( 'enqueue_block_editor_assets', 'sparks_mikado_google_fonts_styles' );
	// add action
	add_action( 'enqueue_block_editor_assets', 'sparks_mikado_enqueue_editor_customizer_styles' );
}

if (!function_exists('sparks_mikado_rgba_color')) {
    /**
     * Function that generates rgba part of css color property
     *
     * @param $color string hex color
     * @param $transparency float transparency value between 0 and 1
     *
     * @return string generated rgba string
     */
    function sparks_mikado_rgba_color($color, $transparency) {
        if ($color !== '' && $transparency !== '') {
            $rgba_color = '';

            $rgb_color_array = sparks_mikado_hex2rgb($color);
            $rgba_color .= 'rgba(' . implode(', ', $rgb_color_array) . ', ' . $transparency . ')';

            return $rgba_color;
        }
    }
}


if (!function_exists('sparks_mikado_header_meta')) {
    /**
     * Function that echoes meta data if our seo is enabled
     */
    function sparks_mikado_header_meta() { ?>

        <meta charset="<?php bloginfo('charset'); ?>"/>
        <link rel="profile" href="http://gmpg.org/xfn/11"/>
        <?php if (is_singular() && pings_open(get_queried_object())) : ?>
            <link rel="pingback" href="<?php bloginfo('pingback_url'); ?>">
        <?php endif; ?>

    <?php }

    add_action('sparks_mikado_header_meta', 'sparks_mikado_header_meta');
}


if (!function_exists('sparks_mikado_user_scalable_meta')) {
    /**
     * Function that outputs user scalable meta if responsiveness is turned on
     * Hooked to sparks_mikado_header_meta action
     */
    function sparks_mikado_user_scalable_meta() {
        //is responsiveness option is chosen?
        if (sparks_mikado_is_responsive_on()) { ?>
            <meta name="viewport" content="width=device-width,initial-scale=1,user-scalable=no">
        <?php } else { ?>
            <meta name="viewport" content="width=1200,user-scalable=yes">
        <?php }
    }

    add_action('sparks_mikado_header_meta', 'sparks_mikado_user_scalable_meta');
}


if (!function_exists('sparks_mikado_get_page_id')) {
    /**
     * Function that returns current page / post id.
     * Checks if current page is woocommerce page and returns that id if it is.
     * Checks if current page is any archive page (category, tag, date, author etc.) and returns -1 because that isn't
     * page that is created in WP admin.
     *
     * @return int
     *
     * @version 0.1
     *
     * @see sparks_mikado_is_woocommerce_installed()
     * @see sparks_mikado_is_woocommerce_shop()
     */
    function sparks_mikado_get_page_id() {
        if (sparks_mikado_is_woocommerce_installed() && sparks_mikado_is_woocommerce_shop()) {
            return sparks_mikado_get_woo_shop_page_id();
        }

        if (is_archive() || is_search() || is_404() || (is_home() && is_front_page())) {
            return -1;
        }

        return get_queried_object_id();
    }
}


if (!function_exists('sparks_mikado_is_default_wp_template')) {
    /**
     * Function that checks if current page archive page, search, 404 or default home blog page
     * @return bool
     *
     * @see is_archive()
     * @see is_search()
     * @see is_404()
     * @see is_front_page()
     * @see is_home()
     */
    function sparks_mikado_is_default_wp_template() {
        return is_archive() || is_search() || is_404() || (is_front_page() && is_home());
    }
}

if (!function_exists('sparks_mikado_get_page_template_name')) {
    /**
     * Returns current template file name without extension
     * @return string name of current template file
     */
    function sparks_mikado_get_page_template_name() {
        $file_name = '';

        if (!sparks_mikado_is_default_wp_template()) {
            $file_name_without_ext = preg_replace('/\\.[^.\\s]{3,4}$/', '', basename(get_page_template()));

            if ($file_name_without_ext !== '') {
                $file_name = $file_name_without_ext;
            }
        }

        return $file_name;
    }
}

if (!function_exists('sparks_mikado_has_shortcode')) {
    /**
     * Function that checks whether shortcode exists on current page / post
     *
     * @param string shortcode to find
     * @param string content to check. If isn't passed current post content will be used
     *
     * @return bool whether content has shortcode or not
     */
    function sparks_mikado_has_shortcode($shortcode, $content = '') {
        $has_shortcode = false;

        if ($shortcode) {
            //if content variable isn't past
            if ($content == '') {
                //take content from current post
                $page_id = sparks_mikado_get_page_id();
                if (!empty($page_id)) {
                    $current_post = get_post($page_id);

                    if (is_object($current_post) && property_exists($current_post, 'post_content')) {
                        $content = $current_post->post_content;
                    }
                }
            }

            //does content has shortcode added?
            if (stripos($content, '[' . $shortcode) !== false) {
                $has_shortcode = true;
            }
        }

        return $has_shortcode;
    }
}

if (!function_exists('sparks_mikado_get_dynamic_sidebar')) {
    /**
     * Return Custom Widget Area content
     *
     * @return string
     */
    function sparks_mikado_get_dynamic_sidebar($index = 1) {
        ob_start();
        dynamic_sidebar($index);
        $sidebar_contents = ob_get_clean();

        return $sidebar_contents;
    }
}

if (!function_exists('sparks_mikado_get_sidebar')) {
    /**
     * Return Sidebar
     *
     * @return string
     */
    function sparks_mikado_get_sidebar() {

        $id = sparks_mikado_get_page_id();

        $sidebar = "sidebar";

        if (get_post_meta($id, 'mkd_custom_sidebar_meta', true) != '') {
            $sidebar = get_post_meta($id, 'mkd_custom_sidebar_meta', true);
        } else {
            if (is_single() && sparks_mikado_options()->getOptionValue('blog_single_custom_sidebar') != '') {
                $sidebar = esc_attr(sparks_mikado_options()->getOptionValue('blog_single_custom_sidebar'));
            } elseif ((is_archive() || (is_home() && is_front_page())) && sparks_mikado_options()->getOptionValue('blog_custom_sidebar') != '') {
                $sidebar = esc_attr(sparks_mikado_options()->getOptionValue('blog_custom_sidebar'));
            } elseif (is_page() && sparks_mikado_options()->getOptionValue('page_custom_sidebar') != '') {
                $sidebar = esc_attr(sparks_mikado_options()->getOptionValue('page_custom_sidebar'));
            }
        }

        return $sidebar;
    }
}


if (!function_exists('sparks_mikado_sidebar_columns_class')) {

    /**
     * Return classes for columns holder when sidebar is active
     *
     * @return array
     */

    function sparks_mikado_sidebar_columns_class() {

        $sidebar_class = array();
        $sidebar_layout = sparks_mikado_sidebar_layout();

        switch ($sidebar_layout):
            case 'sidebar-33-right':
                $sidebar_class[] = 'mkd-two-columns-66-33';
                break;
            case 'sidebar-25-right':
                $sidebar_class[] = 'mkd-two-columns-75-25';
                break;
            case 'sidebar-33-left':
                $sidebar_class[] = 'mkd-two-columns-33-66';
                break;
            case 'sidebar-25-left':
                $sidebar_class[] = 'mkd-two-columns-25-75';
                break;

        endswitch;

        $sidebar_class[] = 'clearfix';

        return sparks_mikado_class_attribute($sidebar_class);

    }

}


if (!function_exists('sparks_mikado_sidebar_layout')) {

    /**
     * Function that check is sidebar is enabled and return type of sidebar layout
     */

    function sparks_mikado_sidebar_layout() {

        $sidebar_layout = '';
        $page_id = sparks_mikado_get_page_id();

        $page_sidebar_meta = get_post_meta($page_id, 'mkd_sidebar_meta', true);

        if (($page_sidebar_meta !== '') && $page_id !== -1) {
            if ($page_sidebar_meta == 'no-sidebar') {
                $sidebar_layout = '';
            } else {
                $sidebar_layout = $page_sidebar_meta;
            }
        } else {
            if (is_single() && sparks_mikado_options()->getOptionValue('blog_single_sidebar_layout')) {
                $sidebar_layout = esc_attr(sparks_mikado_options()->getOptionValue('blog_single_sidebar_layout'));
            } elseif ((is_archive() || (is_home() && is_front_page())) && sparks_mikado_options()->getOptionValue('archive_sidebar_layout')) {
                $sidebar_layout = esc_attr(sparks_mikado_options()->getOptionValue('archive_sidebar_layout'));
            } elseif (is_page() && sparks_mikado_options()->getOptionValue('page_sidebar_layout')) {
                $sidebar_layout = esc_attr(sparks_mikado_options()->getOptionValue('page_sidebar_layout'));
			} elseif(! empty( $sidebar_layout ) && ! is_active_sidebar( sparks_mikado_get_sidebar() ) ) {
				$sidebar_layout = '';
			}
        }

        return $sidebar_layout;
    }
}

if (!function_exists('sparks_mikado_page_custom_style')) {
    /**
     * Function that print custom page style
     */
    function sparks_mikado_page_custom_style() {
        
        $style = apply_filters('sparks_mikado_add_page_custom_style', $style = array());

        if ($style !== '') {
            wp_add_inline_style('sparks-mikado-style-dynamic', $style);
        }
    }

    add_action('wp_enqueue_scripts', 'sparks_mikado_page_custom_style');
}

if (!function_exists('sparks_mikado_container_style')) {
    /**
     * Function that return container style
     */
    function sparks_mikado_container_style($style) {
        $id = sparks_mikado_get_page_id();
        $class_id = sparks_mikado_get_page_id();
        if (sparks_mikado_is_woocommerce_installed() && is_product()) {
            $class_id = get_the_ID();
        }

        $class_prefix = sparks_mikado_get_unique_page_class($class_id);

        $container_selector = array(
            $class_prefix . ' .mkd-content .mkd-content-inner > .mkd-container',
            $class_prefix . ' .mkd-content .mkd-content-inner > .mkd-full-width',
        );

        $container_class = array();
        $page_backgorund_color = get_post_meta($id, "mkd_page_background_color_meta", true);

        if ($page_backgorund_color) {
            $container_class['background-color'] = $page_backgorund_color;
        }

        $current_style = sparks_mikado_dynamic_css($container_selector, $container_class);
        $style[] = $current_style;

        return $current_style;
    }

    add_filter('sparks_mikado_add_page_custom_style', 'sparks_mikado_container_style');
}

if (!function_exists('sparks_mikado_boxed_container_style')) {
    /**
     * Function that return container style
     */
    function sparks_mikado_boxed_container_style($style) {
        $id = sparks_mikado_get_page_id();
        $class_id = sparks_mikado_get_page_id();
        if (sparks_mikado_is_woocommerce_installed() && is_product()) {
            $class_id = get_the_ID();
        }

        $class_prefix = sparks_mikado_get_unique_page_class($class_id);

        $container_selector = array(
            $class_prefix . '.mkd-boxed .mkd-wrapper'
        );

        $boxed_background_style = array();
        $background_color = get_post_meta($id, "mkd_page_background_color_in_box", true);
        if ($background_color) {
            $boxed_background_style['background-color'] = get_post_meta($id, "mkd_page_background_color_in_box", true);
        }

        $background_image = get_post_meta($id, "mkd_boxed_background_image", true);
        if ($background_image) {
            $boxed_background_style['background-image'] = 'url(' . esc_url($background_image) . ')';
            $boxed_background_style['background-position'] = 'center 0px';
            $boxed_background_style['background-repeat'] = 'no-repeat';
        }

        $background_pattern = get_post_meta($id, "mkd_boxed_pattern_background_image", true);
        if ($background_pattern) {
            $boxed_background_style['background-image'] = 'url(' . esc_url($background_pattern) . ')';
            $boxed_background_style['background-position'] = '0px 0px';
            $boxed_background_style['background-repeat'] = 'repeat';
        }

        $background_attachment = get_post_meta($id, "mkd_boxed_background_image_attachment", true);
        if ($background_attachment) {
            $boxed_background_style['background-attachment'] = $background_attachment;
        }

        $current_style = sparks_mikado_dynamic_css($container_selector, $boxed_background_style);
        $current_style = $current_style . $style;

        return $current_style;
    }

    add_filter('sparks_mikado_add_page_custom_style', 'sparks_mikado_boxed_container_style');
}


if (!function_exists('sparks_mikado_get_unique_page_class')) {
    /**
     * Returns unique page class based on post type and page id
     *
     * @return string
     */
    function sparks_mikado_get_unique_page_class() {
        $id = sparks_mikado_get_page_id();
        $page_class = '';

        if (is_single()) {
            $page_class = '.postid-' . get_queried_object_id();
        } elseif ($id === sparks_mikado_get_woo_shop_page_id()) {
            $page_class = '.woocommerce-page';
        } elseif (is_home()) {
            $page_class .= '.home';
        } else {
            $page_class .= '.page-id-' . $id;
        }

        return $page_class;
    }
}

if (!function_exists('sparks_mikado_print_custom_css')) {
    /**
     * Prints out custom css from theme options
     */
    function sparks_mikado_print_custom_css() {
        $custom_css = sparks_mikado_options()->getOptionValue('custom_css');

        if ($custom_css !== '') {
            wp_add_inline_style('sparks-mikado-modules', $custom_css);
        }
    }

    add_action('wp_enqueue_scripts', 'sparks_mikado_print_custom_css');
}

if (!function_exists('sparks_mikado_print_custom_js')) {
    /**
     * Prints out custom css from theme options
     */
    function sparks_mikado_print_custom_js() {
        $custom_js = sparks_mikado_options()->getOptionValue('custom_js');

        if ($custom_js !== '') {
            wp_add_inline_script('sparks-mikado-modules', $custom_js);
        }
    }

    add_action('wp_enqueue_scripts', 'sparks_mikado_print_custom_js');
}

if (!function_exists('sparks_mikado_get_global_variables')) {
    /**
     * Function that generates global variables and put them in array so they could be used in the theme
     */
    function sparks_mikado_get_global_variables() {

        $global_variables = array();
        $element_appear_amount = -150;

        $global_variables['mkdAddForAdminBar'] = is_admin_bar_showing() ? 32 : 0;
        $global_variables['mkdElementAppearAmount'] = sparks_mikado_options()->getOptionValue('element_appear_amount') !== '' ? sparks_mikado_options()->getOptionValue('element_appear_amount') : $element_appear_amount;
        $global_variables['mkdFinishedMessage'] = esc_html__('No more posts', 'sparks');
        $global_variables['mkdMessage'] = esc_html__('Loading new posts...', 'sparks');
        $global_variables['mkdAddingToCart'] = esc_html__('Adding to Cart...', 'sparks');

        $global_variables = apply_filters('sparks_mikado_js_global_variables', $global_variables);

        wp_localize_script('sparks-mikado-modules', 'mkdGlobalVars', array(
            'vars' => $global_variables
        ));

    }

    add_action('wp_enqueue_scripts', 'sparks_mikado_get_global_variables');
}

if (!function_exists('sparks_mikado_per_page_js_variables')) {
    /**
     * Outputs global JS variable that holds page settings
     */
    function sparks_mikado_per_page_js_variables() {
        $per_page_js_vars = apply_filters('sparks_mikado_per_page_js_vars', array());

        wp_localize_script('sparks-mikado-modules', 'mkdPerPageVars', array(
            'vars' => $per_page_js_vars
        ));
    }

    add_action('wp_enqueue_scripts', 'sparks_mikado_per_page_js_variables');
}

if (!function_exists('sparks_mikado_content_elem_style_attr')) {
    /**
     * Defines filter for adding custom styles to content HTML element
     */
    function sparks_mikado_content_elem_style_attr() {
        $styles = apply_filters('sparks_mikado_content_elem_style_attr', array());

        sparks_mikado_inline_style($styles);
    }
}

if (!function_exists('sparks_mikado_is_woocommerce_installed')) {
    /**
     * Function that checks if woocommerce is installed
     * @return bool
     */
    function sparks_mikado_is_woocommerce_installed() {
        return function_exists('is_woocommerce');
    }
}

if (!function_exists('sparks_mikado_visual_composer_installed')) {
    /**
     * Function that checks if visual composer installed
     * @return bool
     */
    function sparks_mikado_visual_composer_installed() {
        //is Visual Composer installed?
        if (class_exists('WPBakeryVisualComposerAbstract')) {
            return true;
        }

        return false;
    }
}

if (!function_exists('sparks_mikado_contact_form_7_installed')) {
    /**
     * Function that checks if contact form 7 installed
     * @return bool
     */
    function sparks_mikado_contact_form_7_installed() {
        //is Contact Form 7 installed?
        if (defined('WPCF7_VERSION')) {
            return true;
        }

        return false;
    }
}

if (!function_exists('sparks_mikado_is_wpml_installed')) {
    /**
     * Function that checks if WPML plugin is installed
     * @return bool
     *
     * @version 0.1
     */
    function sparks_mikado_is_wpml_installed() {
        return defined('ICL_SITEPRESS_VERSION');
    }
}

if (!function_exists('sparks_mikado_is_membership_installed')) {
    /**
     * Function that checks if Mikado Membership Plugin installed
     *
     * @return bool
     */
    function sparks_mikado_is_membership_installed() {
        return defined('MIKADO_MEMBERSHIP_VERSION');
    }
}

if ( ! function_exists( 'sparks_mikado_is_plugin_installed' ) ) {
	/**
	 * Function that checks if forward plugin installed
	 *
	 * @param $plugin string
	 *
	 * @return bool
	 */
	function sparks_mikado_is_plugin_installed( $plugin ) {
		switch ( $plugin ) {
			case 'core':
				return defined( 'MIKADO_CORE_VERSION' );
				break;
			case 'woocommerce':
				return function_exists( 'is_woocommerce' );
				break;
			case 'visual-composer':
				return class_exists( 'WPBakeryVisualComposerAbstract' );
				break;
			case 'revolution-slider':
				return class_exists( 'RevSliderFront' );
				break;
			case 'contact-form-7':
				return defined( 'WPCF7_VERSION' );
				break;
			case 'wpml':
				return defined( 'ICL_SITEPRESS_VERSION' );
				break;
			case 'gutenberg-editor':
				return class_exists( 'WP_Block_Type' );
				break;
			case 'gutenberg-plugin':
				return function_exists( 'is_gutenberg_page' ) && is_gutenberg_page();
				break;
			default:
				return false;
				break;
		}
	}
}

if (!function_exists('sparks_mikado_max_image_width_srcset')) {
    /**
     * Set max width for srcset to 1920
     *
     * @return int
     */
    function sparks_mikado_max_image_width_srcset() {
        return 1920;
    }

    add_filter('max_srcset_image_width', 'sparks_mikado_max_image_width_srcset');
}

if (!function_exists('sparks_mikado_get_user_custom_fields')) {
    /**
     * Function returns links and icons for author social networks
     *
     * return array
     *
     */
    function sparks_mikado_get_user_custom_fields($id) {

        $user_social_array = array();
        $social_network_array = array('instagram', 'twitter', 'facebook', 'googleplus');

        foreach ($social_network_array as $network) {

            $$network = array(
                'name' => $network,
                'link' => get_the_author_meta($network, $id),
                'class' => 'social_' . $network
            );

            $user_social_array[$network] = $$network;

        }

        return $user_social_array;
    }
}

if (!function_exists('sparks_mikado_is_ajax_request')) {
    /**
     * Function that checks if the incoming request is made by ajax function
     */
    function sparks_mikado_is_ajax_request() {

        return isset($_POST['ajaxReq']) && $_POST['ajaxReq'] == 'yes';

    }
}


if (!function_exists('sparks_mikado_content_padding_top')) {

    /**
     * Function that return padding for content
     */

    function sparks_mikado_content_padding_top($style) {


        $id = sparks_mikado_get_page_id();
        $class_id = sparks_mikado_get_page_id();
        if (sparks_mikado_is_woocommerce_installed() && is_product()) {
            $class_id = get_the_ID();
        }

        $class_prefix = sparks_mikado_get_unique_page_class($class_id);

        /* content top */

        $content_selector = array(
            $class_prefix . ' .mkd-content .mkd-content-inner > .mkd-container > .mkd-container-inner',
            $class_prefix . ' .mkd-content .mkd-content-inner > .mkd-full-width > .mkd-full-width-inner',
        );

        $current_style = '';
        $content_class = array();

        $page_padding_top = get_post_meta($id, "mkd_page_content_top_padding", true);

        if ($page_padding_top !== '') {
            if (get_post_meta($id, "mkd_page_content_top_padding_mobile", true) == 'yes') {
                $content_class['padding-top'] = sparks_mikado_filter_px($page_padding_top) . 'px!important';
            } else {
                $content_class['padding-top'] = sparks_mikado_filter_px($page_padding_top) . 'px';
            }
            $current_style .= sparks_mikado_dynamic_css($content_selector, $content_class);
        }

        $current_style = $current_style . $style;

        /* content bottom */

        $content_selector = array(
            $class_prefix . ' .mkd-content'
        );

        $current_style_2 = '';

        $content_class = array();

        $page_padding_bottom = get_post_meta($id, "mkd_page_content_bottom_padding", true);

        if ($page_padding_bottom !== '') {
            $content_class['padding-bottom'] = sparks_mikado_filter_px($page_padding_bottom) . 'px';
            $current_style_2 .= sparks_mikado_dynamic_css($content_selector, $content_class);
        }

        $current_style = $current_style_2 . $current_style;


        return $current_style;

    }

    add_filter('sparks_mikado_add_page_custom_style', 'sparks_mikado_content_padding_top');
}

if (!function_exists('sparks_mikado_generate_first_main_color_per_page')) {
    /**
     * Function that checks first main color in page options and generate css if color is set
     */
    function sparks_mikado_generate_first_main_color_per_page($style) {

        $id = sparks_mikado_get_page_id();
        $first_color = sparks_mikado_get_meta_field_intersect('first_color', $id);
        if ($first_color !== '') {

            extract(sparks_mikado_generate_first_color_selectors());

            $style .= sparks_mikado_dynamic_css('::selection', array('background' => $first_color));
            $style .= sparks_mikado_dynamic_css('::-moz-selection', array('background' => $first_color));

            $style .= sparks_mikado_dynamic_css($color_selector, array('color' => $first_color));
            $style .= sparks_mikado_dynamic_css($color_important_selector, array('color' => $first_color . ' !important'));
            $style .= sparks_mikado_dynamic_css($background_color_selector, array('background-color' => $first_color));
            $style .= sparks_mikado_dynamic_css($background_color_important_selector, array('background-color' => $first_color . ' !important'));
            $style .= sparks_mikado_dynamic_css($border_color_selector, array('border-color' => $first_color));
            $style .= sparks_mikado_dynamic_css($border_color_important_selector, array('border-color' => $first_color . ' !important'));
        }

        return $style;
    }

    add_filter('sparks_mikado_add_page_custom_style', 'sparks_mikado_generate_first_main_color_per_page');
}

if (!function_exists('sparks_mikado_generate_first_color_selectors')) {
    /**
     * Function generate arrays of selectors for first color option
     */
    function sparks_mikado_generate_first_color_selectors() {

        ////////////////////////////////////////////////////////////////////////////////////////////////////////////////
        // generate background color selectors array

        $return_array['background_color_selector'] = array(
            '.mkd-st-loader .pulse',
            '.mkd-st-loader .blinking_square .blinking_square-node',
            '.mkd-st-loader .double_pulse .double-bounce1',
            '.mkd-st-loader .double_pulse .double-bounce2',
            '.mkd-st-loader .cube',
            '.mkd-st-loader .rotating_cubes .cube1',
            '.mkd-st-loader .rotating_cubes .cube2',
            '.mkd-st-loader .stripes>div',
            '.mkd-st-loader .wave>div',
            '.mkd-st-loader .two_rotating_circles .dot1',
            '.mkd-st-loader .two_rotating_circles .dot2',
            '.mkd-st-loader .five_rotating_circles .container1>div',
            '.mkd-st-loader .five_rotating_circles .container2>div',
            '.mkd-st-loader .five_rotating_circles .container3>div',
            '.mkd-st-loader .atom .ball-1:before',
            '.mkd-st-loader .atom .ball-2:before',
            '.mkd-st-loader .atom .ball-3:before',
            '.mkd-st-loader .atom .ball-4:before',
            '.mkd-st-loader .clock .ball:before',
            '.mkd-st-loader .mitosis .ball',
            '.mkd-st-loader .lines .line1',
            '.mkd-st-loader .lines .line2',
            '.mkd-st-loader .lines .line3',
            '.mkd-st-loader .lines .line4',
            '.mkd-st-loader .fussion .ball',
            '.mkd-st-loader .fussion .ball-1',
            '.mkd-st-loader .fussion .ball-2',
            '.mkd-st-loader .fussion .ball-3',
            '.mkd-st-loader .fussion .ball-4',
            '.mkd-st-loader .wave_circles .ball',
            '.mkd-st-loader .pulse_circles .ball',
            '#submit_comment',
            '.post-password-form input[type=submit]',
            'input.wpcf7-form-control.wpcf7-submit',
            '.mkd-pagination li a:hover',
            '.mkd-pagination li.active span',
            '.mkd-single-links-pages-inner a:hover span',
            '.mkd-single-links-pages-inner>span',
            '.mkd-owl-shortcode-slider .owl-controls .owl-dots .owl-dot.active span',
            '#mkd-back-to-top>span',
            '.mkd-drop-down .second .inner ul li a:before',
            '.mkd-header-vertical .mkd-vertical-dropdown-float .second .inner ul li a:before',
            '.mkd-header-vertical .mkd-vertical-dropdown-click .second:after',
            '.mkd-header-vertical .mkd-vertical-menu>ul>li>a:before',
            '.mkd-header-vertical .mkd-vertical-menu>ul>li>a:after',
            'nav.mkd-fullscreen-menu ul>li:hover>a .mkd-underline',
            'body.search-no-results .input-holder button',
            'body.search-results .input-holder button',
            '.mkd-pl-standard-pagination ul li a:hover',
            '.mkd-pl-standard-pagination ul li.mkd-pl-pag-active a',
            '.mkd-pl-standard-pagination ul li.mkd-pl-pag-next:hover a',
            '.mkd-pl-standard-pagination ul li.mkd-pl-pag-prev:hover a',
            '.mkd-team.main-info-on-hover .mkd-team-content-holder',
            '.mkd-icon-shortcode.circle',
            '.mkd-icon-shortcode.square',
            '.mkd-progress-bar .mkd-progress-content-outer .mkd-progress-content',
            '.mkd-price-table.mkd-active .mkd-price-table-inner .mkd-price-table-button .mkd-btn.mkd-btn-solid',
            '.mkd-larger-active .mkd-price-table.mkd-active .mkd-price-table-inner .mkd-price-table-button .mkd-btn',
            '.mkd-pricing-slider .mkd-pricing-slider-bar-holder .mkd-pricing-slider-bar',
            '.mkd-pricing-slider .mkd-pricing-slider-bar-holder .mkd-pricing-slider-bar .mkd-pricing-slider-drag',
            '.mkd-tabs .mkd-tabs-nav li .mkd-tab-title a',
            '.mkd-blog-list-holder.mkd-masonry .mkd-item-image .mkd-post-info-category a:hover',
            '.mkd-btn.mkd-btn-solid',
            '.mkd-clients-carousel .owl-controls .owl-dots .owl-dot.active span',
            '.mkd-dropcaps.mkd-circle',
            '.mkd-dropcaps.mkd-square',
            '.mkd-process-item.mkd-icon-and-number .mkd-process-item-numeration',
            '.mkd-process-item.mkd-icon-or-number .mkd-icon-shortcode.circle',
            '.mkd-service-table .mkd-btn.mkd-btn-solid.mkd-btn-animation-yes .mkd-button-overlay',
            '.mkd-service-table table tbody tr td .mkd-button-overlay-wrapper .mkd-button-overlay',
            '.mkd-info-box-holder:hover .mkd-ib-overlay',
            '.mkd-workflow .mkd-workflow-item .mkd-workflow-item-inner .mkd-workflow-text .circle:after',
            '.wpb_widgetised_column .widget.widget_search .input-holder button',
            'aside.mkd-sidebar .widget.widget_search .input-holder button',
            '.wpb_widgetised_column .widget.widget_tag_cloud a:hover',
            'aside.mkd-sidebar .widget.widget_tag_cloud a:hover',
            '.wpb_widgetised_column .widget_mkd_social_icon_widget .mkd-icon-shortcode.circle:hover',
            '.wpb_widgetised_column .widget_mkd_social_icon_widget .mkd-icon-shortcode.square:hover',
            'aside.mkd-sidebar .widget_mkd_social_icon_widget .mkd-icon-shortcode.circle:hover',
            'aside.mkd-sidebar .widget_mkd_social_icon_widget .mkd-icon-shortcode.square:hover',
            'footer .mkd-footer-top .widget.widget_tag_cloud a:hover',
            'footer .mkd-footer-top .widget_mkd_social_icon_widget .mkd-icon-shortcode.circle:hover',
            'footer .mkd-footer-top .widget_mkd_social_icon_widget .mkd-icon-shortcode.square:hover',
            'footer .mkd-footer-bottom .widget.widget_tag_cloud a:hover',
            'footer .mkd-footer-bottom .widget_mkd_social_icon_widget .mkd-icon-shortcode.circle:hover',
            'footer .mkd-footer-bottom .widget_mkd_social_icon_widget .mkd-icon-shortcode.square:hover',
            '.mkd-side-menu .widget #wp-calendar td#today',
            '.mkd-side-menu .widget.widget_search .input-holder button',
            '.mkd-side-menu .widget.widget_tag_cloud a',
            '.mkd-side-menu .widget.widget_tag_cloud a:hover',
            '.mkd-side-menu .widget_mkd_social_icon_widget .mkd-icon-shortcode.circle:hover',
            '.mkd-side-menu .widget_mkd_social_icon_widget .mkd-icon-shortcode.square:hover',
            '.mkd-content-bottom .widget.widget_search .input-holder button',
            '.mkd-content-bottom .widget.widget_tag_cloud a:hover',
            '.mkd-content-bottom .widget_mkd_social_icon_widget .mkd-icon-shortcode.circle:hover',
            '.mkd-content-bottom .widget_mkd_social_icon_widget .mkd-icon-shortcode.square:hover',
            '.mkd-blog-holder.mkd-blog-type-standard article.format-audio .mkd-icon-holder .mkd-icon',
            '.mkd-blog-holder.mkd-blog-type-masonry article.format-audio .mkd-icon-holder .mkd-icon',
            '.mkd-blog-holder:not(.mkd-blog-single) .mkd-post-info-category a',
            '.mkd-blog-holder.mkd-date-outside .mkd-post-info-date .year',
            '.mkd-blog-audio-holder .mejs-container .mejs-controls>.mejs-playpause-button button',
            '.mkd-blog-audio-holder .mejs-container .mejs-controls>.mejs-time-rail .mejs-time-total .mejs-time-current',
            '.mkd-blog-audio-holder .mejs-container .mejs-controls>a.mejs-horizontal-volume-slider .mejs-horizontal-volume-current',
            '.single-post article.format-audio .mkd-icon-holder .mkd-icon',
            '.mkd-blog-holder.mkd-blog-single .mkd-post-info-category a',
        );

        $woo_background_color_selector = array();
        if (sparks_mikado_is_woocommerce_installed()) {
            $woo_background_color_selector = array(
                '.woocommerce-page .mkd-content a.added_to_cart',
                '.woocommerce-page .mkd-content a.button',
                '.woocommerce-page .mkd-content button[type=submit]',
                '.woocommerce-page .mkd-content input[type=submit]',
                'div.woocommerce a.added_to_cart',
                'div.woocommerce a.button',
                'div.woocommerce button[type=submit]',
                'div.woocommerce input[type=submit]',
                '.woocommerce-page .mkd-content .wc-forward:not(.added_to_cart):not(.checkout-button)',
                'div.woocommerce .wc-forward:not(.added_to_cart):not(.checkout-button)',
                '.woocommerce .mkd-onsale',
                '.woocommerce-pagination .page-numbers li a.current',
                '.woocommerce-pagination .page-numbers li a:hover',
                '.woocommerce-pagination .page-numbers li span.current',
                '.woocommerce-pagination .page-numbers li span:hover',
                '.woocommerce-pagination .page-numbers li a:hover',
                '.mkd-woo-view-all-pagination a:hover',
                '.mkd-woo-single-page .woocommerce-tabs ul.tabs>li',
                'ul.products>.product .mkd-pl-inner .mkd-pl-text-inner .added_to_cart',
                'ul.products>.product .mkd-pl-inner .mkd-pl-text-inner .button',
                '.mkd-plc-holder .mkd-plc-item .mkd-plc-onsale',
                '.mkd-plc-holder .mkd-plc-item .added_to_cart',
                '.mkd-plc-holder .mkd-plc-item .button',
                '.mkd-plc-holder .mkd-plc-item .mkd-plc-add-to-cart.mkd-default-skin .added_to_cart',
                '.mkd-plc-holder .mkd-plc-item .mkd-plc-add-to-cart.mkd-default-skin .button',
                '.mkd-plc-holder .mkd-plc-item .mkd-plc-add-to-cart.mkd-light-skin .added_to_cart:hover',
                '.mkd-plc-holder .mkd-plc-item .mkd-plc-add-to-cart.mkd-light-skin .button:hover',
                '.mkd-plc-holder .mkd-plc-item .mkd-plc-add-to-cart.mkd-dark-skin .added_to_cart:hover',
                '.mkd-plc-holder .mkd-plc-item .mkd-plc-add-to-cart.mkd-dark-skin .button:hover',
                '.widget.woocommerce.widget_product_search .input-holder button',
                '.widget.woocommerce.widget_price_filter .price_slider_wrapper .ui-widget-content',
                '.widget.woocommerce.widget_price_filter .price_slider_wrapper .ui-widget-content .ui-slider-handle',
                '.widget.woocommerce.widget_price_filter .price_slider_amount .button',
                '.widget.woocommerce.widget_shopping_cart .widget_shopping_cart_content .buttons a',
                '.mkd-shopping-cart-dropdown .mkd-item-info-holder .remove:hover',
                '.mkd-shopping-cart-dropdown .mkd-cart-bottom .mkd-view-cart',
            );
        }

        $return_array['background_color_selector'] = array_merge($return_array['background_color_selector'], $woo_background_color_selector);

        ////////////////////////////////////////////////////////////////////////////////////////////////////////////////
        // generate background color important selectors array

        $return_array['background_color_important_selector'] = array(
            '.mkd-pricing-slider .mkd-pricing-slider-button-holder .mkd-pricing-slider-button-extra.active .mkd-btn',
            '.mkd-pricing-slider .mkd-pricing-slider-button-holder .mkd-pricing-slider-button.active .mkd-btn',
            '.mkd-pricing-slider .mkd-pricing-slider-info-holder .mkd-pricing-info-button .mkd-btn',
            '.mkd-btn.mkd-btn-outline:not(.mkd-btn-custom-hover-bg):hover',
            '.mkd-service-table table tbody tr td .mkd-btn.mkd-btn-solid:not(.mkd-btn-custom-hover-bg):hover',
        );

        $woo_background_color_important_selector = array();
        if (sparks_mikado_is_woocommerce_installed()) {
            $woo_background_color_important_selector = array(
                '.mkd-shopping-cart-holder .mkd-header-cart .mkd-cart-number',
            );
        }

        $return_array['background_color_important_selector'] = array_merge($return_array['background_color_important_selector'], $woo_background_color_important_selector);

        ////////////////////////////////////////////////////////////////////////////////////////////////////////////////
        // generate color selector array

        $return_array['color_selector'] = array(
            'a',
            'h1 a:hover',
            'h2 a:hover',
            'h3 a:hover',
            'h4 a:hover',
            'h5 a:hover',
            'h6 a:hover',
            'p a',
            '.mkd-comment-holder .mkd-comment .mkd-comment-text .mkd-comment-info>:hover',
            '.mkd-owl-slider .owl-nav .mkd-next-icon:hover i',
            '.mkd-owl-slider .owl-nav .mkd-prev-icon:hover i',
            '.mkd-main-menu ul li.mkd-active-item a',
            '.mkd-main-menu ul li:hover a',
            '.mkd-main-menu ul .mkd-menu-featured-icon',
            '.mkd-drop-down .second .inner ul li ul li:hover>a',
            '.mkd-drop-down .second .inner ul li.current-menu-item>a',
            '.mkd-drop-down .second .inner ul li.sub ul li:hover>a',
            '.mkd-drop-down .second .inner>ul>li:hover>a',
            '.mkd-drop-down .wide .second .inner ul li.sub .flexslider ul li a:hover',
            '.mkd-drop-down .wide .second ul li .flexslider ul li a:hover',
            '.mkd-drop-down .wide .second .inner ul li.sub .flexslider.widget_flexslider .menu_recent_post_text a:hover',
            '.mkd-header-vertical .mkd-vertical-dropdown-float .second .inner ul li a:hover',
            '.mkd-header-vertical .mkd-vertical-dropdown-click .second .inner ul li a:hover',
            '.mkd-header-vertical .mkd-vertical-menu ul li a:hover',
            '.mkd-mobile-header .mkd-mobile-nav a:hover',
            '.mkd-mobile-header .mkd-mobile-nav h4:hover',
            '.mkd-mobile-header .mkd-mobile-menu-opener a:hover',
            '.mkd-page-header .mkd-sticky-header .mkd-main-menu>ul>li:hover>a',
            '.mkd-page-header .mkd-sticky-header .mkd-search-opener:hover',
            '.mkd-page-header .mkd-sticky-header .mkd-side-menu-button-opener:hover',
            '.mkd-page-header .mkd-search-opener:hover',
            '.mkd-title .mkd-title-holder .mkd-breadcrumbs a:hover',
            '.mkd-side-menu-button-opener:hover',
            'nav.mkd-fullscreen-menu ul>li:hover>a',
            '.mkd-search-cover .mkd-search-close a:hover',
            '.mkd-portfolio-list-holder article .mkd-pli-text .mkd-pli-category-holder h6 a:hover',
            '.mkd-portfolio-list-holder.mkd-pl-gallery-overlay article .mkd-pli-text .mkd-pli-category-holder a:hover',
            '.mkd-pl-filter-holder ul li.mkd-pl-current h6',
            '.mkd-pl-filter-holder ul li:hover h6',
            '.mkd-portfolio-slider-holder .owl-nav .mkd-next-icon:hover i',
            '.mkd-portfolio-slider-holder .owl-nav .mkd-prev-icon:hover i',
            '.mkd-portfolio-single-holder .mkd-ps-info-holder .mkd-portfolio-info-item.mkd-portfolio-categories h6 a:hover',
            '.mkd-portfolio-single-holder .mkd-ps-info-holder .mkd-portfolio-info-item.mkd-portfolio-tags h6 a:hover',
            '.mkd-portfolio-single-holder .mkd-ps-info-holder .mkd-portfolio-info-item.mkd-portfolio-custom-field a:hover',
            '.mkd-portfolio-single-nav .mkd-portfolio-next:hover a .nav-item h6',
            '.mkd-portfolio-single-nav .mkd-portfolio-prev:hover a .nav-item h6',
            '.mkd-portfolio-single-nav .mkd-portfolio-back-btn:hover a',
            '.mkd-team.main-info-below-image .mkd-team-info .mkd-team-title-holder .mkd-team-position',
            '.mkd-team.main-info-below-image .mkd-team-info .mkd-team-social-wrapp .mkd-icon-shortcode a:hover',
            '.mkd-counter-holder .mkd-counter',
            '.mkd-message .mkd-message-inner a.mkd-close i:hover',
            '.mkd-ordered-list ol>li.mkd-list-item:before',
            '.mkd-unordered-list ul>li.mkd-list-item .icon i',
            '.mkd-progress-bar .mkd-progress-number-wrapper.mkd-static .mkd-progress-number',
            '.mkd-testimonials-holder .mkd-testimonials.mkd-testimonials-slider .mkd-testimonial-text-holder .mkd-testimonial-text-inner .mkd-testimonials-job',
            '.mkd-price-table.mkd-active .mkd-price-table-inner .mkd-price-table-price .mkd-price-holder .mkd-value',
            '.mkd-larger-active .mkd-price-table.mkd-active .mkd-price-table-inner .mkd-price-table-title h4',
            '.mkd-pricing-slider .mkd-pricing-slider-info-holder .mkd-pricing-info-pricing .mkd-price',
            '.mkd-blog-list-holder .mkd-item-info-section>div a:hover',
            '.mkd-btn.mkd-btn-outline',
            '.mkd-btn.mkd-btn-minimal',
            'blockquote .mkd-icon-quotations-holder',
            '.mkd-video-button-play .mkd-video-button-wrapper',
            '.mkd-dropcaps',
            '.mkd-service-table table tbody tr td .mkd-mark.mkd-checked',
            '.mkd-video-banner-holder .mkd-video-banner-overlay .mkd-video-banner-overlay-inner1 .mkd-video-banner-overlay-inner2 .mkd-icon-holder:after',
            '.mkd-twitter-slider .mkd-twitter-slider-item .mkd-twitter-time:before',
            '.mkd-progress-circle-holder .mkd-progress-circle i',
            '.mkd-progress-circle-holder .mkd-progress-circle span',
            '.wpb_widgetised_column .widget ul li>a:hover',
            'aside.mkd-sidebar .widget ul li>a:hover',
            '.wpb_widgetised_column .widget #wp-calendar tfoot a:hover',
            'aside.mkd-sidebar .widget #wp-calendar tfoot a:hover',
            '.wpb_widgetised_column .mkd_twitter_widget li a:hover',
            'aside.mkd-sidebar .mkd_twitter_widget li a:hover',
            '.wpb_widgetised_column .widget_mkd_social_icon_widget .mkd-icon-shortcode.normal:hover a>i',
            'aside.mkd-sidebar .widget_mkd_social_icon_widget .mkd-icon-shortcode.normal:hover a>i',
            'footer .mkd-footer-top .mkd_twitter_widget li a:hover',
            'footer .mkd-footer-top .widget_mkd_social_icon_widget .mkd-icon-shortcode.normal:hover a>i',
            'footer .mkd-footer-bottom .mkd_twitter_widget li a:hover',
            'footer .mkd-footer-bottom .widget_mkd_social_icon_widget .mkd-icon-shortcode.normal:hover a>i',
            '.mkd-side-menu .mkd_twitter_widget li a:hover',
            '.mkd-side-menu .widget_mkd_social_icon_widget .mkd-icon-shortcode.normal:hover a>i',
            '.mkd-content-bottom .widget ul li>a:hover',
            '.mkd-content-bottom .widget #wp-calendar tfoot a:hover',
            '.mkd-content-bottom .mkd_twitter_widget li a:hover',
            '.mkd-content-bottom .widget_mkd_social_icon_widget .mkd-icon-shortcode.normal:hover a>i',
            '.mkd-blog-holder.mkd-blog-type-standard article.format-link .mkd-post-text .mkd-post-mark',
            '.mkd-blog-holder.mkd-blog-type-standard article.format-quote .mkd-post-text .mkd-post-mark',
            '.mkd-blog-holder.mkd-blog-type-standard article.format-quote .mkd-post-text a .quote-author',
            '.mkd-filter-blog-holder li.mkd-active',
            '.mkd-blog-holder.mkd-blog-type-masonry article.format-link .mkd-post-text .mkd-post-mark',
            '.mkd-blog-holder.mkd-blog-type-masonry article.format-quote .mkd-post-text .mkd-post-mark',
            '.mkd-blog-holder.mkd-blog-type-masonry article.format-quote .mkd-post-text a .quote-author',
            '.mkd-blog-holder:not(.mkd-blog-single) .mkd-post-info>div a:hover',
            '.mkd-blog-holder:not(.mkd-blog-single) .mkd-post-info>div.mkd-blog-like a:hover:before',
            '.mkd-author-description .mkd-author-social-holder a:hover',
            '.single-post article.format-link .mkd-post-text .mkd-post-mark',
            '.single-post article.format-quote .mkd-post-text .mkd-post-mark',
            '.mkd-blog-holder.mkd-blog-single .mkd-post-info>div a:hover',
            '.mkd-blog-holder.mkd-blog-single .mkd-post-info>div.mkd-blog-like a:hover:before',
            '.single-post .mkd-blog-single-nav .mkd-blog-next:hover a .nav-item h6',
            '.single-post .mkd-blog-single-nav .mkd-blog-prev:hover a .nav-item h6',
        );

        $woo_color_selector = array();
        if (sparks_mikado_is_woocommerce_installed()) {
            $woo_color_selector = array(
                '.woocommerce .star-rating',
                '.mkd-single-product-summary .product_meta>span a:hover',
                'ul.products>.product .mkd-pl-text-wrapper .price del',
                '.mkd-woocommerce-page.woocommerce-account .woocommerce-MyAccount-navigation ul li.is-active a',
                '.mkd-woocommerce-page.woocommerce-account .woocommerce table.shop_table td.order-number a:hover',
                '.mkd-plc-holder .mkd-plc-item .mkd-plc-rating',
                '.widget.woocommerce ul li a:hover',
                '.widget.woocommerce.widget_product_tag_cloud a:hover',
                '.widget.woocommerce.widget_shopping_cart .widget_shopping_cart_content ul li .remove:hover',
            );
        }

        $return_array['color_selector'] = array_merge($return_array['color_selector'], $woo_color_selector);

        ////////////////////////////////////////////////////////////////////////////////////////////////////////////////
        // generate color important selector array

        $return_array['color_important_selector'] = array(
            '.mkd-dark-header .mkd-vertical-menu>ul>li>a.current',
            '.mkd-dark-header .mkd-vertical-menu>ul>li>a:hover',
            '.mkd-light-header .mkd-dark-header .mkd-vertical-menu>ul>li>a.current',
            '.mkd-light-header .mkd-dark-header .mkd-vertical-menu>ul>li>a:hover',
            '.mkd-dark-header .mkd-page-header>div:not(.mkd-sticky-header) .mkd-side-menu-button-opener:hover',
            '.mkd-dark-header .mkd-top-bar .mkd-side-menu-button-opener:hover',
            '.mkd-dark-header.mkd-header-style-on-scroll .mkd-page-header .mkd-side-menu-button-opener:hover',
            '.mkd-light-header .mkd-page-header>div:not(.mkd-sticky-header) .mkd-side-menu-button-opener:hover',
            '.mkd-light-header .mkd-top-bar .mkd-side-menu-button-opener:hover',
            '.mkd-light-header.mkd-header-style-on-scroll .mkd-page-header .mkd-side-menu-button-opener:hover',
            '.mkd-btn.mkd-btn-minimal.mkd-light:not(.mkd-btn-custom-hover-color):hover',
            '.mkd-btn.mkd-btn-minimal.mkd-dark:not(.mkd-btn-custom-hover-color):hover',
            '.mkd-read-more-holder .mkd-btn.mkd-btn-minimal:hover',
        );

        ////////////////////////////////////////////////////////////////////////////////////////////////////////////////
        // generate border color selectors array

        $return_array['border_color_selector'] = array(
            '.mkd-st-loader .pulse_circles .ball',
            '#submit_comment',
            '.post-password-form input[type=submit]',
            'input.wpcf7-form-control.wpcf7-submit',
            '.mkd-page-header .mkd-main-menu>ul>li>a.current',
            '.mkd-page-header .mkd-main-menu>ul>li>a:hover',
            '.mkd-title .mkd-separator-holder .mkd-separator',
            '.mkd-testimonials-holder .mkd-testimonials.mkd-testimonials-slider .mkd-testimonial-text-holder .mkd-testimonial-text-inner .mkd-separator-holder .mkd-separator',
            '.mkd-price-table.mkd-active .mkd-price-table-inner .mkd-price-table-button .mkd-btn.mkd-btn-solid',
            '.mkd-separator',
            '.mkd-btn.mkd-btn-solid',
            '.mkd-btn.mkd-btn-outline',
            '.wpb_widgetised_column .widget .mkd-widget-title-holder .mkd-separator',
            'aside.mkd-sidebar .widget .mkd-widget-title-holder .mkd-separator',
            '.wpb_widgetised_column .widget_mkd_social_icon_widget .mkd-icon-shortcode.circle:hover',
            '.wpb_widgetised_column .widget_mkd_social_icon_widget .mkd-icon-shortcode.square:hover',
            'aside.mkd-sidebar .widget_mkd_social_icon_widget .mkd-icon-shortcode.circle:hover',
            'aside.mkd-sidebar .widget_mkd_social_icon_widget .mkd-icon-shortcode.square:hover',
            'footer .mkd-footer-top .widget_mkd_social_icon_widget .mkd-icon-shortcode.circle:hover',
            'footer .mkd-footer-top .widget_mkd_social_icon_widget .mkd-icon-shortcode.square:hover',
            'footer .mkd-footer-bottom .widget_mkd_social_icon_widget .mkd-icon-shortcode.circle:hover',
            'footer .mkd-footer-bottom .widget_mkd_social_icon_widget .mkd-icon-shortcode.square:hover',
            '.mkd-side-menu .widget .mkd-widget-title-holder .mkd-separator',
            '.mkd-side-menu .widget_mkd_social_icon_widget .mkd-icon-shortcode.circle:hover',
            '.mkd-side-menu .widget_mkd_social_icon_widget .mkd-icon-shortcode.square:hover',
            '.mkd-content-bottom .widget .mkd-widget-title-holder .mkd-separator',
            '.mkd-content-bottom .widget_mkd_social_icon_widget .mkd-icon-shortcode.circle:hover',
            '.mkd-content-bottom .widget_mkd_social_icon_widget .mkd-icon-shortcode.square:hover',
            '.mkd-blog-holder.mkd-date-outside .mkd-post-info-date .year',
            '.mkd-post-ajax-preloader .mkd-pulse',
        );

        ////////////////////////////////////////////////////////////////////////////////////////////////////////////////
        // generate border color important selectors array

        $return_array['border_color_important_selector'] = array(
            '.mkd-pricing-slider .mkd-pricing-slider-info-holder .mkd-pricing-info-button .mkd-btn',
            '.mkd-btn.mkd-btn-outline:not(.mkd-btn-custom-border-hover):hover',
            '.mkd-service-table table tbody tr td .mkd-btn.mkd-btn-solid:not(.mkd-btn-custom-hover-bg):hover',
        );

        return $return_array;
    }
}

if ( ! function_exists( 'sparks_mikado_get_module_part' ) ) {
	function sparks_mikado_get_module_part( $module ) {
		return $module;
	}
}